import 'dart:convert';
import 'package:mmoo_easemob_im/mmoo_easemob_im.dart';
import 'package:mmoo_live_room/Config/config_live_socket.dart';
import 'package:mmoo_live_room/Model/model_rtm_message.dart';
import 'package:mmoo_live_room/Utils/utils_live_dlog.dart';

typedef OnUserJoinLiveBlack = void Function(ModelRtmMessage rtmMessage);
typedef OnUserExitLiveBlack = void Function(ModelRtmMessage rtmMessage);
typedef OnUserJoinPrivateBlack = void Function(ModelRtmMessage rtmMessage);
typedef OnUserSendGiftBlack = void Function(ModelRtmMessage rtmMessage);

typedef OnUserSendTextBlack = void Function(ModelRtmMessage rtmMessage);

typedef OnUserJoinPlaceBlack = void Function(ModelRtmMessage rtmMessage);
typedef OnUserExitPlaceBlack = void Function(ModelRtmMessage rtmMessage);
typedef OnLiveNoticeBlack = void Function(ModelRtmMessage rtmMessage);
typedef OnUserIsBanMicrophoneBlack = void Function(ModelRtmMessage rtmMessage);
// typedef OnUserIsCloseMicrophoneBlack = void Function(
//     ModelRtmMessage rtmMessage);
typedef OnMasterSetPriceBlack = void Function(ModelRtmMessage rtmMessage);
typedef OnUserRefreshLiveInfoBlack = void Function(ModelRtmMessage rtmMessage);
typedef OnUserLiveInfoBlack = void Function(ModelRtmMessage rtmMessage);
typedef OnMasterCloseLiveBlack = void Function(ModelRtmMessage rtmMessage);
typedef OnUserIsBannedBlack = void Function(ModelRtmMessage rtmMessage);
// typedef OnUserExitVoicePlaceBlack = void Function(
//     ModelRtmMessage rtmMessage);
typedef OnUserLiveBlackBlack = void Function(ModelRtmMessage rtmMessage);
typedef OnMasterApplyJoinPlaceBlack = void Function(ModelRtmMessage rtmMessage);
typedef OnMasterIsAgreeJoibPlaceBlack = void Function(
    ModelRtmMessage rtmMessage);
typedef OnMasterInviteJoinPlaceBlack = void Function(
    ModelRtmMessage rtmMessage);
// typedef OnMasterOperationExitPlace = void Function(ModelRtmMessage rtmMessage);
typedef OnOtherMethod = void Function();

typedef OnUserLiveRefusePlaceBlack = void Function(
  ModelRtmMessage rtmMessage,
);
typedef OnUserLiveCancelPlaceBlack = void Function(ModelRtmMessage rtmMessage);

class LiveSocketEventHandler {
  OnUserJoinLiveBlack? onUserJoinLiveBlack;
  OnUserExitLiveBlack? onUserExitLiveBlack;
  OnUserLiveRefusePlaceBlack? onUserLiveRefusePlaceBlack;
  OnUserLiveCancelPlaceBlack? onUserLiveCancelPlaceBlack;
  // OnUserChangePermissionsBlack? onUserChangePermissionsBlack;
  OnUserJoinPrivateBlack? onUserJoinPrivateBlack;
  OnUserSendGiftBlack? onUserSendGiftBlack;
  OnUserSendTextBlack? onUserSendTextBlack;
  OnUserJoinPlaceBlack? onUserJoinPlaceBlack;
  // OnMasterOperationExitPlace? onMasterOperationExitPlace;
  OnUserExitPlaceBlack? onUserExitPlaceBlack;
  OnLiveNoticeBlack? onLiveNoticeBlack;
  OnUserIsBanMicrophoneBlack? onUserIsBanMicrophoneBlack;
  // OnUserIsCloseMicrophoneBlack? onUserIsCloseMicrophoneBlack;
  OnMasterSetPriceBlack? onMasterSetPriceBlack;
  OnUserRefreshLiveInfoBlack? onUserRefreshLiveInfoBlack;
  OnUserLiveInfoBlack? onUserLiveInfoBlack;
  OnMasterCloseLiveBlack? onMasterCloseLiveBlack;
  OnUserIsBannedBlack? onUserIsBannedBlack;

  OnUserLiveBlackBlack? onUserLiveBlackBlack;
  OnMasterApplyJoinPlaceBlack? onMasterApplyJoinPlaceBlack;
  OnMasterIsAgreeJoibPlaceBlack? onMasterIsAgreeJoibPlaceBlack;
  OnMasterInviteJoinPlaceBlack? onMasterInviteJoinPlaceBlack;
  OnOtherMethod? onOtherMethod;
  LiveSocketEventHandler({
    this.onUserJoinLiveBlack,
    this.onUserExitLiveBlack,
    this.onUserJoinPrivateBlack,
    this.onUserSendGiftBlack,
    this.onUserSendTextBlack,
    this.onUserJoinPlaceBlack,
    this.onUserExitPlaceBlack,
    this.onLiveNoticeBlack,
    this.onUserIsBanMicrophoneBlack,
    this.onMasterSetPriceBlack,
    this.onUserRefreshLiveInfoBlack,
    this.onUserLiveInfoBlack,
    this.onMasterCloseLiveBlack,
    this.onUserIsBannedBlack,
    this.onUserLiveCancelPlaceBlack,
    this.onUserLiveRefusePlaceBlack,
    this.onMasterApplyJoinPlaceBlack,
    this.onMasterIsAgreeJoibPlaceBlack,
    this.onMasterInviteJoinPlaceBlack,
    this.onUserLiveBlackBlack,
    this.onOtherMethod,
  });

  void onMessageReceived(EMMessage message) {
    if (message.body is EMTextMessageBody || message.body is EMCmdMessageBody) {
      ModelRtmMessage rtmMessage;
      if (message.body is EMTextMessageBody) {
        EMTextMessageBody body = message.body as EMTextMessageBody;
        rtmMessage = ModelRtmMessage.fromJson(jsonDecode(body.content ?? ''));
      } else {
        // DLog(msg)/
        var map = jsonDecode(message.attributes['content']);
        if (map is String) {
          map = jsonDecode(map);
        }
        rtmMessage = ModelRtmMessage.fromJson(map);
      }
      if (rtmMessage.typeMethod == ConfigLiveSocket.liveSocketConfig_joinRoom) {
        onUserJoinLiveBlack?.call(rtmMessage);
      } else if (rtmMessage.typeMethod ==
          ConfigLiveSocket.liveSocketConfig_exitRoom) {
        onUserExitLiveBlack?.call(rtmMessage);
      } else if (rtmMessage.typeMethod ==
          ConfigLiveSocket.liveSocketConfig_joinPrivate) {
        onUserJoinPrivateBlack?.call(rtmMessage);
      } else if (rtmMessage.typeMethod ==
          ConfigLiveSocket.liveSocketConfig_sendGift) {
        onUserSendGiftBlack?.call(rtmMessage);
      } else if (rtmMessage.typeMethod ==
          ConfigLiveSocket.liveSocketConfig_sendText) {
        onUserSendTextBlack?.call(rtmMessage);
      } else if (rtmMessage.typeMethod ==
          ConfigLiveSocket.liveSocketConfig_joinPlace) {
        onUserJoinPlaceBlack?.call(rtmMessage);
      } else if (rtmMessage.typeMethod ==
          ConfigLiveSocket.liveSocketConfig_exitPlace) {
        onUserExitPlaceBlack?.call(rtmMessage);
      } else if (rtmMessage.typeMethod ==
          ConfigLiveSocket.liveSocketConfig_liveNotice) {
        onLiveNoticeBlack?.call(rtmMessage);
      } else if (rtmMessage.typeMethod ==
          ConfigLiveSocket.liveSocketConfig_isBanMicrophone) {
        onUserIsBanMicrophoneBlack?.call(rtmMessage);
      } else if (rtmMessage.typeMethod ==
          ConfigLiveSocket.liveSocketConfig_setPrice) {
        onMasterSetPriceBlack?.call(rtmMessage);
      } else if (rtmMessage.typeMethod ==
          ConfigLiveSocket.liveSocketConfig_refreshLiveInfo) {
        onUserRefreshLiveInfoBlack?.call(rtmMessage);
      } else if (rtmMessage.typeMethod ==
          ConfigLiveSocket.liveSocketConfig_liveInfo) {
        onUserLiveInfoBlack?.call(rtmMessage);
      } else if (rtmMessage.typeMethod ==
          ConfigLiveSocket.liveSocketConfig_closeLive) {
        onMasterCloseLiveBlack?.call(rtmMessage);
      } else if (rtmMessage.typeMethod ==
          ConfigLiveSocket.liveSocketConfig_isBanned) {
        onUserIsBannedBlack?.call(rtmMessage);
      } else if (rtmMessage.typeMethod ==
          ConfigLiveSocket.liveSocketConfig_liveBlack) {
        onUserLiveBlackBlack?.call(rtmMessage);
      } else if (rtmMessage.typeMethod ==
          ConfigLiveSocket.liveSocketConfig_applyJoinPlace) {
        onMasterApplyJoinPlaceBlack?.call(rtmMessage);
      } else if (rtmMessage.typeMethod ==
          ConfigLiveSocket.liveSocketConfig_isAgreeJoibPlace) {
        onMasterIsAgreeJoibPlaceBlack?.call(rtmMessage);
      } else if (rtmMessage.typeMethod ==
          ConfigLiveSocket.liveSocketConfig_inviteJoinPlace) {
        onMasterInviteJoinPlaceBlack?.call(rtmMessage);
      } else if (rtmMessage.typeMethod ==
          ConfigLiveSocket.liveSocketConfig_RefusePlace) {
        onUserLiveRefusePlaceBlack?.call(
          rtmMessage,
        );
      } else if (rtmMessage.typeMethod ==
          ConfigLiveSocket.liveSocketConfig_cancelPlace) {
        onUserLiveCancelPlaceBlack?.call(rtmMessage);
      } else {
        onOtherMethod?.call();
      }
    }
  }
}
