// import 'package:mmoo_live_room/Config/LiveSocketConfig.dart';
// import 'package:mmoo_live_room/Provider/provider_live_user.dart';
// import 'package:mmoo_live_room/Model/model_lastLive_entity.dart';
// import 'package:mmoo_live_room/Model/model_liveInfo_entity.dart';

import 'dart:convert';

import 'package:image_picker/image_picker.dart';
import 'package:mmoo_base/utils/common_utils.dart';
import 'package:mmoo_live_room/Config/config_live_socket.dart';
import 'package:mmoo_live_room/Model/model_live_info_entity.dart';
import 'package:mmoo_live_room/Provider/provider_live_user.dart';
import 'package:mmoo_live_room/Utils/utils_live_alert.dart';
import 'package:mmoo_live_room/Utils/utils_live_permission.dart';
import 'package:mmoo_live_room/generated/l10n.dart';
import 'package:permission_handler/permission_handler.dart';

class UtilsLive {
//转化年龄工具类
  static String getAge(String ageStr) {
    if (ageStr.length < 3) {
      return '18';
    }
    DateTime brt = DateTime.parse(ageStr);
    if (brt.year < 1000) {
      brt = DateTime.utc(DateTime.now().year - 18);
    }
    int age = 0;
    DateTime dateTime = DateTime.now();
    int yearNow = dateTime.year; //当前年份
    int monthNow = dateTime.month; //当前月份
    int dayOfMonthNow = dateTime.day; //当前日期

    int yearBirth = brt.year;
    int monthBirth = brt.month;
    int dayOfMonthBirth = brt.day;
    age = yearNow - yearBirth; //计算整岁数
    if (monthNow <= monthBirth) {
      if (monthNow == monthBirth) {
        if (dayOfMonthNow < dayOfMonthBirth) age--; //当前日期在生日之前，年龄减一
      } else {
        age--; //当前月份在生日之前，年龄减一
      }
    }
    return age.toString();
  }

  static ModelLiveInfoPlaceList? getOwenrPlaceInfo(
      ModelLiveInfoEntity infoEntity) {
    ModelLiveInfoPlaceList? placeList;
    infoEntity.videoPlaceList?.forEach((element) {
      if (element.userId == ProviderLiveUser().userInfo.uid) {
        placeList = element;
      }
    });
    infoEntity.voicePlaceList?.forEach((element) {
      if (element.userId == ProviderLiveUser().userInfo.uid) {
        placeList = element;
      }
    });
    return placeList;
  }

  static Map<String, dynamic> rtmSendMessageMap(
      String typeMethod, String text) {
    return {
      "typeMethod": typeMethod,
      "content": text,
      "userId": ProviderLiveUser().userInfo.uid.toString(),
      "headImage": ProviderLiveUser().userInfo.headImage.toString(),
      "name": ProviderLiveUser().userInfo.nickName.toString(),
      "roomUserId": ProviderLiveUser.roomUserId.toString(),
      "roomId": ProviderLiveUser.roomId.toString(),
      "isHost": ProviderLiveUser().userInfo.isHost.toString(),
    };
  }

  Map<String, dynamic> rtmSendGiftMap({
    required String gifUrl,
    required int id,
    required String name,
    required String preUrl,
    required String price,
    required String num,
    required List giveGiftUserInfoList,
  }) {
    return {
      "typeMethod": ConfigLiveSocket.liveSocketConfig_sendGift,
      "content": const JsonEncoder().convert({
        "gifUrl": gifUrl,
        "id": id,
        "name": name,
        "preUrl": preUrl,
        "num": num,
        "giveGiftUserInfoList": giveGiftUserInfoList,
        "price": price
      }),
      "userId": ProviderLiveUser().userInfo.uid.toString(),
      "headImage": ProviderLiveUser().userInfo.headImage.toString(),
      "name": ProviderLiveUser().userInfo.nickName.toString(),
      "roomUserId": ProviderLiveUser.roomUserId.toString(),
      "isHost" : ProviderLiveUser().userInfo.isHost.toString(),
      "roomId": ProviderLiveUser.roomId.toString()
    };
  }

  static void showImageView(context, callback, {showCallback}) async {
    UtilsLiveAlert.showActionSheet(context,
        rows: [S.current.Live_Albumupload, S.current.Live_Cameraupload],
        selectAction: (index, title) async {
      if (index == 1) {
        if (await UtilsLivePermission.checkPermission(
            context, Permission.camera)) {
          showCallback?.call(false);
          XFile? image = await ImagePicker()
              .pickImage(source: ImageSource.camera)
              .catchError((onError) {
            CommonUtils.showToast(onError.toString());
          });
          if (image != null) {
            if (image.path.contains(' ')) {
              CommonUtils.showToast(S.current.Live_takefilefailed);
              return;
            }
            callback?.call(image.path);
          }
          showCallback?.call(true);
        }
      } else if (index == 0) {
        if (await UtilsLivePermission.checkPermission(
            context, Permission.photos)) {
          showCallback?.call(false);
          XFile? image = await ImagePicker()
              .pickImage(source: ImageSource.gallery)
              .catchError((onError) {
            CommonUtils.showToast(onError.toString());
          });
          if (image != null) {
            if (image.path.contains(' ')) {
              CommonUtils.showToast(S.current.Live_takefilefailed);
              return;
            }
            callback?.call(image.path);
          }
          showCallback?.call(true);
        }
      }
    });
  }
}
 
  

//   //主播是否同意 用户上麦
//   Map<String, dynamic> rtmSendIsAgreeMessageMap(bool isAgree, int type) {
//     return {
//       "typeMethod": LiveSocketConfig.liveSocketConfig_isAgreeJoibPlace,
//       "content": JsonEncoder().convert({"isAgree": isAgree ? "1" : "0", "type": type}),
//       "userId": ProviderLiveUser().userInfo.uid.toString(),
//       "headImage": ProviderLiveUser().userInfo.headImage.toString(),
//       "name": ProviderLiveUser().userInfo.nickName.toString(),
//       "roomUserId": ProviderLiveUser.roomUserId.toString(),
//       "isHost" : ProviderLiveUser().userInfo.isHost.toString(),
//       "roomId": ProviderLiveUser.roomId.toString()
//     };
//   }

// //用户主动 申请上麦
//   Map<String, dynamic> rtmSendApplyForMikeMap() {
//     return {
//       "typeMethod": LiveSocketConfig.liveSocketConfig_applyJoinPlace,
//       "content": "",
//       "userId": ProviderLiveUser().userInfo.uid.toString(),
//       "headImage": ProviderLiveUser().userInfo.headImage.toString(),
//       "name": ProviderLiveUser().userInfo.nickName.toString(),
//       "roomUserId": ProviderLiveUser.roomUserId.toString(),
//       "isHost" : ProviderLiveUser().userInfo.isHost.toString(),
//       "roomId": ProviderLiveUser.roomId.toString()
//     };
//   }

//   //管理员邀请上麦   type 0 语音 1 视频
//   Map<String, dynamic> rtmSendInviteJoinPlaceMap(int type) {
//     return {
//       "typeMethod": LiveSocketConfig.liveSocketConfig_inviteJoinPlace,
//       "content": type.toString(),
//       "userId": ProviderLiveUser().userInfo.uid.toString(),
//       "headImage": ProviderLiveUser().userInfo.headImage.toString(),
//       "name": ProviderLiveUser().userInfo.nickName.toString(),
//       "roomUserId": ProviderLiveUser.roomUserId.toString(),
//       "isHost" : ProviderLiveUser().userInfo.isHost.toString(),
//       "roomId": ProviderLiveUser.roomId.toString()
//     };
//     // 管理员邀请上麦   type 0 语音 1 视频
//   }

  

//   Map<String, dynamic> rtmSendJoinPlaceMap({
//     required ModelLiveInfoPlaceList placeList,
//   }) {
//     return {
//       "typeMethod": LiveSocketConfig.liveSocketConfig_joinPlace,
//       "content": JsonEncoder().convert(placeList.toJson()),
//       "userId": ProviderLiveUser().userInfo.uid.toString(),
//       "headImage": ProviderLiveUser().userInfo.headImage.toString(),
//       "name": ProviderLiveUser().userInfo.nickName.toString(),
//       "roomUserId": ProviderLiveUser.roomUserId.toString(),
//       "isHost" : ProviderLiveUser().userInfo.isHost.toString(),
//       "roomId": ProviderLiveUser.roomId.toString()
//     };
//   }

//   //是否禁言麦克风
//   Map<String, dynamic> rtmSendIsMicphoneMap({
//     required ModelLiveInfoPlaceList placeList,
//   }) {
//     return {
//       "typeMethod": LiveSocketConfig.liveSocketConfig_isBanMicrophone,
//       "content": JsonEncoder().convert(placeList.toJson()),
//       "userId": ProviderLiveUser().userInfo.uid.toString(),
//       "headImage": ProviderLiveUser().userInfo.headImage.toString(),
//       "name": ProviderLiveUser().userInfo.nickName.toString(),
//       "roomUserId": ProviderLiveUser.roomUserId.toString(),
//       "isHost" : ProviderLiveUser().userInfo.isHost.toString(),
//       "roomId": ProviderLiveUser.roomId.toString()
//     };
//   }

//     //是否关闭麦克风
//   // Map<String, dynamic> rtmSendIsCloseMicphoneMap({
//   //   required ModelLiveInfoPlaceList placeList,
//   // }) {
//   //   return {
//   //     "typeMethod": LiveSocketConfig.liveSocketConfig_isCloseMicrophone,
//   //     "content": JsonEncoder().convert(placeList.toJson()),
//   //     "userId": ProviderLiveUser().userInfo.uid.toString(),
//   //     "headImage": ProviderLiveUser().userInfo.headImage.toString(),
//   //     "name": ProviderLiveUser().userInfo.nickName.toString(),
//   //     "roomUserId": ProviderLiveUser.roomUserId.toString(),
//   //     "isHost" : ProviderLiveUser().userInfo.isHost.toString(),
//   //     "roomId": ProviderLiveUser.roomId.toString()
//   //   };
//   // }

//   Map<String, dynamic> rtmSendUpdataRoomInfoMap({
//     required ModelLastLiveEntity infoEntity,
//     required int liveId,
//   }) {
//     return {
//       "typeMethod": LiveSocketConfig.liveSocketConfig_liveInfo,
//       "content": JsonEncoder().convert({
//         'language': infoEntity.language,
//         'liveNotice': infoEntity.liveNotice ?? '',
//         'title': infoEntity.title ?? '',
//         'videoPrice': infoEntity.chooseVideoPrice,
//         'price': infoEntity.pricatePrice,
//         'roomId': infoEntity.roomId,
//         'liveId': liveId,
//         'voicePrice': infoEntity.chooseVoicePrice
//       }),
//       "userId": ProviderLiveUser().userInfo.uid.toString(),
//       "headImage": ProviderLiveUser().userInfo.headImage.toString(),
//       "name": ProviderLiveUser().userInfo.nickName.toString(),
//       "roomUserId": ProviderLiveUser.roomUserId.toString(),
//       "isHost" : ProviderLiveUser().userInfo.isHost.toString(),
//       "roomId": ProviderLiveUser.roomId.toString()
//     };
//   }

//     ModelLiveInfoPlaceList? getPlaceIdPlaceInfo(ModelLiveInfoEntity infoEntity,int placeID ) {
//     ModelLiveInfoPlaceList? placeList;
//     infoEntity.videoPlaceList?.forEach((element) {
//         if (element.roomPlaceId == placeID) {
//           placeList = element;
//         }
//     });
//     infoEntity.voicePlaceList?.forEach((element) {
//         if (element.roomPlaceId == placeID) {
//           placeList = element;
//         }
//     });
//     return placeList;
//   }
  
//   ModelLiveInfoPlaceList? getOwenrPlaceInfo(ModelLiveInfoEntity infoEntity) {
//     ModelLiveInfoPlaceList? placeList;
//     infoEntity.videoPlaceList?.forEach((element) {
//         if (element.userId == ProviderLiveUser().userInfo.uid) {
//           placeList = element;
//         }
//     });
//     infoEntity.voicePlaceList?.forEach((element) {
//         if (element.userId == ProviderLiveUser().userInfo.uid) {
//           placeList = element;
//         }
//     });
//     return placeList;
//   }

//   //检测对方有没有在线且在该直播间
//   // Future<bool> checkOtherPartyIsOnRoom(int userId, int roomId,
//   //     {bool isShotToast = true}) async {
//   //   if (AgoraRtmManager.getInstance().getClient() == null) {
//   //     return false;
//   //   }
//   //   Map map = await AgoraRtmManager.getInstance()
//   //       .getClient()!
//   //       .queryPeersOnlineStatus([userId.toString()]);
//   //   if (map[userId.toString()]) {
//   //     DataResult dataResult = await LiveRepositoryImpl()
//   //         .apiLiveUserIsOnRoom(userId: userId, roomId: roomId);
//   //     if (dataResult.result && dataResult.data != null) {
//   //       int type = dataResult.data['type'] is String
//   //           ? int.parse(dataResult.data['type'])
//   //           : dataResult.data['type'].toInt();
//   //       if (type == 1) {
//   //         return true;
//   //       } else {
//   //         if (isShotToast) {
//   //           CommonUtils.showToast(S.current.Live_userNotRoom);
//   //         }

//   //         return false;
//   //       }
//   //     } else {
//   //       return false;
//   //     }
//   //   } else {
//   //     if (isShotToast) {
//   //       CommonUtils.showToast(S.current.Live_Theotherpersonisnotonline);
//   //     }
//   //     return false;
//   //   }
//   // }
// }
