import 'package:flutter/material.dart';
import 'package:flutter_screenutil/flutter_screenutil.dart';
import 'package:mmoo_base/dao/dao_result.dart';
import 'package:mmoo_base/entity/base_entity.dart';
import 'package:mmoo_base/utils/navigator_utils.dart';
import 'package:mmoo_live_room/Utils/utils_live_colors.dart';
import 'package:mmoo_live_room/Utils/utils_live_image.dart';
import 'package:mmoo_live_room/Utils/utils_live_repeat_click.dart';
import 'package:mmoo_live_room/Utils/utils_live_svga_widget.dart';
import 'package:mmoo_live_room/Utils/utils_live_textStyle.dart';
import 'package:mmoo_live_room/Widget/widget_action_btns.dart';

class UtilsLiveAlert {
  /// 中间弹出弹窗
  static Future showCenter(
    BuildContext context, {
    required Widget? child,
    bool barrierDismissible = true,
  }) async {
    await showDialog(
      context: context,
      useSafeArea: false,
      barrierColor: Colors.transparent,
      builder: (ctx) {
        return GestureDetector(
          child: Container(
            color: Colors.black.withOpacity(0.3),
            child: Column(
              children: [
                Expanded(child: Container()),
                Center(child: child),
                Expanded(child: Container()),
              ],
            ),
          ),
          onTap: () {
            if (barrierDismissible) {
              if (Navigator.of(context).canPop()) {
                Navigator.of(context).pop();
              }
            }
          },
        );
      },
    );
  }

  static Future showCenterGeneral(
    BuildContext context, {
    bool barrierDismissible = true,
    bool isLive = false,
    required String infoStr,
    String? leftStr,
    String rightStr = "Cancel",
    Function? leftVoidCallBack,
    Function? rightVoidCallBack,
  }) async {
    await showDialog(
      context: context,
      useSafeArea: false,
      barrierColor: Colors.transparent,
      builder: (ctx) {
        return GestureDetector(
          child: Container(
            color: Colors.black.withOpacity(0.3),
            child: Column(
              children: [
                Expanded(child: Container()),
                Center(
                    child: Container(
                  padding: EdgeInsets.only(
                      left: 15.w, right: 15.w, top: 30.w, bottom: 20.w),
                  width: 325.w,
                  decoration: BoxDecoration(
                    color: isLive ? const Color(0xff2B1248) : Colors.white,
                    borderRadius: BorderRadius.circular(30),
                  ),
                  child: Column(
                    children: [
                      Container(
                        alignment: Alignment.center,
                        constraints: BoxConstraints(maxWidth: 280.w),
                        child: Text(infoStr,
                            textAlign: TextAlign.center,
                            style: TextStyle(
                                fontSize: 18,
                                color: isLive
                                    ? Colors.white
                                    : const Color(0xff333333),
                                fontWeight: FontWeight.bold,
                                decoration: TextDecoration.none)),
                      ),
                      SizedBox(
                        height: 20.w,
                      ),
                      leftStr == null
                          ? Row(
                              children: [
                                Expanded(
                                    child: GestureDetector(
                                  onTap: UtilsLiveRepeatClick.debounce(() {
                                    Navigator.pop(context);
                                    if (rightVoidCallBack != null) {
                                      rightVoidCallBack();
                                    }
                                  }),
                                  child: Container(
                                    alignment: Alignment.center,
                                    height: 50.w,
                                    decoration: const ShapeDecoration(
                                        shape: StadiumBorder(),
                                        gradient: LinearGradient(
                                            colors:
                                                UtilsLiveColor.startColors)),
                                    child: Text(
                                      rightStr,
                                      style:
                                          UtilsLiveTextStyle.pt20WhiteSemiBold,
                                    ),
                                  ),
                                ))
                              ],
                            )
                          : Row(
                              mainAxisAlignment: MainAxisAlignment.spaceBetween,
                              children: [
                                GestureDetector(
                                    onTap:
                                        UtilsLiveRepeatClick.debounce(() async {
                                      Navigator.pop(context);
                                      if (leftVoidCallBack != null) {
                                        leftVoidCallBack();
                                      }
                                    }),
                                    child: Container(
                                      width: 140.w,
                                      alignment: Alignment.center,
                                      height: 50.w,
                                      decoration: BoxDecoration(
                                          borderRadius:
                                              BorderRadius.circular(25.w),
                                          border: Border.all(
                                              width: 2,
                                              color: const Color(0xffFB5C9A))),
                                      child: Text(
                                        leftStr,
                                        style: const TextStyle(
                                            fontSize: 20,
                                            color: Color(0xffFB5C9A),
                                            fontWeight: FontWeight.w600,
                                            decoration: TextDecoration.none),
                                      ),
                                    )),
                                GestureDetector(
                                    onTap:
                                        UtilsLiveRepeatClick.debounce(() async {
                                      Navigator.pop(context);
                                      if (rightVoidCallBack != null) {
                                        rightVoidCallBack();
                                      }
                                    }),
                                    child: Container(
                                      height: 50.w,
                                      width: 140.w,
                                      alignment: Alignment.center,
                                      decoration: const ShapeDecoration(
                                          shape: StadiumBorder(),
                                          gradient: LinearGradient(
                                              colors:
                                                  UtilsLiveColor.startColors)),
                                      child: Text(
                                        rightStr,
                                        style: UtilsLiveTextStyle
                                            .pt20WhiteSemiBold,
                                      ),
                                    ))
                              ],
                            )
                    ],
                  ),
                )),
                Expanded(child: Container()),
              ],
            ),
          ),
          onTap: () {
            if (barrierDismissible) {
              if (Navigator.of(context).canPop()) {
                Navigator.of(context).pop();
              }
            }
          },
        );
      },
    );
// return;
  }

  static showDioTips(BuildContext context, DataResult dataResult) {
    if (dataResult.data is BaseEntity) {
      BaseEntity baseEntity = dataResult.data;
      if (baseEntity.code != null) {
        UtilsLiveAlert.showCenterGeneral(context,
            isLive: true, infoStr: baseEntity.msg ?? '');

        // if (int.parse(baseEntity.code!)  >= 7500 && int.parse(baseEntity.code!) < 7600) {
        //   WidgetActionBtns.showMimoLiveAlert(context, leftCallBack: () {

        //   }, infoString: baseEntity.msg ?? '');
        // } else {
        //   ToastUtil.showToast(baseEntity.msg ?? '');
        // }
      }
    }
  }

  static showBottomSheet(BuildContext context, Widget child) async {
    await showModalBottomSheet(
        context: context,
        isScrollControlled: true,
        backgroundColor: Colors.transparent,
        // barrierColor: Colors.transparent,
        builder: (ctx) => Column(
              children: [
                Expanded(
                    child: GestureDetector(
                  behavior: HitTestBehavior.opaque,
                  onTap: () {
                    Navigator.pop(context);
                  },
                )),
                Container(
                  // color: ,
                  // height: 15,
                  decoration: const BoxDecoration(
                      color: Color(0xff2B1248),
                      borderRadius: BorderRadius.only(
                          topLeft: Radius.circular(15),
                          topRight: Radius.circular(15))),
                  child: child,
                )
              ],
            ));
  }

  static List<String> giftListV2 = [
    'Lollipop',
    'Kiss',
    'Fireworks',
    'Lipstick',
    'Condoms',
    'DiamondRing',
    'SportsCar',
    'Aircraft'
  ];
  static showSvgaPlayerAnimation(BuildContext context,
      {String? resUrl, String? assetsName, VoidCallBack? voidCallBack}) {
    String? giftAss;
    String? giftUrl;

    if (assetsName != null) {
      if (giftListV2.contains(assetsName)) {
        giftAss = assetsName + '.svga';
      } else {
        giftUrl = resUrl;
      }
    }

    return showDialog(
        context: context,
        useSafeArea: false,
        builder: (builder) {
          return Container(
            color: Colors.transparent,
            child: UtilsLiveSvgaWidget(
              resUrl: giftUrl,
              assetsName: giftAss,
            ),
            // onTap: () {
            //   // Navigator.pop(context);
            // },
          );
        }).then((value) {
      if (voidCallBack != null) {
        voidCallBack();
      }
    });
  }

  static showCenterBalanceInsufficient(
    BuildContext context, {
    required VoidCallback voidCallback,
    bool barrierDismissible = true,
  }) {
    showDialog(
        barrierDismissible: barrierDismissible,
        context: context,
        builder: (ctx) {
          return Column(
            children: [
              Expanded(child: Container()),
              Container(
              width: 325.w,
              padding: EdgeInsets.all(15.w),
              decoration: BoxDecoration(
                  borderRadius: BorderRadius.circular(30), color: Colors.white),
              child: Column(
                children: [
                  Container(
                    margin: EdgeInsets.symmetric(vertical: 15.w),
                    child: UtilsLiveImage.getIconByPath(
                      'app_balance_Recharge',
                    ),
                  ),
                  SizedBox(
                    height: 5.w,
                  ),
                  const Text(
                    'Your balance is insufficient. Please recharge and try again.',
                    style: UtilsLiveTextStyle.pt16Grey999999,
                    textAlign: TextAlign.center,
                  ),
                  GestureDetector(
                    behavior: HitTestBehavior.opaque,
                    onTap: NavigatorUtils.debounce(() {
                      Navigator.pop(context);
                      voidCallback();
                      
                    }),
                    child: Container(
                      width: 294.w,
                      height: 50.w,
                      margin: EdgeInsets.only(top: 20.w),
                      alignment: Alignment.center,
                      decoration: const ShapeDecoration(
                          shape: StadiumBorder(),
                          gradient: LinearGradient(
                              colors: UtilsLiveColor.startColors)),
                      child: const Text(
                        'Recharge',
                        style: UtilsLiveTextStyle.pt20WhiteSemiBold,
                        textAlign: TextAlign.center,
                      ),
                    ),
                  )
                ],
              )),
               Expanded(child: Container()),
            ],
          );
        });
  }

  static showActionSheet(
    BuildContext context, {
    List<String>? rows,
    bool showCancel = true,
    ActionRowsSelect? selectAction,
    String cancelStr = 'Cancel',
  }) {
    showModalBottomSheet(
        context: context,
        backgroundColor: Colors.transparent,
        builder: (ctx) {
          final cellHeight = ((rows ?? []).length + 1) * 55 +
              20 +
              ScreenUtil().bottomBarHeight;
          return Container(
            width: 1.sw,
            margin: const EdgeInsets.symmetric(horizontal: 15),
            padding: EdgeInsets.only(bottom: ScreenUtil().bottomBarHeight),
            color: Colors.transparent,
            height: cellHeight + 1.0,
            child: Column(
              children: [
                Container(
                  decoration: BoxDecoration(
                      borderRadius: BorderRadius.circular(15),
                      color: Colors.white),
                  child: Column(
                    children: (rows ?? []).map((e) {
                     
                      return GestureDetector(
                        child: Container(
                          color: Colors.transparent,
                          width: 1.sw,
                          height: 55,
                          child: Center(
                            child: Text(e,
                                style: TextStyle(
                                    fontSize: 18,
                                    color: (e == "Block"
                                        ? const Color(0xFFF53838)
                                        : const Color(0xFF333333)))),
                          ),
                        ),
                        onTap: () {
                          if (selectAction != null) {
                            selectAction(rows!.indexOf(e), e);
                          }

                          if (Navigator.of(context).canPop()) {
                            Navigator.of(context).pop();
                          }
                        },
                      );
                    }).toList(),
                  ),
                ),
                GestureDetector(
                  child: Container(
                    decoration: BoxDecoration(
                        borderRadius: BorderRadius.circular(15),
                        color: Colors.white),
                    margin: const EdgeInsets.symmetric(vertical: 10),
                    width: 1.sw,
                    height: 55,
                    child: Center(
                      child: Text(cancelStr,
                          style: const TextStyle(
                              fontSize: 18, color: Color(0xFF999999))),
                    ),
                  ),
                  onTap: () {
                    if (Navigator.of(context).canPop()) {
                      Navigator.of(context).pop();
                    }
                  },
                )
              ],
            ),
          );
        });
  }
}
