import 'package:extended_image/extended_image.dart';
import 'package:flutter/material.dart';
import 'package:mmoo_live_room/Utils/utils_live_colors.dart';
import 'package:mmoo_live_room/Utils/utils_live_dlog.dart';

class UtilsLiveImage {
  static Widget getLoadWidget(String? url,
      {int urlWidth = 0,
      double? width,
      double? height,
      bool color = true,
      bool file = false,
      BoxFit fit = BoxFit.cover}) {
    if (url?.isEmpty == false) {
      if (file) {
        return ExtendedImage.file(
          File(url!),
          width: width,
          height: height,
          fit: fit,
          enableLoadState: true,
          loadStateChanged: ((ExtendedImageState state) {
            switch (state.extendedImageLoadState) {
              case LoadState.loading:
                if (state.loadingProgress == null) {
                  return UtilsLiveImage.getIconByPath(
                    "app_pic",
                  );
                }
                return Container(
                  color: color
                      ? UtilsLiveColor.hexToColor("#40285C")
                      : Colors.transparent,
                  child: Center(
                    child: CircularProgressIndicator(
                        valueColor: AlwaysStoppedAnimation<Color>(color
                            ? UtilsLiveColor.hexToColor("#251142")
                            : UtilsLiveColor.hexToColor("#362056")),
                        value: state.loadingProgress!.expectedTotalBytes != null
                            ? state.loadingProgress!.cumulativeBytesLoaded /
                                state.loadingProgress!.expectedTotalBytes!
                            : null),
                  ),
                );
              case LoadState.completed:
                return state.completedWidget;
              default:
                return UtilsLiveImage.getIconByPath(
                  "app_pic",
                );
            }
          }),
        );
      } else {
        return ExtendedImage.network(
          urlWidth == 0 ? url! : _compressImageUrl(url!, width: urlWidth),
          width: width,
          height: height,
          fit: fit,
          enableLoadState: true,
          handleLoadingProgress: true,
          loadStateChanged: ((ExtendedImageState state) {
            switch (state.extendedImageLoadState) {
              case LoadState.loading:
                if (state.loadingProgress == null) {
                  return UtilsLiveImage.getIconByPath(
                    "app_pic",
                  );
                }
                return Container(
                  color: color
                      ? UtilsLiveColor.hexToColor("#362056")
                      : Colors.transparent,
                  child: Center(
                    child: CircularProgressIndicator(
                        valueColor: AlwaysStoppedAnimation<Color>(color
                            ? UtilsLiveColor.hexToColor("#251142")
                            : UtilsLiveColor.hexToColor("#362056")),
                        value: state.loadingProgress!.expectedTotalBytes != null
                            ? state.loadingProgress!.cumulativeBytesLoaded /
                                state.loadingProgress!.expectedTotalBytes!
                            : null),
                  ),
                );
              case LoadState.completed:
                return state.completedWidget;
              default:
                return UtilsLiveImage.getIconByPath(
                  "app_pic_error",
                );
            }
          }),
        );
      }
    } else {
      return UtilsLiveImage.getIconByPath(
        "app_pic",
        width: width,
        height: height,
      );
    }
  }

  static String _compressImageUrl(String url, {int width = 0}) {
    try {
      if (url.startsWith('http') && width != 0) {
        if (url.endsWith('!user')) url = url.replaceAll('!user', '');
      }
      var spacing = url.contains('?') ? '&' : '?';
      return '$url${spacing}x-oss-process=image/resize,w_$width';
    } catch (e) {
      DLog(e);
    }
    return url;
  }

  static Image getIconByPath(String path,
      {String? package, double? width, double? height, BoxFit? fit}) {
    return Image.asset(
      // lib/assets/images/app_pic.png
      AssetImage(path.contains('assets')
              ? path
              : ('lib/assets/images/' + path + '.png'))
          .assetName,
      package: package ??'mmoo_live_room',
      fit: fit ?? BoxFit.cover,
      width: width,
      height: height,
      gaplessPlayback: true,
    );
  }
}
