import 'package:flutter/material.dart';
import 'package:flutter_screenutil/flutter_screenutil.dart';
import 'package:mmoo_live_room/Config/config_live_typedef.dart';
import 'package:mmoo_live_room/Utils/utils_live_colors.dart';
import 'package:mmoo_live_room/Utils/utils_live_image.dart';
import 'package:mmoo_live_room/Utils/utils_live_textStyle.dart';
import 'package:mmoo_live_room/generated/l10n.dart';

typedef VoidCallBack = void Function();
typedef ActionRowsSelect = void Function(int index, String title);

// showModalBottomSheet
class WidgetActionBtns {
  static showActionTwoBtns(
    BuildContext context, {
    String? leftTitle,
    String? rightTitle,
    VoidCallBack? leftPressed,
    VoidCallBack? rightPressed,
  }) {
    showDialog(
      context: context,
      useSafeArea: false,
      builder: (ctx) {
        return Center(
          child: WidgetActionTwoView(
            leftTitle: leftTitle,
            leftPressed: leftPressed,
            rightPressed: rightPressed,
            rightTitle: rightTitle,
          ),
        );
      },
    );
  }

  static Future bottomSheet(BuildContext context, Widget child) async {
    await showModalBottomSheet(
        context: context,
        isScrollControlled: true,
        backgroundColor: Colors.transparent,
        barrierColor: Colors.transparent,
        builder: (ctx) => Column(
              children: [
                Expanded(
                    child: GestureDetector(
                  behavior: HitTestBehavior.opaque,
                  onTap: () {
                    Navigator.pop(context);
                  },
                )),
                Container(
                  child: child,
                )
                // child
              ],
            ));
  }

  static Future showMimoLiveAlert(BuildContext context,
      {String? leftString,
      required VoidCallBack leftCallBack,
      String? rightString,
      required String infoString,
      VoidCallBack? rightCallBack,
      bool isLeftHighlight = false,
      String? titMessage}) {
    return showDialog(
        context: context,
        useSafeArea: false,
        builder: (ctx) {
          return Center(
              child: WidgetActionChooseView(
                  leftCallBack: leftCallBack,
                  rightString: rightString,
                  leftString: leftString,
                  infoString: infoString,
                  titMessage: titMessage,
                  isLeftHighlight: isLeftHighlight,
                  rightCallBack: rightCallBack));
        });
  }

  static showActionMoreBtns(BuildContext context, List<String> rows,
      {ActionRowsSelect? actionRowsSelect,
      AnimationComplete? animationComplete}) async {
    await showDialog(
      context: context,
      builder: (ctx) {
        return Column(
          children: [
            Expanded(child: Container()),
            WidgetActionMoresView(
              rows,
              actionRowsSelect: actionRowsSelect,
            ),
            Expanded(child: Container()),
          ],
        );
      },
    ).then((value) {
      if (animationComplete != null) {
        animationComplete();
      }
    });
  }
}

class WidgetActionTwoView extends StatelessWidget {
  final String? leftTitle;
  final String? rightTitle;
  final VoidCallBack? leftPressed;
  final VoidCallBack? rightPressed;
  // ignore: use_key_in_widget_constructors
  const WidgetActionTwoView(
      {this.leftTitle, this.rightTitle, this.leftPressed, this.rightPressed});
  @override
  Widget build(BuildContext context) {
    return Container(
        height: 204.w,
        margin: EdgeInsets.symmetric(horizontal: 20.w),
        decoration: BoxDecoration(
            borderRadius: BorderRadius.circular(20), color: Colors.white),
        child: Column(
          children: [
            Row(
              mainAxisAlignment: MainAxisAlignment.end,
              children: [
                GestureDetector(
                  child: Container(
                    width: 40,
                    height: 40,
                    color: Colors.transparent,
                    child: UtilsLiveImage.getIconByPath(
                      'tanchuang_btn_guanbi',

                    ),
                  ),
                  onTap: () {
                    Navigator.pop(context);
                  },
                )
              ],
            ),
            Row(
              mainAxisAlignment: MainAxisAlignment.spaceBetween,
              children: [
                GestureDetector(
                  child: Container(
                      width: 160.w,
                      height: 125.w,
                      color: Colors.transparent,
                      child: Center(
                        child: Text(
                          leftTitle ?? '',
                          style: UtilsLiveTextStyle.big2TextBlackBold,
                        ),
                      )),
                  onTap: () {
                    if (leftPressed != null) {
                      leftPressed!();
                    }
                    Navigator.pop(context);
                  },
                ),
                Container(
                  color: UtilsLiveColor.hexToColor('#EEEEEE'),
                  width: 2,
                  height: 125.w,
                ),
                GestureDetector(
                  child: Container(
                      width: 160.w,
                      height: 125.w,
                      color: Colors.transparent,
                      child: Center(
                        child: Text(
                          rightTitle ?? '',
                          style: UtilsLiveTextStyle.big2TextBlackBold,
                        ),
                      )),
                  onTap: () {
                    if (rightPressed != null) {
                      rightPressed!();
                    }
                    Navigator.pop(context);
                  },
                ),
              ],
            ),
          ],
        ));
  }
}

class WidgetActionChooseView extends StatelessWidget {
  final String? leftString;
  final String? rightString;
  final String infoString;
  final String? titMessage;
  final bool isLeftHighlight;
  final VoidCallBack leftCallBack;
  final VoidCallBack? rightCallBack;
  // ignore: use_key_in_widget_constructors
  const WidgetActionChooseView(
      {this.leftString,
      required this.leftCallBack,
      this.rightString,
      required this.infoString,
      this.isLeftHighlight = false,
      this.rightCallBack,
      this.titMessage});
  @override
  Widget build(BuildContext context) {
    return Container(
      height: 250,
      margin: const EdgeInsets.symmetric(horizontal: 20),
      decoration: BoxDecoration(
          borderRadius: BorderRadius.circular(20), color: Colors.white),
      child: Stack(
        children: [
          Positioned(
              right: 0,
              top: 0,
              child: GestureDetector(
                child: SizedBox(
                  width: 44,
                  height: 44,
                  child: UtilsLiveImage.getIconByPath(
                    'tanchuang_btn_guanbi',
                  ),
                ),
                onTap: () {
                  Navigator.pop(context);
                },
              )),
          Positioned(
              child: Container(
            margin: const EdgeInsets.symmetric(horizontal: 15),
            child: Column(
              mainAxisAlignment: MainAxisAlignment.spaceAround,
              children: [
                Container(
                  margin: const EdgeInsets.only(top: 22),
                  child: Text(
                    titMessage ?? S.current.Live_tirl,
                    style: const TextStyle(
                        color: Colors.black,
                        fontSize: 25,
                        fontWeight: FontWeight.bold,
                        decoration: TextDecoration.none),
                    // UtilsLiveTextStyle.big2TextBlackBold
                  ),
                ),
                Text(
                  infoString,
                  textAlign: TextAlign.center,
                  style: const TextStyle(
                      color: Colors.black,
                      fontSize: 16,
                      fontWeight: FontWeight.normal,
                      decoration: TextDecoration.none),
                ),
                Container(
                  // margin: EdgeInsets.symmetric(horizontal: 10),
                  margin:
                      const EdgeInsets.only(bottom: 32, left: 10, right: 10),
                  child: rightString == null
                      ? Row(
                          mainAxisAlignment: MainAxisAlignment.center,
                          children: [
                            GestureDetector(
                              child: Container(
                                width: 115,
                                height: 40,
                                decoration: BoxDecoration(
                                    color: const Color(0xFFFF77CC),
                                    borderRadius: BorderRadius.circular(20)),
                                child: Center(
                                  child: Text(
                                    leftString ?? S.current.Live_Close,
                                    style: const TextStyle(
                                        color: Colors.white,
                                        fontSize: 16,
                                        fontWeight: FontWeight.normal,
                                        decoration: TextDecoration.none),
                                  ),
                                ),
                              ),
                              onTap: () {
                                leftCallBack();
                                Navigator.pop(context);
                              },
                            ),
                          ],
                        )
                      : Row(
                          mainAxisAlignment: MainAxisAlignment.spaceBetween,
                          children: [
                            GestureDetector(
                              child: Container(
                                width: 115,
                                height: 40,
                                decoration: BoxDecoration(
                                    color: isLeftHighlight
                                        ? const Color(0xFFFF77CC)
                                        : const Color(0xFFF3F3F3),
                                    borderRadius: BorderRadius.circular(20)),
                                child: Center(
                                  child: Text(
                                    leftString ?? S.current.Live_Close,
                                    style: TextStyle(
                                        color: isLeftHighlight
                                            ? const Color(0xFFFFFFFF)
                                            : const Color(0xFF666666),
                                        fontSize: 16,
                                        fontWeight: FontWeight.normal,
                                        decoration: TextDecoration.none),
                                  ),
                                ),
                              ),
                              onTap: () {
                                leftCallBack();
                                Navigator.pop(context);
                              },
                            ),
                            Visibility(
                                visible: rightString != null,
                                child: GestureDetector(
                                  child: Container(
                                    width: 115,
                                    height: 40,
                                    decoration: BoxDecoration(
                                        color: (isLeftHighlight ||
                                                rightString == null)
                                            ? const Color(0xFFF3F3F3)
                                            : const Color(0xFFFF77CC),
                                        borderRadius:
                                            BorderRadius.circular(20)),
                                    child: Center(
                                      child: Text(
                                        rightString ?? '',
                                        style: TextStyle(
                                            color: (isLeftHighlight ||
                                                    rightString == null)
                                                ? const Color(0xFF666666)
                                                : const Color(0xFFFFFFFF),
                                            fontSize: 16,
                                            fontWeight: FontWeight.normal,
                                            decoration: TextDecoration.none),
                                      ),
                                    ),
                                  ),
                                  onTap: () {
                                    if (rightCallBack != null) {
                                      rightCallBack!();
                                    }

                                    Navigator.pop(context);
                                  },
                                ))
                          ],
                        ),
                )
              ],
            ),
          ))
        ],
      ),
    );
  }
}

class WidgetActionMoresView extends StatelessWidget {
  final List<String> rows;

  final ActionRowsSelect? actionRowsSelect;
  // ignore: use_key_in_widget_constructors
  const WidgetActionMoresView(this.rows, {this.actionRowsSelect});

  @override
  Widget build(BuildContext context) {
    return Container(
      margin: EdgeInsets.symmetric(horizontal: 20.w),
      padding: const EdgeInsets.all(15),
      decoration: BoxDecoration(
          borderRadius: BorderRadius.circular(20), color: Colors.white),
      child: Column(
        children: [
          Row(
            mainAxisAlignment: MainAxisAlignment.end,
            children: [
              GestureDetector(
                behavior: HitTestBehavior.opaque,
                child: Container(
                  width: 40,
                  height: 40,
                  color: Colors.transparent,
                  child: UtilsLiveImage.getIconByPath(
                    'tanchuang_btn_guanbi',

                  ),
                ),
                onTap: () {
                  Navigator.pop(context);
                },
              ),
            ],
          ),
          Column(
            children: [
              for (var i = 0; i < rows.length; i++)
                GestureDetector(
                  onTap: () {
                    if (actionRowsSelect != null) {
                      actionRowsSelect!(i, rows[i]);
                    }
                    Navigator.pop(context);
                  },
                  child: Container(
                    color: Colors.transparent,
                    height: 60.w,
                    child: Column(
                      children: [
                        Expanded(
                            child: Center(
                          child: Text(
                            rows[i],
                            style: UtilsLiveTextStyle.big2TextBlackBold,
                          ),
                        )),
                        Container(
                          color: UtilsLiveColor.hexToColor('#EEEEEE'),
                          height: rows.length == (i + 1) ? 0 : 1,
                        )
                      ],
                    ),
                  ),
                )
            ],
          )
        ],
      ),
    );
  }
}
