
import 'package:flutter/cupertino.dart';
import 'package:flutter/material.dart';
import 'package:flutter_screenutil/flutter_screenutil.dart';
import 'package:mmoo_base/entity/language_entity.dart';
import 'package:mmoo_live_room/Config/config_live_app.dart';
import 'package:mmoo_live_room/Provider/provider_live_user.dart';
import 'package:mmoo_live_room/Config/config_live_globalkey.dart';
import 'package:mmoo_live_room/Config/config_live_typedef.dart';
import 'package:mmoo_live_room/Utils/utils_live_alert.dart';
import 'package:mmoo_live_room/Utils/utils_live_image.dart';
import 'package:mmoo_live_room/Widget/widget_live_more_choose.dart';
import 'package:mmoo_live_room/Model/model_lastLive_entity.dart';
import 'package:mmoo_live_room/Utils/utils_live_colors.dart';
import 'package:mmoo_live_room/Utils/utils_live_textStyle.dart';
import 'package:mmoo_live_room/generated/l10n.dart';

typedef VoidModelCallback = Function(ModelLastLiveEntity liveEntity);
/// 房间资料编辑页面
class WidgetBeginLiveVideoInfo {
  static showVideoInfoView(BuildContext context,
      {required ClickCallBack clickCallBack,
      required ModelLastLiveEntity lastLiveEntity,
      AnimationComplete? animatComplete,
      final bool? isShowMicSwitch,
      required VoidModelCallback callback,
      bool isRoomEdit = false}) async {
    await showModalBottomSheet(
        context: context,
        isScrollControlled: true,
        backgroundColor: Colors.transparent,
        // barrierColor: Colors.transparent,
        builder: (context) {
          // return testView();
          return WidgetBeginLiveVideoView(
            ConfigLiveGlobalkey.videoViewKey,
            clickCallBack: clickCallBack,
            lastLiveEntity: lastLiveEntity,
            isShowMicSwitch: isShowMicSwitch ?? true,
            isRoomEdit: isRoomEdit,
            // isShowMicSwitch: isShowMicSwitch,
            callback: callback,
          );
        }).then((value) {
      if (animatComplete != null) {
        animatComplete();
      }
    });
  }
}


class WidgetBeginLiveVideoView extends StatefulWidget {
  final ClickCallBack clickCallBack;
  final ModelLastLiveEntity? lastLiveEntity;
  final bool isRoomEdit;
  final bool? isShowMicSwitch;
  final VoidModelCallback callback;

  WidgetBeginLiveVideoView(Key key,
      {required this.clickCallBack,
      this.lastLiveEntity,
      this.isShowMicSwitch,
      required this.callback,
      required this.isRoomEdit})
      : super(key: key);
  @override
  WidgetBeginLiveVideoViewState createState() =>
      WidgetBeginLiveVideoViewState();
}

class WidgetBeginLiveVideoViewState extends State<WidgetBeginLiveVideoView> {
  final TextEditingController _editingSignaController = TextEditingController();
  final FocusNode _editSignaFocusNode = FocusNode();

  final ScrollController _scrollController = ScrollController();
  // var _switchValue = false;
  var _switchMicValue = false;

  ModelLastLiveEntity? currentLiveEntity;
  @override
  Widget build(BuildContext context) {
    return Column(
      children: [
        Expanded(
          child: GestureDetector(
            behavior: HitTestBehavior.opaque,
            onTap: () {
              Navigator.pop(context);
            },
          ),
        ),
        GestureDetector(
          child: buildView(),
          onTap: () {
            // FocusScope.of(context).requestFocus();
            FocusScope.of(context).requestFocus(FocusNode());
          },
        )
      ],
    );
  }

  Widget buildView() {
    LanguageLists language = LanguageLists();
    language.value = "English";
    language.code = '01';
    ProviderLiveUser().userInfo.language?.forEach((element) {
      if (element.code == currentLiveEntity?.language) {
        language = element;
      }
    });

    return Container(
        height: 500.w,
        margin:
            EdgeInsets.only(bottom: MediaQuery.of(context).viewInsets.bottom),
        decoration: BoxDecoration(
            borderRadius: const BorderRadius.only(
                topRight: Radius.circular(30), topLeft: Radius.circular(30)),
            color: UtilsLiveColor.hexToColor('#2B1248')),
        child: Column(
          children: [
            Container(
              margin: EdgeInsets.symmetric(horizontal: 10.w),
              height: 60,
              child: Row(
                mainAxisAlignment: MainAxisAlignment.spaceBetween,
                children: [
                  SizedBox(
                    width: 40.w,
                    height: 40.w,
                  ),
                  Text(S.current.Live_Roomsettings,
                      style: UtilsLiveTextStyle.pt20WhiteSemiBold),
                  GestureDetector(
                    child: SizedBox(
                      width: 40.w,
                      height: 40.w,
                      child: UtilsLiveImage.getIconByPath(
                        'kaibo_icon_guanbitanchuang',
                        fit: BoxFit.none
                      ),
                    ),
                    onTap: () {
                      Navigator.pop(context);
                    },
                  )
                ],
              ),
            ),
            Expanded(
                child: SingleChildScrollView(
                    controller: _scrollController,
                    child: Container(
                      margin: EdgeInsets.symmetric(horizontal: 15.w),
                      child: Column(
                        children: [
                          GestureDetector(
                            onTap: () {
                              // widget.clickCallBack('chooselaguage', '');
                              UtilsLiveAlert.showBottomSheet(
                                  context,
                                  WidgetLiveMoreChoose(
                                    titStr: S.current.Live_Choosealanguage,
                                    rows:
                                        (ProviderLiveUser().userInfo.language ??
                                                    [])
                                                .isNotEmpty
                                            ? (ProviderLiveUser()
                                                    .userInfo
                                                    .language
                                                    ?.map((e) {
                                                  return e.value as String;
                                                }).toList() ??
                                                [])
                                            : (ConfigLiveApp.langList.map((e) {
                                                return e.value as String;
                                              }).toList()),
                                    chooseCallback: (index) {
                                      if (mounted) {
                                        setState(() {
                                          currentLiveEntity?.language =
                                              ProviderLiveUser()
                                                  .userInfo
                                                  .language?[index]
                                                  .code;
                                        });
                                      }
                                    },
                                  ));
                            },
                            child: buildCell(
                                S.current.Live_Begin_Language, language.value ?? "English"),
                          ),
                          Visibility(
                            visible: (widget.isShowMicSwitch ?? true) &&
                                widget.isRoomEdit == false,
                            // visible:  ,
                            child: buildMicSeatSwitchCell(),
                          ),
                          Visibility(
                              visible: _switchMicValue,
                              child: GestureDetector(
                                onTap: () {
                                  if (widget.isRoomEdit) {
                                    return;
                                  }
                                  UtilsLiveAlert.showBottomSheet(
                                      context,
                                      WidgetLiveMoreChoose(
                                        titStr:  S.current.Live_Begin_MicSeatPrice,
                                        rows: (currentLiveEntity?.voicePrice ??
                                                    [])
                                                .isEmpty
                                            ? ConfigLiveApp.LiveVoicePrices.map(
                                                (e) {
                                                return (e.toString() == '0')
                                                    ?  S.current.Live_Begin_Free
                                                    : S.current.Live_Begin_Coins(e) ;
                                              }).toList()
                                            : (currentLiveEntity?.voicePrice
                                                    ?.map((e) {
                                                  return (e.toString() == '0')
                                                      ? S.current.Live_Begin_Free
                                                      : S.current.Live_Begin_Coins(e);
                                                }).toList() ??
                                                []),
                                        chooseCallback: (index) {
                                          if (mounted) {
                                            setState(() {
                                              currentLiveEntity
                                                      ?.chooseVoicePrice =
                                                  (currentLiveEntity
                                                          ?.voicePrice?[index])
                                                      .toString();
                                            });
                                          }
                                        },
                                      ));
                                },
                                child: buildCell(
                                    S.current.Live_Begin_MicSeatPrice,
                                    (currentLiveEntity?.chooseVoicePrice == "0"
                                        ? S.current.Live_Begin_Free
                                        : S.current.Live_Begin_Coins(currentLiveEntity?.chooseVoicePrice ?? '') )),
                              )),
                          Visibility(
                            visible:
                                currentLiveEntity?.type == 1,
                            child: GestureDetector(
                                onTap: () {
                                  if (widget.isRoomEdit) {
                                    return;
                                  }
                                  UtilsLiveAlert.showBottomSheet(
                                      context,
                                      WidgetLiveMoreChoose(
                                        titStr: S.current.Live_Begin_VideoSeatPrice,
                                        rows: (currentLiveEntity?.videoPrice ??
                                                    [])
                                                .isEmpty
                                            ? ConfigLiveApp.LiveVideoPrices.map(
                                                (e) {
                                                return (e.toString() == '0')
                                                    ? S.current.Live_Begin_Free
                                                    : S.current.Live_Begin_Coins(e); 
                                              }).toList()
                                            : (currentLiveEntity?.videoPrice
                                                    ?.map((e) {
                                                  return (e.toString() == '0')
                                                      ? S.current.Live_Begin_Free
                                                      : S.current.Live_Begin_Coins(e);
                                                }).toList() ??
                                                []),
                                        chooseCallback: (index) {
                                          if (mounted) {
                                            setState(() {
                                              currentLiveEntity
                                                      ?.chooseVideoPrice =
                                                  (currentLiveEntity
                                                          ?.videoPrice?[index])
                                                      .toString();
                                            });
                                          }
                                        },
                                      ));
                                },
                                child: buildCell(
                                    S.current.Live_Begin_VideoSeatPrice,
                                    (currentLiveEntity?.chooseVideoPrice == "0"
                                        ? S.current.Live_Begin_Free
                                        : S.current.Live_Begin_Coins(currentLiveEntity?.chooseVideoPrice ?? '')))),
                          ),
                          Container(
                            height: 50.w,
                            // margin: EdgeInsets.only(bottom: 10.w),
                            alignment: Alignment.centerLeft,
                            child: const Text(
                              "Room announcement",
                              style: UtilsLiveTextStyle.pt18WhiteNormal,
                            ),
                          ),
                          buildBottomInput(),
                        ],
                      ),
                    ))),
            GestureDetector(
              child: Container(
                  margin: EdgeInsets.only(
                      top: 10.w,
                      bottom: 10.w + ScreenUtil().bottomBarHeight,
                      left: 35.w,
                      right: 35.w),
                  height: 50.w,
                  width: 305.w,
                  alignment: Alignment.center,
                  decoration: BoxDecoration(
                      gradient: const LinearGradient(
                          colors: UtilsLiveColor.startColors),
                      borderRadius: BorderRadius.circular(25.w)),
                  child: Text(
                    S.current.Live_Submit,
                    style: UtilsLiveTextStyle.pt20WhiteSemiBold,
                  )),
              onTap: () {
                if (currentLiveEntity != null) {
                  currentLiveEntity?.liveNotice = _editingSignaController.text;
                  widget.callback(currentLiveEntity!);
                }

                Navigator.pop(context);
              },
            )
          ],
        ));
  }

  Widget buildBottomInput() {
    return Container(
      height: 100.w,
      padding: EdgeInsets.symmetric(horizontal: 15.w, vertical: 5.w),
      decoration: BoxDecoration(
          borderRadius: BorderRadius.circular(20),
          color: UtilsLiveColor.hexToColor("#ffffff").withOpacity(0.1)),
      child: Column(
        children: [
          Expanded(
            child: TextField(
              maxLines: null,
              keyboardType: TextInputType.multiline,
              autofocus: false,
              onChanged: (text) {},
              maxLength: 1000,
              controller: _editingSignaController,
              focusNode: _editSignaFocusNode,
              textInputAction: TextInputAction.done,
              decoration: InputDecoration(
                  border: InputBorder.none,
                  counterText: "",
                  hintText: S.current.Live_Pleaseenterroomannouncement,
                  hintStyle:
                      TextStyle(color: UtilsLiveColor.hexToColor("#999999"))),
              style: TextStyle(
                  color: UtilsLiveColor.hexToColor("#cccccc"), fontSize: 14),
              onSubmitted: (text) {
                // currentLiveEntity?.liveNotice = text;
              },
            ),
          ),
        ],
      ),
    );
  }

  Widget buildCell(String title, String infoStr) {
    return Container(
      height: 50.w,
      color: Colors.transparent,
      child: Column(
        children: [
          Expanded(
              child: Row(
            mainAxisAlignment: MainAxisAlignment.spaceBetween,
            children: [
              Text(
                title,
                style: TextStyle(
                    fontSize: 18,
                    color: (widget.isRoomEdit && title != 'Language')
                        ? const Color(0xff999999)
                        : UtilsLiveColor.hexToColor("#FFFFFF"),
                    fontWeight: FontWeight.normal,
                    decoration: TextDecoration.none),
              ),
              Row(
                children: [
                  Text(
                    infoStr,
                    style: TextStyle(
                        fontSize: 18,
                        color: (widget.isRoomEdit && title != 'Language')
                            ? const Color(0xff999999)
                            : UtilsLiveColor.hexToColor("#FFFFFF"),
                        fontWeight: FontWeight.normal,
                        decoration: TextDecoration.none),
                  ),
                  Container(
                    padding: const EdgeInsets.only(left: 10),
                    child: widget.isRoomEdit
                        ? Container()
                        : UtilsLiveImage.getIconByPath(
                            'live_open_arrow',
                          ),
                  )
                ],
              )
            ],
          )),
          Container(
            height: 1,
            color: Colors.white.withAlpha(50),
          )
        ],
      ),
    );
  }

  Widget buildMicSeatSwitchCell() {
    return Column(
      crossAxisAlignment: CrossAxisAlignment.end,
      children: [
        SizedBox(
            height: 50.w,
            child: Row(
              mainAxisAlignment: MainAxisAlignment.spaceBetween,
              children: [
                const Text(
                  'Mic Seat',
                  style: UtilsLiveTextStyle.pt18WhiteNormal,
                ),
                CupertinoSwitch(
                  value: _switchMicValue,
                  trackColor:
                      UtilsLiveColor.hexToColor('#FFFFFF').withOpacity(0.1),
                  activeColor: UtilsLiveColor.hexToColor('#FB5C9A'),
                  // activeColor: UtilsLiveColor.hexToColor('#FB5C9A'),
                  onChanged: (value) {
                    setState(() {
                      currentLiveEntity?.micSeat = value ? '4' : '0';
                      _switchMicValue = value;
                    });
                  },
                )
              ],
            )),
        Container(
          height: 1,
          color: Colors.white.withAlpha(50),
        )
      ],
    );
  }

  updateLastLiveInfo(ModelLastLiveEntity newLastLiveEntity) {
    setState(() {
      currentLiveEntity = newLastLiveEntity;
    });
  }

  @override
  void initState() {
    super.initState();
    // widget.lastLiveEntity;
    currentLiveEntity = ModelLastLiveEntity()
        .fromJson((widget.lastLiveEntity ?? ModelLastLiveEntity()).toJson());
    _editingSignaController.text = currentLiveEntity?.liveNotice ?? '';
    if (int.parse((widget.lastLiveEntity?.micSeat ?? '0')) > 0) {
      _switchMicValue = true;
    }
    // _editingNameController.text = widget.lastLiveEntity?.title ?? "";
    // String s = 'vads';

    // var keyboardVisibilityController = KeyboardVisibilityController();
    // keyboardVisibilityController.onChange.listen((bool visible) {
    //   if (visible == false) {
    //     _editingSignaController.text = currentLiveEntity?.liveNotice ?? '';
    //   }
    //   //   if (_scrollController.hasClients) {
    //   //     Future.delayed(Duration(milliseconds: 50)).then((value) {
    //   //     _scrollController.animateTo(_scrollController.position.maxScrollExtent,
    //   //         duration: Duration(milliseconds: 300), curve: Curves.easeIn);
    //   //   });
    //   //   }
    // });
  }

  @override
  void dispose() {
    super.dispose();

    // _editingNameController.dispose();
    // _editPriceController.dispose();
    _editingSignaController.dispose();
    // _editNameFocusNode.dispose();
    // _editPriceFocusNode.dispose();
    _editSignaFocusNode.dispose();
  }

  @override
  void didUpdateWidget(WidgetBeginLiveVideoView oldWidget) {
    super.didUpdateWidget(oldWidget);
  }

  @override
  void didChangeDependencies() {
    super.didChangeDependencies();
  }
}
