import 'package:flutter/material.dart';
import 'package:flutter_screenutil/flutter_screenutil.dart';
import 'package:mmoo_live_room/Config/config_live_typedef.dart';
import 'package:mmoo_live_room/Utils/utils_live_colors.dart';
import 'package:mmoo_live_room/Utils/utils_live_image.dart';
import 'package:mmoo_live_room/Utils/utils_live_textStyle.dart';
import 'package:mmoo_live_room/generated/l10n.dart';

class WidgetLiveAlert {
  static showPrivateLiveAlert(BuildContext context,
      {required ClickCallBack clickCallBack, required int price}) async {
    await showDialog(
        context: context,
        builder: (btc) {
          return Center(
            child: WidgetPrivateLiveView(
              clickCallBack,
              price: price,
            ),
          );
        });
  }
}

class WidgetPrivateLiveView extends StatelessWidget {
  final ClickCallBack clickCallBack;
  final int price;
  // ignore: use_key_in_widget_constructors
  const WidgetPrivateLiveView(this.clickCallBack, {required this.price});
  @override
  Widget build(BuildContext context) {
    return Container(
      height: 350.w,
      margin: EdgeInsets.symmetric(horizontal: 20.w),
      decoration: BoxDecoration(
          borderRadius: BorderRadius.circular(20),
          gradient: const LinearGradient(
              colors: UtilsLiveColor.privateColors,
              begin: Alignment.topLeft,
              end: Alignment.bottomRight)),
      child: Column(
        children: [
          Container(
            margin: EdgeInsets.only(top: 40.w, bottom: 15.w),
            width: 80.w,
            height: 80.w,
            decoration: BoxDecoration(
                borderRadius: BorderRadius.circular(40.w),
                color: UtilsLiveColor.hexToColor('#FFFFFF'),
                border: Border.all(
                    color: UtilsLiveColor.hexToColor('#979797'), width: 0.5)),
            child: UtilsLiveImage.getIconByPath(
              'simizhibo_icon_simitou',
              
            ),
          ),
          SizedBox(
            height: 30.w,
            child: Center(
              child: Text(S.current.Live_privatelive,
                  style: UtilsLiveTextStyle.big3TextWhiteBold),
            ),
          ),
          Container(
            margin: EdgeInsets.only(top: 15.w),
            child: Row(
              mainAxisAlignment: MainAxisAlignment.center,
              children: [
                Container(
                  margin: const EdgeInsets.only(right: 10),
                  child: UtilsLiveImage.getIconByPath(
                    'zuanshi',
                    
                    width: 15.w,
                    height: 13.w,
                  ),
                ),
                Text(
                  price.toString(),
                  style: UtilsLiveTextStyle.pt15white,
                )
              ],
            ),
          ),
          GestureDetector(
            child: Container(
              width: 250.w,
              height: 50.w,
              margin: EdgeInsets.only(top: 29.w),
              decoration: BoxDecoration(
                  borderRadius: BorderRadius.circular(25.w),
                  gradient: const LinearGradient(
                      colors: UtilsLiveColor.startColors,
                      begin: Alignment.centerLeft,
                      end: Alignment.centerRight)),
              child: Center(
                child: Text(
                  S.current.Live_PayToWatch,
                  style: UtilsLiveTextStyle.pt20WhiteSemiBold,
                ),
              ),
            ),
            onTap: () {
              clickCallBack("", null);
            },
          ),
          Expanded(
              child: GestureDetector(
            child: Center(
                child: Text(
              S.current.Live_Exit,
              style: TextStyle(
                  fontSize: 16,
                  color: UtilsLiveColor.hexToColor("#999999"),
                  fontWeight: FontWeight.normal,
                  decoration: TextDecoration.underline,
                  decorationColor: UtilsLiveColor.hexToColor("#999999"),
                  decorationStyle: TextDecorationStyle.solid),
            )),
            onTap: () {
              Navigator.pop(context);
            },
          ))
        ],
      ),
    );
  }
}
