// ignore_for_file: use_key_in_widget_constructors

import 'package:flutter/material.dart';
import 'package:flutter_screenutil/flutter_screenutil.dart';
import 'package:mmoo_base/dao/dao_result.dart';
import 'package:mmoo_base/dao/main_dao.dart';
import 'package:mmoo_live_room/Config/config_live_methon.dart';
import 'package:mmoo_live_room/Config/config_live_typedef.dart';
import 'package:mmoo_live_room/Model/model_live_care_user_list_entity.dart';
import 'package:mmoo_live_room/Utils/utils_live_colors.dart';
import 'package:mmoo_live_room/generated/l10n.dart';
import 'package:mmoo_live_room/Model/model_live_info_entity.dart';
import 'package:mmoo_live_room/Utils/utils_live_textStyle.dart';
import 'package:mmoo_live_room/Utils/utils_live_image.dart';
import 'package:pull_to_refresh/pull_to_refresh.dart';

///直播间  拉黑列表
class WidgetLiveBlacklist {
  static showLiveUserList(BuildContext context,
      {required ClickCallBack clickCallBack,
      required ModelLiveInfoEntity infoEntity}) async {
    await showModalBottomSheet(
        isScrollControlled: true,
        backgroundColor: Colors.transparent,
        barrierColor: Colors.transparent,
        context: context,
        builder: (ctx) {
          return WidgetLiveBlacklistView(
              infoEntity: infoEntity, clickCallBack: clickCallBack);
        });
  }
}

class WidgetLiveBlacklistView extends StatefulWidget {
  final ClickCallBack clickCallBack;
  final ModelLiveInfoEntity infoEntity;
  const WidgetLiveBlacklistView(
      {required this.infoEntity, required this.clickCallBack});
  @override
  WidgetLiveBlacklistViewState createState() => WidgetLiveBlacklistViewState();
}

class WidgetLiveBlacklistViewState extends State<WidgetLiveBlacklistView> {
  final RefreshController _refreshController =
      RefreshController(initialRefresh: true);
  ModelLiveCareUserListEntity _blockUserListEntity =
      ModelLiveCareUserListEntity();

  @override
  Widget build(BuildContext context) {
    return Container(
        height: 400.w + ScreenUtil().bottomBarHeight,
        padding: EdgeInsets.symmetric(horizontal: 15.w),
        decoration: const BoxDecoration(
            color: Color(0xff2B1248),
            borderRadius: BorderRadius.only(
                topLeft: Radius.circular(30), topRight: Radius.circular(30))),
        child: Column(children: [
          SizedBox(
            height: 60,
            child: Row(
              mainAxisAlignment: MainAxisAlignment.spaceBetween,
              children: [
                const SizedBox(
                  width: 40,
                  height: 40,
                ),
                Text(
                  S.current
                      .Live_RoomBlocklist(_blockUserListEntity.userNum ?? ''),
                  style: const TextStyle(
                      color: Colors.white,
                      fontSize: 20,
                      fontWeight: FontWeight.bold),
                ),
                GestureDetector(
                  child: SizedBox(
                    width: 40,
                    height: 40,
                    child: UtilsLiveImage.getIconByPath(
                      'live_open_close',
                    ),
                  ),
                  onTap: () {
                    Navigator.pop(context);
                  },
                )
              ],
            ),
          ),
          Expanded(
              child: SmartRefresher(
            controller: _refreshController,
            enablePullDown: true,
            enablePullUp: true,
            onRefresh: _onRefresh,
            onLoading: _onLoading,
            child: ListView.separated(
              itemCount: _blockUserListEntity.users?.length ?? 0,
              separatorBuilder: (BuildContext context, int index) {
                return Container(
                  color: Colors.white.withOpacity(0.1),
                  height: 1,
                );
              },
              itemBuilder: (c, i) =>
                  buildApplyListView(_blockUserListEntity.users![i]),
            ),
          )),
        ]));
  }

  Widget buildApplyListView(ModelLiveCareUserListRows model) {
    return SizedBox(
      height: 70,
      // margin: EdgeInsets.symmetric(horizontal: 15.w, vertical: 13.w),
      child: Row(
        mainAxisAlignment: MainAxisAlignment.spaceBetween,
        children: [
          Row(
            children: [
              GestureDetector(
                child: ClipRRect(
                  borderRadius: BorderRadius.circular(25.w),
                  child: SizedBox(
                    width: 50.w,
                    height: 50.w,
                    child: UtilsLiveImage.getLoadWidget(model.headImage),
                  ),
                ),
                onTap: () {
                  widget.clickCallBack(
                      ConfigLiveMethon.liveClickUserInfo, model.userId);
                },
              ),
              Column(
                mainAxisAlignment: MainAxisAlignment.center,
                crossAxisAlignment: CrossAxisAlignment.start,
                children: [
                  Row(
                    children: [
                      Container(
                        padding: const EdgeInsets.symmetric(horizontal: 10),
                        constraints: BoxConstraints(maxWidth: 180.w),
                        child: Text(
                          model.nickname ?? '',
                          maxLines: 1,
                          overflow: TextOverflow.ellipsis,
                          style: TextStyle(
                              fontSize: 18,
                              color: UtilsLiveColor.hexToColor("#FFFFFF"),
                              fontWeight: FontWeight.bold,
                              wordSpacing: -1,
                              decoration: TextDecoration.none),
                        ),
                      ),
                    ],
                  ),
                  const SizedBox(
                    height: 3,
                  ),
                  Container(
                    height: 20,
                    margin: const EdgeInsets.only(left: 10),
                    padding: const EdgeInsets.symmetric(horizontal: 7),
                    decoration: BoxDecoration(
                        borderRadius: BorderRadius.circular(10),
                        color: model.isAnchor == 0
                            ? UtilsLiveColor.hexToColor("#FFFFFF")
                                .withOpacity(0.1)
                            : UtilsLiveColor.hexToColor('#EB6B00')),
                    child: Row(
                      children: [
                        Text(
                          model.isAnchor == 0 ? S.current.Live_GuestInfo : S.current.Live_Anchor,
                          style: const TextStyle(
                              color: Colors.white,
                              fontSize: 12,
                              fontWeight: FontWeight.normal,
                              decoration: TextDecoration.none),
                        )
                      ],
                    ),
                  )
                ],
              ),
            ],
          ),
          GestureDetector(
            child: Container(
              width: 90,
              height: 30,
              decoration: BoxDecoration(
                  borderRadius: BorderRadius.circular(15),
                  gradient: const LinearGradient(
                      colors: UtilsLiveColor.startColors,
                      begin: Alignment.centerLeft,
                      end: Alignment.centerRight)),
              child: Center(
                child: Text(
                  S.current.Live_Remove,
                  style: UtilsLiveTextStyle.middleTextWhite,
                ),
              ),
            ),
            onTap: () {
              cancelUserBlock(model);
            },
          )
        ],
      ),
    );
  }

  cancelUserBlock(ModelLiveCareUserListRows model) async {
    DataResult dataResult = await MainDao.livePostBlockUser(
        isCancelBlock: true,
        userId: model.userId ?? 0,
        roomId: widget.infoEntity.roomId ?? 0);

    if (dataResult.result && dataResult.data != null) {
      if (mounted) {
        setState(() {
          _blockUserListEntity.users!.remove(model);
        });
      }
    }
  }

  _onRefresh() async {
    _blockUserListEntity.num = 1;
    _refreshDataSource();
  }

  _refreshDataSource() async {
    DataResult dataResult = await MainDao.livePostBlockUserList(
        roomId: widget.infoEntity.roomId ?? 0,
        num: _blockUserListEntity.num ?? 1,
        size: 20);

    _refreshController.refreshCompleted();
    if (dataResult.result && dataResult.data != null) {
      ModelLiveCareUserListEntity listEntity =
          ModelLiveCareUserListEntity().fromJson(dataResult.data);
      if ((listEntity.users?.length ?? 0) < 20) {
        _refreshController.loadNoData();
      } else {
        _refreshController.loadComplete();
      }
      if (listEntity.num == 1) {
        _blockUserListEntity =
            ModelLiveCareUserListEntity().fromJson(dataResult.data);
      } else {
        _blockUserListEntity.users?.addAll(_blockUserListEntity.users ?? []);
      }
      if (mounted) {
        setState(() {});
      }
    } else {
      _refreshController.loadFailed();
    }
  }

  _onLoading() async {
    // if (widget.type == 0) {
    _blockUserListEntity.num = (_blockUserListEntity.num ?? 1) + 1;
    _refreshDataSource();
    // }
  }

  @override
  void initState() {
    _blockUserListEntity.num = 1;
    _blockUserListEntity.users = [];
    _blockUserListEntity.onlineNum = 0;
    super.initState();
  }

  @override
  void dispose() {
    super.dispose();
    _refreshController.dispose();
  }

  @override
  void didUpdateWidget(WidgetLiveBlacklistView oldWidget) {
    super.didUpdateWidget(oldWidget);
  }

  @override
  void didChangeDependencies() {
    super.didChangeDependencies();
  }
}
