// ignore_for_file: prefer_const_constructors_in_immutables

import 'dart:convert';

import 'package:flutter/gestures.dart';
import 'package:flutter/material.dart';
import 'package:flutter_screenutil/flutter_screenutil.dart';
import 'package:mmoo_live_room/Config/config_live_methon.dart';
import 'package:mmoo_live_room/Config/config_live_typedef.dart';
import 'package:mmoo_live_room/Config/config_live_socket.dart';
import 'package:mmoo_live_room/Model/model_rtm_message.dart';
import 'package:mmoo_live_room/Provider/provider_live_chat_messages.dart';
import 'package:mmoo_live_room/Provider/provider_live_info_entity.dart';
import 'package:mmoo_live_room/generated/l10n.dart';
import 'package:mmoo_live_room/Model/model_live_gift_list_entity.dart';
import 'package:mmoo_live_room/Utils/utils_live_colors.dart';
import 'package:provider/provider.dart';

///直播间  左下角消息列表
class WidgetLiveChatMessages extends StatefulWidget {
  final ClickCallBack clickCallBack;
  WidgetLiveChatMessages({Key? key, required this.clickCallBack}) : super(key: key);
  @override
  WidgetLiveChatMessagesState createState() => WidgetLiveChatMessagesState();
}

class WidgetLiveChatMessagesState extends State<WidgetLiveChatMessages> {
  final ScrollController _scrollController = ScrollController();
  @override
  Widget build(BuildContext context) {
    return MediaQuery.removePadding(
        removeTop: true,
        removeBottom: true,
        context: context,
        child: Container(
          // color: Colors.red,
          margin:
              EdgeInsets.only(top: 00.w, bottom: 0.w, left: 15.w, right: 130.w),
          child: Consumer<ProviderLiveChatMessage>(
              builder: (context, chatMessageProvider, child) {
            scrollAnimation();
            return ListView.builder(
                controller: _scrollController,
                itemCount: chatMessageProvider.rtmMessages.length,
                itemBuilder: (BuildContext context, int index) {
                  return Container(
                    margin: EdgeInsets.only(top: 4.w, bottom: 4.w),
                    child: Row(
                      children: [
                        Column(
                            children: [
                              Container(
                                constraints: BoxConstraints(maxWidth: 223.w),
                                padding: EdgeInsets.only(
                                    left: 10.w,
                                    right: 10.w,
                                    top: 10.w,
                                    bottom: 10.w),
                                decoration: BoxDecoration(
                                    borderRadius:const
                                        BorderRadius.all(Radius.circular(15)),
                                    color: const Color(UtilsLiveColor.color_back)
                                        .withOpacity(
                                            0.4)), //FBKColor.color_4c000000
                                child: getMessageType(
                                    chatMessageProvider.rtmMessages[index]),
                              ),
                            ],
                          ),
                        
                      ],
                    ),
                  );
                });
          }),
        ));
  }

  Widget getMessageType(ModelRtmMessage message) {
    if (message.typeMethod == ConfigLiveSocket.liveSocketConfig_sendText) {
      return getTextMessage(message);
    } else if (message.typeMethod == ConfigLiveSocket.liveSocketConfig_joinRoom) {
      return getJoinRoomMessage(message);
    } else if (message.typeMethod == ConfigLiveSocket.liveSocketConfig_sendGift) {
      return getSendGiftMessage(message);
    } else {
      return RichText(
        text: TextSpan(style: DefaultTextStyle.of(context).style, children: [
          TextSpan(
              text:
                  message.content,
              style: const TextStyle(color: Color(0xFFFFC72F), fontSize: 14)),
        ]),
      );
    }
  }

  Widget getJoinRoomMessage(ModelRtmMessage model) {
    return RichText(
      text: TextSpan(style: DefaultTextStyle.of(context).style, children: [
        WidgetSpan(
            child: Visibility(
              visible: ProviderLiveInfoEntity().infoEntity.userId.toString() ==
                      model.userId || model.isHost == '1',
          child: Container(
              height: 16,
              margin:const EdgeInsets.only(right: 5),
              width: 54,
              // padding: EdgeInsets.symmetric(horizontal: 7),
              alignment: Alignment.center,
              decoration:
                  BoxDecoration(borderRadius: BorderRadius.circular(8),
                  color: ProviderLiveInfoEntity().infoEntity.userId.toString() ==
                      model.userId ?const Color(0xffFB5C9A) :const Color(0xffEB6B00)
                  ),
              child: Text(ProviderLiveInfoEntity().infoEntity.userId.toString() ==
                      model.userId
                  ? S.current.Live_Owners
                  : S.current.Live_Anchor,
                  style:const TextStyle(
                    color: Colors.white,
                    fontWeight: FontWeight.bold,
                    fontSize: 12
                  ),
                  )),
        )),
        TextSpan(
            text: (model.name ?? '') + " " + S.current.Live_JoinRoom,
            recognizer: TapGestureRecognizer()
              ..onTap = () {
                widget.clickCallBack(ConfigLiveMethon.liveClickUserInfo,
                    int.parse((model.userId ?? '')));
              },
            style: const TextStyle(
                color: Colors.white, fontSize: 12)),
      ]),
    );
  }

  Widget getSendGiftMessage(ModelRtmMessage model) {
    
    ModelLiveGiftListGifts giftListGifts =
        ModelLiveGiftListGifts().fromJson(jsonDecode(model.content ?? ''));
    String nameStr = '';
    giftListGifts.giveGiftUserInfoList?.forEach((element) {
      if (nameStr.isEmpty) {
        nameStr = '‘ ' + S.current.Live_to + ' ' + (element.nickname ?? '');
      } else {
        nameStr = nameStr + ',' + (element.nickname ?? '');
      }
    });
    return RichText(
      text: TextSpan(style: DefaultTextStyle.of(context).style, children: [
        WidgetSpan(
            child: Visibility(
              visible: ProviderLiveInfoEntity().infoEntity.userId.toString() ==
                      model.userId || model.isHost == '1',
          child: Container(
              height: 16,
              margin:const  EdgeInsets.only(right: 5),
              width: 54,
              // padding: EdgeInsets.symmetric(horizontal: 7),
              alignment: Alignment.center,
              decoration:
                  BoxDecoration(borderRadius: BorderRadius.circular(8),
                  color: ProviderLiveInfoEntity().infoEntity.userId.toString() ==
                      model.userId ? const Color(0xffFB5C9A) : const Color(0xffEB6B00)
                  ),
              child: Text(ProviderLiveInfoEntity().infoEntity.userId.toString() ==
                      model.userId
                  ? S.current.Live_Owners
                  : S.current.Live_Anchor,
                  style:const  TextStyle(
                    color: Colors.white,
                    fontWeight: FontWeight.bold,
                    fontSize: 12
                  ),
                  )),
        )),
        TextSpan(
            text: model.name,
            recognizer: TapGestureRecognizer()
              ..onTap = () {
                widget.clickCallBack(ConfigLiveMethon.liveClickUserInfo,
                    int.parse((model.userId ?? '')));
              },
            style: const TextStyle(
                color: Colors.white, fontSize: 12)),
        TextSpan(
            text: '  ' +
                S.current.Live_give +
                '  ' +
                (giftListGifts.num ?? '') +
                ' ’',
            style: const TextStyle(
                color: Colors.white, fontSize: 12)),
        TextSpan(
            text: giftListGifts.name,
            style: const TextStyle(
                color: Colors.white, fontSize: 12)),
        TextSpan(
            text: nameStr,
            style: const TextStyle(
                color: Colors.white, fontSize: 12)),
      ]),
    );
  }

  Widget getTextMessage(ModelRtmMessage model) {
   
    return RichText(
      textAlign: TextAlign.start,
      text: TextSpan(style: DefaultTextStyle.of(context).style, children: [
        WidgetSpan(
            child: Visibility(
              visible: ProviderLiveInfoEntity().infoEntity.userId.toString() ==
                      model.userId || model.isHost == '1',
          child: Container(
              height: 16,
              margin:const  EdgeInsets.only(right: 5),
              width: 54,
              alignment: Alignment.center,
              decoration:
                  BoxDecoration(borderRadius: BorderRadius.circular(8),
                  color: ProviderLiveInfoEntity().infoEntity.userId.toString() ==
                      model.userId ? const Color(0xffFB5C9A) :const  Color(0xffEB6B00)
                  ),
              child: Text(ProviderLiveInfoEntity().infoEntity.userId.toString() ==
                      model.userId
                  ? S.current.Live_Owners
                  : S.current.Live_Anchor,
                  style: const TextStyle(
                    color: Colors.white,
                    fontWeight: FontWeight.bold,
                    fontSize: 12
                  ),
                  )),
        )),
        TextSpan(
            text: (model.name ?? '') + ":",
            recognizer: TapGestureRecognizer()
              ..onTap = () {
                widget.clickCallBack(ConfigLiveMethon.liveClickUserInfo,
                    int.parse((model.userId ?? '')));
              },
            style: const TextStyle(
                color: Color(0xff999999), fontSize: 14)),
        TextSpan(
            text:  (model.content ?? ''),
            style: const TextStyle(
                color: Color(UtilsLiveColor.color_white), fontSize: 14))
      ]),
    );
  }

  scrollAnimation() {
    if (_scrollController.hasClients) {
      Future.delayed(const Duration(milliseconds: 50)).then((value) {
        _scrollController.animateTo(_scrollController.position.maxScrollExtent,
            duration: const Duration(milliseconds: 300), curve: Curves.easeIn);
      });
    }
  }

  @override
  void initState() {

    super.initState();
  }

  @override
  void dispose() {
    _scrollController.dispose();
    super.dispose();
  }

  @override
  void didUpdateWidget(WidgetLiveChatMessages oldWidget) {
    super.didUpdateWidget(oldWidget);
  }

  @override
  void didChangeDependencies() {
    super.didChangeDependencies();
  }
}
