import 'dart:ui';

import 'package:flutter/material.dart';
import 'package:flutter_screenutil/flutter_screenutil.dart';
import 'package:mmoo_base/dao/dao_result.dart';
import 'package:mmoo_base/dao/main_dao.dart';
import 'package:mmoo_live_room/Config/config_live_methon.dart';
import 'package:mmoo_live_room/Config/config_live_typedef.dart';
import 'package:mmoo_live_room/Provider/provider_live_info_entity.dart';
import 'package:mmoo_live_room/Widget/widget_live_user_info.dart';
import 'package:mmoo_live_room/generated/l10n.dart';
import 'package:mmoo_live_room/Model/model_live_info_entity.dart';
import 'package:mmoo_live_room/Model/model_live_care_user_list_entity.dart';
import 'package:mmoo_live_room/Utils/utils_live_colors.dart';
import 'package:mmoo_live_room/Utils/utils_live_image.dart';
import 'package:pull_to_refresh/pull_to_refresh.dart';
/// 直播间  关注该直播的用户列表
class WidgetLiveFollowlist {
  static showLiveUserList(BuildContext context,
      {required ClickCallBack clickCallBack,
      required ModelLiveInfoEntity infoEntity}) async {
    await showModalBottomSheet(
        isScrollControlled: true,
        backgroundColor: Colors.transparent,
        // barrierColor: Colors.transparent,
        context: context,
        builder: (ctx) {
          return WidgetLiveFollowlistView(
              infoEntity: infoEntity, clickCallBack: clickCallBack);
        });
  }
}

class WidgetLiveFollowlistView extends StatefulWidget {
  final ClickCallBack clickCallBack;
  final ModelLiveInfoEntity infoEntity;
  // ignore: use_key_in_widget_constructors
  const WidgetLiveFollowlistView(
      {required this.infoEntity, required this.clickCallBack});

  @override
  WidgetLiveFollowlistViewState createState() =>
      WidgetLiveFollowlistViewState();
}

class WidgetLiveFollowlistViewState extends State<WidgetLiveFollowlistView> {
  final RefreshController _refreshController =
      RefreshController(initialRefresh: true);
  // List lists = [];
  ModelLiveCareUserListEntity _careUserListEntity =
      ModelLiveCareUserListEntity();

  @override
  Widget build(BuildContext context) {
    return Container(
      height: 400.w + ScreenUtil().bottomBarHeight,
      padding: EdgeInsets.symmetric(horizontal: 15.w),
      decoration: const BoxDecoration(
          color: Color(0xff2B1248),
          borderRadius: BorderRadius.only(
              topLeft: Radius.circular(30), topRight: Radius.circular(30))),
      child: Column(
        children: [
          SizedBox(
            height: 60,
            child: Row(
              mainAxisAlignment: MainAxisAlignment.spaceBetween,
              children: [
                GestureDetector(
                  child: const SizedBox(
                    width: 40,
                    height: 40,
                  ),
                  onTap: () {
                    // _refreshController.requestRefresh();
                  },
                ),
                Text(
                  S.current
                      .Live_Followers(_careUserListEntity.careUserNum ?? 0),
                  style: const TextStyle(
                      color: Colors.white,
                      fontSize: 20,
                      fontWeight: FontWeight.bold),
                ),
                GestureDetector(
                  child: SizedBox(
                    width: 40,
                    height: 40,
                    child: UtilsLiveImage.getIconByPath(
                      'live_open_close',
                    ),
                  ),
                  onTap: () {
                    Navigator.pop(context);
                  },
                )
              ],
            ),
          ),

          //   Consumer<ProviderLiveBottomState>(
          // builder: (context, unreadProvider, child) {
          //   return Container(
          //     child: Text(
          //       ''
          //       // Provider.of<ProviderLiveBottomState>(context).isMic.t
          //     ),
          //   );
          // }),
          Expanded(
              child: SmartRefresher(
                  controller: _refreshController,
                  enablePullDown: true,
                  enablePullUp: true,
                  onRefresh: _onRefresh,
                  onLoading: _onLoading,
                  child: ListView.builder(
                    itemCount: _careUserListEntity.userList?.length,
                    itemExtent: 70,
                    itemBuilder: (BuildContext context, int index) {
                      return InkWell(
                        child: buildApplyListView(
                            _careUserListEntity.userList![index]),
                        onTap: () {
                          widget.clickCallBack(ConfigLiveMethon.liveClickUserInfo,_careUserListEntity.userList![index].userId ??
                                      0);
                        },
                      );
                    },
                  ))),
        ],
      ),
    );
  }

  Widget buildApplyListView(ModelLiveCareUserListRows model) {
    return Row(
      mainAxisAlignment: MainAxisAlignment.spaceBetween,
      children: [
        Row(
          children: [
            SizedBox(
              width: 50,
              height: 50,
              child: Stack(
                children: [
                  SizedBox(
                    width: 50,
                    height: 50,
                    child: ClipRRect(
                      borderRadius: BorderRadius.circular(25),
                      child: UtilsLiveImage.getLoadWidget(model.headImage),
                      //  child: ,
                    ),
                  ),
                  Positioned(
                      bottom: 0,
                      right: 0,
                      child: Visibility(
                        visible: model.online == 1 || model.online == 2,
                        child: Container(
                          height: 10,
                          width: 10,
                          decoration: BoxDecoration(
                              borderRadius: BorderRadius.circular(5),
                              color: Color(model.online == 1
                                  ? UtilsLiveColor.color_online
                                  : model.online == 2
                                      ? UtilsLiveColor.color_busy
                                      : UtilsLiveColor.color_offline)),
                        ),
                      ))
                ],
              ),
            ),
            Column(
              mainAxisAlignment: MainAxisAlignment.center,
              crossAxisAlignment: CrossAxisAlignment.start,
              children: [
                Row(
                  children: [
                    Container(
                      padding: const EdgeInsets.symmetric(horizontal: 10),
                      constraints: BoxConstraints(maxWidth: 200.w),
                      child: Text(
                        model.nickname ?? '',
                        style: TextStyle(
                            fontSize: 18,
                            color: UtilsLiveColor.hexToColor("#FFFFFF"),
                            fontWeight: FontWeight.bold,
                            decoration: TextDecoration.none),
                      ),
                    ),
                  ],
                ),
                const SizedBox(
                  height: 3,
                ),
                Container(
                  height: 20,
                  margin: const EdgeInsets.only(left: 10),
                  padding: const EdgeInsets.symmetric(horizontal: 7),
                  decoration: BoxDecoration(
                      borderRadius: BorderRadius.circular(10),
                      color: model.userId ==
                              ProviderLiveInfoEntity().infoEntity.userId
                          ? const Color(0xffFB5C9A)
                          : model.isAnchor == 1
                              ? UtilsLiveColor.hexToColor('#EB6B00')
                              : UtilsLiveColor.hexToColor("#FFFFFF")
                                  .withOpacity(0.1)),
                  child: Row(
                    children: [
                      Text(
                        model.userId ==
                                ProviderLiveInfoEntity().infoEntity.userId
                            ? S.current.Live_Owners
                            : model.isAnchor == 1
                                ? S.current.Live_Anchor
                                : S.current.Live_GuestInfo,
                        style: const TextStyle(
                            color: Colors.white,
                            fontSize: 12,
                            fontWeight: FontWeight.normal,
                            decoration: TextDecoration.none),
                      )
                    ],
                  ),
                )
              ],
            ),
          ],
        ),
        Container(
          child: UtilsLiveImage.getIconByPath(
            'live_open_arrow',
          ),
        )
      ],
    );
  }

  _onRefresh() async {
    _careUserListEntity.num = 1;
    _refreshDataSource();
  }

  _refreshDataSource() async {
    DataResult dataResult = await MainDao.livePostCareUserList(
        roomId: widget.infoEntity.roomId ?? 0,
        num: _careUserListEntity.num ?? 1,
        size: 20);
    _refreshController.refreshCompleted();
    if (dataResult.result && dataResult.data != null) {
      ModelLiveCareUserListEntity listEntity =
          ModelLiveCareUserListEntity().fromJson(dataResult.data);
      // if (_careUserListEntity.num == 1) {
      //   _careUserListEntity.userList?.clear();
      // }
      if ((listEntity.userList?.length ?? 0) < 20) {
        _refreshController.loadNoData();
      } else {
        _refreshController.loadComplete();
      }
      if (_careUserListEntity.num == 1) {
        _careUserListEntity =
            ModelLiveCareUserListEntity().fromJson(dataResult.data);
      } else {
        _careUserListEntity.userList?.addAll(listEntity.userList ?? []);
      }
      if (mounted) {
        setState(() {});
      }
    } else {
      _refreshController.refreshFailed();
      _refreshController.loadFailed();
    }
  }

  _onLoading() async {
    _careUserListEntity.num = (_careUserListEntity.num ?? 1) + 1;
    _refreshDataSource();
    // if (widget.type == 0) {
    //   _applyListEntity.num = (_applyListEntity.num ?? 1) + 1;
    // }
  }

  @override
  void initState() {
    // _applyListEntity.num = 1;
    _careUserListEntity.userList = [];
    _careUserListEntity.num = 1;
    _careUserListEntity.careUserNum = 0;

    super.initState();
  }

  @override
  void dispose() {
    super.dispose();
    _refreshController.dispose();
  }

  @override
  void didUpdateWidget(WidgetLiveFollowlistView oldWidget) {
    super.didUpdateWidget(oldWidget);
  }

  @override
  void didChangeDependencies() {
    super.didChangeDependencies();
  }
}
