import 'dart:convert';

import 'package:flutter/material.dart';
import 'package:mmoo_live_room/Config/config_live_globalkey.dart';
import 'package:mmoo_live_room/Model/model_live_gift_list_entity.dart';
import 'package:mmoo_live_room/Model/model_rtm_message.dart';
import 'package:mmoo_live_room/Utils/utils_live_dlog.dart';
import 'package:mmoo_live_room/Utils/utils_live_image.dart';
import 'package:mmoo_live_room/generated/l10n.dart';

///直播间礼物  从左往右退出动画
class WidgetLiveGiftShow extends StatefulWidget {
  WidgetLiveGiftShow() : super(key: ConfigLiveGlobalkey.liveGiftShowKey);
  @override
  WidgetLiveGiftShowState createState() => WidgetLiveGiftShowState();
}

class WidgetLiveGiftShowState extends State<WidgetLiveGiftShow>
    with SingleTickerProviderStateMixin {
  final List<ModelRtmMessage> _animationData = [];
  late AnimationController _controller;
  ModelLiveGiftListGifts? _giftModel;
  ModelRtmMessage? _rtmModel;
  bool _visible = false;
  Animation<Offset>? _inAnimation;
  @override
  Widget build(BuildContext context) {
    return _inAnimation == null
        ? Container()
        : AnimatedOpacity(
            opacity: _visible ? 1.0 : 0.0,
            duration: const Duration(milliseconds: 1),
            child: SlideTransition(
                position: _inAnimation!,
                child: Container(
                  padding: const EdgeInsets.only(left: 10, right: 15),
                  // width: 215,
                  height: 60,
                  decoration: BoxDecoration(
                      color: Colors.black.withOpacity(0.4),
                      borderRadius: const BorderRadius.only(
                          topRight: Radius.circular(30),
                          bottomRight: Radius.circular(30))),
                  child: Row(
                    crossAxisAlignment: CrossAxisAlignment.center,
                    children: [
                      Container(
                        constraints: const BoxConstraints(maxWidth: 120),
                        child: Column(
                          crossAxisAlignment: CrossAxisAlignment.start,
                          mainAxisAlignment: MainAxisAlignment.center,
                          children: [
                            Text(
                              _rtmModel?.name ?? '',
                              textAlign: TextAlign.left,
                              style: const TextStyle(
                                  color: Colors.white,
                                  fontSize: 18,
                                  fontWeight: FontWeight.bold),
                            ),
                            const SizedBox(
                              height: 4,
                            ),
                            Text(
                              // _giftModel.giveGiftUserInfoList.map((e) => e.nickname ?? '').toList().to
                              // _giftModel.giveGiftUserInfoList
                              S.current.Live_Giveto(getGiftName(_giftModel)),
                              textAlign: TextAlign.left,
                              maxLines: 2,
                              overflow: TextOverflow.ellipsis,
                              style: TextStyle(
                                  color: Colors.white.withOpacity(0.8),
                                  fontSize: 14,
                                  fontWeight: FontWeight.bold),
                            ),
                          ],
                        ),
                      ),
                      Container(
                        margin: const EdgeInsets.symmetric(horizontal: 10),
                        child: UtilsLiveImage.getLoadWidget(_giftModel?.preUrl,
                            width: 60, height: 60),
                      ),
                      Text(
                        'x' + (_giftModel?.num ?? ''),
                        textAlign: TextAlign.left,
                        style: const TextStyle(
                            color: Color(0xffFB5C9A),
                            fontSize: 30,
                            fontWeight: FontWeight.bold),
                      ),
                    ],
                  ),
                )));
  }

  String getGiftName(ModelLiveGiftListGifts? _giftModel) {
    if (_giftModel == null || _giftModel.giveGiftUserInfoList == null) {
      return '';
    }
    String result = '';
    _giftModel.giveGiftUserInfoList?.forEach((e) => {
          if (result.isEmpty)
            result = (e.nickname ?? '')
          else
            result = '$result,${(e.nickname ?? '')}'
        });
    return result;
  }

  beginAnimation(ModelRtmMessage rtmModel) {
    DLog("beginAnimation");

    _animationData.add(rtmModel);

    if (_animationData.length == 1) {
      if (mounted) {
        setState(() {
          _rtmModel = _animationData.first;
          _visible = true;
          _giftModel = ModelLiveGiftListGifts()
              .fromJson(jsonDecode(_animationData.first.content ?? ''));
          _inAnimation =
              Tween(begin: const Offset(-1, 0), end: const Offset(0, 0))
                  .animate(_controller);
        });
      }
      _controller.forward();
    }
  }

  removeAnimationDataSource() {
    _animationData.removeAt(0);
    if (_animationData.isNotEmpty) {
      if (mounted) {
        setState(() {
          _rtmModel = _animationData.first;
          _giftModel = ModelLiveGiftListGifts()
              .fromJson(jsonDecode(_animationData.first.content ?? ''));
          _inAnimation =
              Tween(begin: const Offset(-1, 0), end: const Offset(0, 0))
                  .animate(_controller);
        });
      }
      _controller.forward();
    } else {
      if (mounted) {
        setState(() {
          _visible = false;
          _giftModel = null;
          _rtmModel = null;
        });
      }
    }
  }

  @override
  void initState() {
    _controller = AnimationController(
        duration: const Duration(milliseconds: 300), vsync: this);
    _controller.addStatusListener((status) {
      if (status == AnimationStatus.completed) {
        Future.delayed(const Duration(seconds: 3), () {
          _controller.reverse();
        });
      } else if (status == AnimationStatus.dismissed) {
        removeAnimationDataSource();
      }
    });
    if (mounted) {
      setState(() {
        _inAnimation =
            Tween(begin: const Offset(-1, 0), end: const Offset(0, 0))
                .animate(_controller);
      });
    }
    super.initState();
  }

  @override
  void dispose() {
    // TODO: implement dispose
    _controller.dispose();
    super.dispose();
  }

  @override
  void didUpdateWidget(WidgetLiveGiftShow oldWidget) {
    // TODO: implement didUpdateWidget
    super.didUpdateWidget(oldWidget);
  }

  @override
  void didChangeDependencies() {
    // TODO: implement didChangeDependencies
    super.didChangeDependencies();
  }
}
