import 'package:flutter/cupertino.dart';
import 'package:flutter/material.dart';
import 'package:flutter_screenutil/flutter_screenutil.dart';
import 'package:mmoo_base/dao/dao_result.dart';
import 'package:mmoo_base/dao/main_dao.dart';
import 'package:mmoo_base/entity/init_gift_entity.dart';
import 'package:mmoo_base/utils/common_utils.dart';
import 'package:mmoo_live_room/Config/config_live_socket.dart';
import 'package:mmoo_live_room/Config/config_live_app.dart';
import 'package:mmoo_live_room/Config/config_live_methon.dart';
import 'package:mmoo_live_room/Config/config_live_typedef.dart';
import 'package:mmoo_live_room/Model/model_live_send_gift_entity.dart';
import 'package:mmoo_live_room/Model/model_rtm_message.dart';
import 'package:mmoo_live_room/Provider/provider_live_user.dart';
import 'package:mmoo_live_room/Utils/utils_live.dart';
import 'package:mmoo_live_room/Utils/utils_live_alert.dart';
import 'package:mmoo_live_room/Utils/utils_live_colors.dart';
import 'package:mmoo_live_room/generated/l10n.dart';
import 'package:mmoo_live_room/Model/model_live_gift_list_entity.dart';
import 'package:mmoo_live_room/Model/model_live_info_entity.dart';
import 'package:mmoo_live_room/Utils/utils_live_dlog.dart';
import 'package:mmoo_live_room/Utils/utils_live_textStyle.dart';
import 'package:mmoo_live_room/Utils/utils_live_image.dart';
import 'package:mmoo_base/entity/base_entity.dart';
import 'package:provider/provider.dart';

///礼物列表
///
class WidgetLiveGiftList {
  static showGiftListView(BuildContext context,
      {required ClickCallBack clickCallBack,
      required ModelLiveInfoEntity infoEntity}) async {
    await showModalBottomSheet(
        context: context,
        isScrollControlled: true,
        backgroundColor: Colors.transparent,
        barrierColor: Colors.transparent,
        builder: (context) {
          return Column(
            children: [
              Expanded(
                  child: GestureDetector(
                behavior: HitTestBehavior.opaque,
                onTap: () {
                  Navigator.pop(context);
                },
              )),
              WidgetLiveGiftListView((methon, data) {
                clickCallBack(methon, data);
              }, infoEntity, context)
            ],
          );
        }).then((value) => {});
  }
}

class WidgetLiveGiftListView extends StatefulWidget {
  final ClickCallBack clickCallBack;
  final ModelLiveInfoEntity infoEntity;
  // ignore: use_key_in_widget_constructors
  final BuildContext buildContext;
  const WidgetLiveGiftListView(
      this.clickCallBack, this.infoEntity, this.buildContext);
  @override
  WidgetLiveGiftListViewState createState() =>
      // ignore: no_logic_in_create_state
      WidgetLiveGiftListViewState(clickCallBack, infoEntity);
}

class WidgetLiveGiftListViewState extends State<WidgetLiveGiftListView> {
  ClickCallBack clickCallBack;
  ModelLiveInfoEntity infoEntity;
  bool _switchValue = true;
  bool _showGiftCountOption = false;
  WidgetLiveGiftListViewState(this.clickCallBack, this.infoEntity);
  List<ModelLiveInfoPlaceList> placeLists = [];
  int giftNum = int.parse(ConfigLiveApp.giftNumList.first);
  Future? _future;
  ModelLiveGiftListEntity _giftListEntity = ModelLiveGiftListEntity();
  ModelLiveGiftListGifts? _chooseGifts;
  bool isRefresh = false;
  @override
  Widget build(BuildContext context) {
    placeLists = [];
    for (var model in infoEntity.videoPlaceList ?? []) {
      if (model.userId != null) {
        placeLists.add(model);
      }
    }
    for (var model in infoEntity.voicePlaceList ?? []) {
      if (model.userId != null) {
        placeLists.add(model);
      }
    }
    if (_switchValue) {
      for (var element in placeLists) {
        element.chooseGift = 1;
      }
    }

    return Container(
      decoration: BoxDecoration(
          color: Colors.black.withOpacity(0.8),
          borderRadius: const BorderRadius.only(
            topLeft: Radius.circular(30),
            topRight: Radius.circular(30),
          )),
      // height: 303.w + ScreenUtil().bottomBarHeight,
      child: FutureBuilder(
          future: _future,
          builder: (BuildContext context, AsyncSnapshot snapshot) {
            if (snapshot.connectionState == ConnectionState.done) {
              if (snapshot.hasError) {
                return Container();
              } else {
                return isRefresh
                    ? Center(child: ConfigLiveApp.showSpinkit())
                    : Stack(
                        children: [
                          Positioned(child: buildView()),
                          Positioned.fill(
                              child: Visibility(
                                  visible: _showGiftCountOption,
                                  child: GestureDetector(
                                    behavior: HitTestBehavior.opaque,
                                    onTap: () {
                                      if (mounted) {
                                        setState(() {
                                          _showGiftCountOption = false;
                                        });
                                      }
                                    },
                                    child: Container(
                                      margin: EdgeInsets.only(
                                        bottom:
                                            ScreenUtil().bottomBarHeight + 45.w,
                                        right: 75.w,
                                      ),
                                      child: Column(
                                        mainAxisAlignment:
                                            MainAxisAlignment.end,
                                        crossAxisAlignment:
                                            CrossAxisAlignment.end,
                                        children: [_getGiftCountOptionsView()],
                                      ),
                                    ),
                                  )))
                        ],
                      );
              }
            } else {
              return Center(child: ConfigLiveApp.showSpinkit());
            }
          }),
    );
  }

  Widget buildView() {
    return Column(
      children: [
        SizedBox(
            // margin: EdgeInsets.only(top: 5.w),
            height: 70.w,
            child: ListView.separated(
              separatorBuilder: (BuildContext context, int index) {
                return Container(
                  width: 20.w,
                );
              },
              scrollDirection: Axis.horizontal,
              padding: EdgeInsets.symmetric(horizontal: 15.w),
              itemCount: placeLists.length + 1,
              itemBuilder: (BuildContext context, int index) {
                return GestureDetector(
                  onTap: () {
                    if (index == 0) {
                      _switchValue = !_switchValue;
                      for (var element in placeLists) {
                        element.chooseGift = _switchValue ? 1 : 0;
                      }
                      if (mounted) {
                        setState(() {
                          // _switchValue = isAllChoose;
                        });
                      }
                    } else {
                      placeLists[index - 1].chooseGift =
                          placeLists[index - 1].chooseGift == 1 ? 0 : 1;
                      bool isAllChoose = true;
                      for (var element in placeLists) {
                        if (element.chooseGift == 0) {
                          isAllChoose = false;
                        }
                      }
                      if (mounted) {
                        setState(() {
                          _switchValue = isAllChoose;
                        });
                      }
                    }
                  },
                  child: Container(
                    width: 40.w,
                    height: 40.w,
                    margin: EdgeInsets.symmetric(vertical: 15.w),
                    child: Stack(
                      children: [
                        Positioned.fill(
                            // right: 0,
                            // left: 0,
                            child: Container(
                                width: 40.w,
                                height: 40.w,
                                decoration: BoxDecoration(
                                  border: Border.all(
                                      color: ((index == 0 && _switchValue) ||
                                              (index > 0 &&
                                                  placeLists[index - 1]
                                                          .chooseGift ==
                                                      1))
                                          ? UtilsLiveColor.hexToColor('#18D878')
                                          : Colors.transparent,
                                      width: 1),
                                  borderRadius: BorderRadius.circular(20.w),
                                ),
                                child: index == 0
                                    ? UtilsLiveImage.getIconByPath(
                                        'icon_live_all',
                                      )
                                    : ClipRRect(
                                        borderRadius:
                                            BorderRadius.circular(19.w),
                                        child: UtilsLiveImage.getLoadWidget(
                                            placeLists[index - 1].headImage,
                                            width: 38.w,
                                            height: 38.w),
                                      ))),
                        Positioned(
                            bottom: 0,
                            left: 0,
                            right: 0,
                            child: Row(
                              mainAxisAlignment: MainAxisAlignment.center,
                              children: [
                                Container(
                                  constraints: BoxConstraints(maxWidth: 40.w),
                                  padding:
                                      const EdgeInsets.symmetric(horizontal: 5),
                                  // width: 15,
                                  alignment: Alignment.center,
                                  height: 16,
                                  decoration: BoxDecoration(
                                      color: ((index == 0 && _switchValue) ||
                                              (index > 0 &&
                                                  placeLists[index - 1]
                                                          .chooseGift ==
                                                      1))
                                          ? UtilsLiveColor.hexToColor('#18D878')
                                          : UtilsLiveColor.hexToColor(
                                              '#4E455A'),
                                      borderRadius: BorderRadius.circular(8)),
                                  child: Text(
                                    index == 0 ? S.current.Live_ALL : (index).toString(),
                                    maxLines: 1,
                                    overflow: TextOverflow.ellipsis,
                                    style: const TextStyle(
                                        fontSize: 12,
                                        wordSpacing: -1,
                                        color: Colors.white,
                                        fontWeight: FontWeight.bold,
                                        decoration: TextDecoration.none),
                                  ),
                                )
                              ],
                            )),
                      ],
                    ),
                  ),
                );
              },
            )),
        Wrap(
            runSpacing: 15.w,
            spacing: 10.w,
            children: (_giftListEntity.gifts ?? []).map((e) {
              return GestureDetector(
                child: Container(
                  width: 80.w,
                  height: 110.w,
                  // color: Colors.red,
                  decoration: BoxDecoration(
                      borderRadius: BorderRadius.circular(5),
                      color: _chooseGifts == e
                          ? Colors.white.withOpacity(0.1)
                          : Colors.transparent),
                  child: Column(
                    mainAxisSize: MainAxisSize.min,
                    children: [
                      SizedBox(
                        height: 70.w,
                        width: 70.w,
                        child: UtilsLiveImage.getLoadWidget(e.preUrl),
                      ),
                      const SizedBox(
                        height: 2,
                      ),
                      Text(
                        e.name ?? '',
                        maxLines: 1,
                        style: TextStyle(
                            fontSize: ScreenUtil().setSp(14),
                            color: Colors.white,
                            wordSpacing: -1,
                            fontWeight: FontWeight.bold,
                            decoration: TextDecoration.none),
                        overflow: TextOverflow.ellipsis,
                      ),
                      const SizedBox(
                        height: 2,
                      ),
                      Text(
                        e.price ?? '',
                        maxLines: 1,
                        overflow: TextOverflow.ellipsis,
                        style: TextStyle(
                            fontSize: 12,
                            wordSpacing: -2,
                            color: UtilsLiveColor.hexToColor('#999999'),
                            fontWeight: FontWeight.normal,
                            decoration: TextDecoration.none),
                      ),
                    ],
                  ),
                ),
                onTap: () {
                  if (mounted) {
                    setState(() {
                      _chooseGifts = e;
                      // _showGiftCountOption = false;
                    });
                  }
                },
              );
            }).toList()),
        Container(
          // 底部帐户余额，送礼视图
          margin: EdgeInsets.only(
              left: 15.w,
              right: 15.w,
              top: 10.w,
              bottom: ScreenUtil().bottomBarHeight + 10.w),
          height: 35.w,
          // color: UtilsLiveColor.hexToColor("#2A2331"),
          child: _getBottomView(),
        )
      ],
    );
  }

  Widget _getBottomView() {
    return Row(
      mainAxisAlignment: MainAxisAlignment.spaceBetween,
      children: [
        _getAccountCoinView(),
        _getGiftCountAndSendButtonView(),
      ],
    );
  }

  Widget _getGiftCountOptionsView() {
    return Visibility(
      visible: _showGiftCountOption,
      child: Container(
          width: 60.w,
          height: 120.w,
          decoration: BoxDecoration(
            borderRadius: BorderRadius.circular(10),
            color: Colors.white,
          ),
          child: Wrap(
            children: ConfigLiveApp.giftNumList
                .map(
                  (e) => GestureDetector(
                      onTap: () {
                        if (mounted) {
                          setState(() {
                            giftNum = int.parse(e);
                            _showGiftCountOption = false;
                          });
                        }
                      },
                      behavior: HitTestBehavior.opaque,
                      child: Container(
                        width: 60.w,
                        height: 30.w,
                        alignment: Alignment.center,
                        color: Colors.transparent,
                        child: Text(
                          e,
                          style: const TextStyle(
                              fontSize: 14,
                              color: Color(0xFF333333),
                              fontWeight: FontWeight.bold,
                              decoration: TextDecoration.none),
                        ),
                      )),
                )
                .toList(),
          )),
    );
  }

  Widget _getGiftCountAndSendButtonView() {
    return Container(
      width: 122,
      height: 30,
      decoration: BoxDecoration(
          borderRadius: BorderRadius.circular(5),
          border: Border.all(
              width: 1, color: UtilsLiveColor.hexToColor("#FB5C9A"))),
      child: Row(
        mainAxisAlignment: MainAxisAlignment.spaceBetween,
        children: [
          GestureDetector(
            onTap: () {
              if (mounted) {
                setState(() {
                  _showGiftCountOption = true;
                });
              }
            },
            child: Container(
              width: 60,
              color: Colors.transparent,
              child: Center(
                  child: Row(
                // mainAxisSize: MainAxisSize.min,
                mainAxisAlignment: MainAxisAlignment.center,
                children: [
                  Visibility(
                      // visible: widget.showOptions,
                      child: Container(
                    margin: EdgeInsets.only(right: 5.w),
                    child: UtilsLiveImage.getIconByPath(
                      'icon_live_gift_quantity',
                    ),
                  )),
                  Text(
                    giftNum.toString(),
                    style: UtilsLiveTextStyle.pt16White,
                  ),
                ],
              )),
            ),
          ),
          GestureDetector(
            // behavior: HitTestBehavior.opaque,
            onTap: () {
              // _sendGift();
              getSendGiftToUser();
            },
            child: Container(
              width: 60,
              decoration: BoxDecoration(
                color: UtilsLiveColor.hexToColor("#FB5C9A"),
              ),
              child:  Center(
                child: Text(
                  S.current.Live_send,
                  style: UtilsLiveTextStyle.pt16WhiteSemiBold,
                ),
              ),
            ),
          )
        ],
      ),
    );
  }

  Container _getAccountCoinView() {
    return Container(
      alignment: Alignment.center,
      child: GestureDetector(
        onTap: () {
          widget.clickCallBack(ConfigLiveMethon.liveOpenRechargPage, '');
        },
        child: Row(
          children: [
            UtilsLiveImage.getIconByPath(
              'icon_live_gift_Diamond',
            ),
            const SizedBox(
              width: 8,
            ),
            Consumer<ProviderLiveUser>(builder: (context, userProvider, child) {
              return Text(
                // 'vsdf',
                (userProvider.userInfo.money ?? 0).toString(),
                style: UtilsLiveTextStyle.pt18WhiteNormal,
              );
            }),
            const SizedBox(
              width: 6,
            ),
            UtilsLiveImage.getIconByPath(
              'icon_live_gift_Recharge',
            )
          ],
        ),
      ),
    );
  }

  Future getGiftListDataSource() async {
    DataResult dataResult = await MainDao.initGift();

    if (dataResult.result && dataResult.data != null) {
      if (dataResult.data is InitGiftEntity) {
        InitGiftEntity giftEntity = dataResult.data as InitGiftEntity;
        dataResult.data = giftEntity.toJson();
      }
      _giftListEntity = ModelLiveGiftListEntity().fromJson(dataResult.data);
      return;
    } else {
      return Future.error('');
    }
  }

  getSendGiftToUser() async {
    if (_chooseGifts != null) {
      // ModelLiveGiftListGifts giftModel = _giftListEntity.gifts![chooseInt];
      List<int> userList = [];
      for (var element in placeLists) {
        if (element.chooseGift == 1) {
          userList.add(element.userId ?? 0);
        }
      }
      // Live_Diamondsbalanceisinsufficient

      if (userList.isEmpty) {
        CommonUtils.showToast(S.current.Live_giftPeople);
      } else {
        int needCoins =
            userList.length * int.parse(_chooseGifts?.price ?? '0') * giftNum;
        DLog(ProviderLiveUser().userInfo.money);
        if (needCoins > (ProviderLiveUser().userInfo.money ?? 0)) {
          UtilsLiveAlert.showCenterBalanceInsufficient(context,
              barrierDismissible: true, voidCallback: () {
            clickCallBack(ConfigLiveMethon.liveOpenRechargPage, null);
          });
        } else {
          // if (mounted) {
          //   setState(() {
          //     isRefresh = true;
          //   });
          // }
          DataResult dataResult = await MainDao.livePostSendGift(
              giftId: _chooseGifts?.id ?? 0,
              num: giftNum,
              roomId: widget.infoEntity.roomId ?? 0,
              userIdList: userList);

          if (dataResult.result && dataResult.data != null) {
            ModelLiveSendGiftEntity giftEntity =
                ModelLiveSendGiftEntity().fromJson(dataResult.data);
            setState(() {
              ProviderLiveUser().userInfo.money = giftEntity.money;
            });
            Map<String, dynamic> map = UtilsLive().rtmSendGiftMap(
                giveGiftUserInfoList: dataResult.data['giveGiftUserInfoList'],
                gifUrl: _chooseGifts?.gifUrl ?? '',
                id: _chooseGifts?.id ?? 0,
                name: _chooseGifts?.name ?? '',
                preUrl: _chooseGifts?.preUrl ?? '',
                num: giftNum.toString(),
                price: _chooseGifts?.price ?? '');
            // AgoraRtmManager.getInstance().sendLiveMessage(map);
            ModelRtmMessage rtmMessage = ModelRtmMessage.fromJson(map);
            widget.clickCallBack(
                ConfigLiveSocket.liveSocketConfig_sendGift, rtmMessage);
          } else {
            BaseEntity baseEntity = dataResult.data;
            if (baseEntity.code == '7507') {
              widget.clickCallBack(ConfigLiveMethon.liveOpenRechargPage, null);
            } else {
              UtilsLiveAlert.showDioTips(context, dataResult);
            }
          }
        }
      }
    } else {
      CommonUtils.showToast("Please choose gift");
    }
  }

  @override
  void initState() {
    // GiftRepository
    _giftListEntity.gifts = [];
    _future = getGiftListDataSource();
    // TODO: implement initState
    super.initState();
  }

  @override
  void dispose() {
    // TODO: implement dispose
    super.dispose();
  }

  @override
  void didUpdateWidget(WidgetLiveGiftListView oldWidget) {
    // TODO: implement didUpdateWidget
    super.didUpdateWidget(oldWidget);
  }

  @override
  void didChangeDependencies() {
    // TODO: implement didChangeDependencies
    super.didChangeDependencies();
  }
}
