import 'package:flutter/material.dart';
import 'package:flutter_screenutil/flutter_screenutil.dart';
import 'package:mmoo_base/dao/main_dao.dart';
import 'package:mmoo_live_room/Config/config_live_app.dart';
import 'package:mmoo_live_room/Config/config_live_methon.dart';
import 'package:mmoo_live_room/Config/config_live_typedef.dart';
import 'package:mmoo_live_room/Provider/provider_live_info_entity.dart';
import 'package:mmoo_live_room/Provider/provider_live_user.dart';
import 'package:mmoo_live_room/Utils/utils_live_colors.dart';
import 'package:mmoo_live_room/generated/l10n.dart';
import 'package:mmoo_live_room/Model/model_live_info_entity.dart';
import 'package:mmoo_live_room/Model/model_live_user_list_entity.dart';
import 'package:mmoo_live_room/Utils/utils_live_image.dart';
import 'package:pull_to_refresh/pull_to_refresh.dart';
///直播间用户列表
class WidgetLiveGuestList extends StatefulWidget {
  final ClickCallBack clickCallBack;
  final ModelLiveInfoEntity infoEntity;
  // ignore: use_key_in_widget_constructors
  const WidgetLiveGuestList(
      {required this.infoEntity, required this.clickCallBack});
  @override
  WidgetLiveGuestListState createState() => WidgetLiveGuestListState();
}

class WidgetLiveGuestListState extends State<WidgetLiveGuestList> {
  final RefreshController _refreshController =
      RefreshController(initialRefresh: true);

  ModelLiveUserListEntity _userlistEntity = ModelLiveUserListEntity();
  @override
  Widget build(BuildContext context) {
    return Container(
        height: 400.w + ScreenUtil().bottomBarHeight,
        padding: EdgeInsets.symmetric(horizontal: 15.w),
        decoration: const BoxDecoration(
            color: Color(0xff2B1248),
            borderRadius: BorderRadius.only(
                topLeft: Radius.circular(30), topRight: Radius.circular(30))),
        child: Column(children: [
          SizedBox(
            height: 60,
            child: Row(
              mainAxisAlignment: MainAxisAlignment.spaceBetween,
              children: [
                const SizedBox(
                  width: 40,
                  height: 40,
                ),
                Text(
                  S.current.Live_Guest(_userlistEntity.onlineNum ?? ''),
                  style: const TextStyle(
                      color: Colors.white,
                      fontSize: 20,
                      fontWeight: FontWeight.bold),
                ),
                GestureDetector(
                  child: SizedBox(
                    width: 40,
                    height: 40,
                    child: UtilsLiveImage.getIconByPath(
                      'live_open_close',
                    ),
                  ),
                  onTap: () {
                    Navigator.pop(context);
                  },
                )
              ],
            ),
          ),
          Expanded(
              child: SmartRefresher(
            controller: _refreshController,
            enablePullDown: true,
            enablePullUp: true,
            onRefresh: _onRefresh,
            onLoading: _onLoading,
            child: ListView.separated(
              itemCount: _userlistEntity.users?.length ?? 0,
              separatorBuilder: (BuildContext context, int index) {
                return Container(
                  color: Colors.white.withOpacity(0.1),
                  height: 1,
                );
              },
              itemBuilder: (c, i) => buildMemberList(_userlistEntity.users![i]),
            ),
          )),
        ]));
  }

  Widget buildMemberList(ModelLiveUserListUsers listModel) {
    return SizedBox(
      height: 70,
      // margin: EdgeInsets.symmetric(horizontal: 15.w, vertical: 13.w),
      child: Row(
        mainAxisAlignment: MainAxisAlignment.spaceBetween,
        children: [
          Row(
            children: [
              GestureDetector(
                child: ClipRRect(
                  borderRadius: BorderRadius.circular(25.w),
                  child: SizedBox(
                    width: 50.w,
                    height: 50.w,
                    child: UtilsLiveImage.getLoadWidget(listModel.headImage),
                  ),
                ),
                onTap: () {
                  widget.clickCallBack(
                      ConfigLiveMethon.liveClickUserInfo, listModel.userId);
                },
              ),
              Column(
                mainAxisAlignment: MainAxisAlignment.center,
                crossAxisAlignment: CrossAxisAlignment.start,
                children: [
                  Row(
                    children: [
                      Container(
                        padding: const EdgeInsets.symmetric(horizontal: 10),
                        constraints: BoxConstraints(maxWidth: 180.w),
                        child: Text(
                          listModel.nickname ?? '',
                          maxLines: 1,
                          overflow: TextOverflow.ellipsis,
                          style: TextStyle(
                              fontSize: 18,
                              color: UtilsLiveColor.hexToColor("#FFFFFF"),
                              fontWeight: FontWeight.bold,
                              wordSpacing: -1,
                              decoration: TextDecoration.none),
                        ),
                      ),
                    ],
                  ),
                  const SizedBox(
                    height: 3,
                  ),
                  Container(
                    height: 20,
                    margin: const EdgeInsets.only(left: 10),
                    padding: const EdgeInsets.symmetric(horizontal: 7),
                    decoration: BoxDecoration(
                        borderRadius: BorderRadius.circular(10),
                        color: listModel.isHost == 0
                            ? UtilsLiveColor.hexToColor("#FFFFFF")
                                .withOpacity(0.1)
                            : listModel.userId ==
                                    ProviderLiveInfoEntity().infoEntity.userId
                                ? const Color(0xffFB5C9A)
                                : UtilsLiveColor.hexToColor('#EB6B00')),
                    // Color(0xffFB5C9A)
                    child: Row(
                      children: [
                        Text(
                          listModel.isHost == 0
                              ? S.current.Live_GuestInfo
                              : listModel.userId ==
                                      ProviderLiveInfoEntity().infoEntity.userId
                                  ? S.current.Live_Owners
                                  : S.current.Live_Anchor,
                          style: const TextStyle(
                              color: Colors.white,
                              fontSize: 12,
                              fontWeight: FontWeight.normal,
                              decoration: TextDecoration.none),
                        )
                      ],
                    ),
                  )
                ],
              ),
            ],
          ),
          Visibility(
              visible: ProviderLiveUser().userInfo.isHost == '1'
                  ? listModel.isHost == 0
                  : listModel.isHost != 0,
              child: Row(
                children: [
                  buildMessageBtn(listModel),
                  SizedBox(
                    width: 10.w,
                  ),
                  Visibility(
                      visible: ConfigLiveApp.gui,
                      child: buildVideoBtn(listModel))
                ],
              ))
        ],
      ),
    );
  }

  Widget buildVideoBtn(ModelLiveUserListUsers listModel) {
    return GestureDetector(
      behavior: HitTestBehavior.opaque,
      onTap: () async {
        widget.clickCallBack(
            ConfigLiveMethon.liveUserCallVideo, listModel.userId.toString());
      },
      child: UtilsLiveImage.getIconByPath(
        'icon_live_room_videocall',
      ),
    );
  }

  Widget buildMessageBtn(ModelLiveUserListUsers listModel) {
    return GestureDetector(
      behavior: HitTestBehavior.opaque,
      onTap: () async {
        widget.clickCallBack(
            ConfigLiveMethon.liveUserIMChat, listModel.userId.toString());
      },
      child: UtilsLiveImage.getIconByPath(
        'icon_live_room_messagecall',
      ),
    );
  }

  void _onRefresh() async {
    _userlistEntity.num = 1;
    refreshDataSource();
  }

  void refreshDataSource() async {
    final res = await MainDao.livePostRoomUserList(
        roomId: widget.infoEntity.roomId ?? 0, num: _userlistEntity.num ?? 1);
    _refreshController.refreshCompleted();

    if (res.result && res.data != null) {
      ModelLiveUserListEntity entity =
          ModelLiveUserListEntity().fromJson(res.data);

      if ((entity.users?.length ?? 0) < 20) {
        _refreshController.loadNoData();
      } else {
        _refreshController.loadComplete();
      }
      if (entity.num == 1) {
        _userlistEntity = ModelLiveUserListEntity().fromJson(res.data);
      } else {
        _userlistEntity.users?.addAll(entity.users ?? []);
      }
      widget.clickCallBack(
          ConfigLiveMethon.liveupdataOnlineNum, _userlistEntity.onlineNum);
      // liveupdataOnlineNum
      if (mounted) {
        setState(() {});
      }
    } else {
      _refreshController.refreshFailed();
      _refreshController.loadFailed();
    }
  }

  void _onLoading() async {
    _userlistEntity.num = (_userlistEntity.num ?? 1) + 1;
    refreshDataSource();
  }

  @override
  void initState() {
    _userlistEntity.users = [];
    _userlistEntity.onlineNum = 0;
    super.initState();
  }

  @override
  void dispose() {
    super.dispose();
  }

  @override
  void didUpdateWidget(WidgetLiveGuestList oldWidget) {
    super.didUpdateWidget(oldWidget);
  }

  @override
  void didChangeDependencies() {
    super.didChangeDependencies();
  }
}
