import 'package:flutter/material.dart';
import 'package:flutter/services.dart';
import 'package:flutter_screenutil/flutter_screenutil.dart';
import 'package:mmoo_base/utils/common_utils.dart';
import 'package:mmoo_live_room/Config/config_live_globalkey.dart';
import 'package:mmoo_live_room/Config/config_live_methon.dart';
import 'package:mmoo_live_room/Config/config_live_typedef.dart';
import 'package:mmoo_live_room/Provider/provider_live_im_unread.dart';
import 'package:mmoo_live_room/Provider/provider_live_user.dart';
import 'package:mmoo_live_room/Utils/utils_live_image.dart';
import 'package:mmoo_live_room/generated/l10n.dart';
import 'package:mmoo_live_room/Utils/utils_live_colors.dart';
import 'package:provider/provider.dart';

///直播间  底部输入框
class WidgetLiveInputWhite extends StatefulWidget {
  // final FocusNode? editFocusNode;
  final ClickCallBack clickCallBack;
  // final AnimatComplete animatComplete
  WidgetLiveInputWhite({ required this.clickCallBack})
      : super(key: ConfigLiveGlobalkey.inputWhiteViewKey);
  @override
  WidgetLiveInputWhiteState createState() => WidgetLiveInputWhiteState();
}

class WidgetLiveInputWhiteState extends State<WidgetLiveInputWhite> {
  TextEditingController editingController = TextEditingController();
  FocusNode editFocusNode = FocusNode();
  bool _isInput = false;
  @override
  Widget build(BuildContext context) {
    return Consumer<ProviderLiveUser>(builder: (context, userProvider, child) {
      return buildView(userProvider);
    });
  }

  Widget buildView(ProviderLiveUser userProvider) {
    return Container(
      padding:
          EdgeInsets.only(left: 10.w, right: 10.w, top: 10.w, bottom: 10.w),
      color: UtilsLiveColor.hexToColor('#2B1248'),
      child: Row(
        mainAxisAlignment: MainAxisAlignment.spaceBetween,
        children: [
          GestureDetector(
            onTap: () {
              widget.clickCallBack(ConfigLiveMethon.liveOpenMessageListPage, '');
              // Navigator.pop(context);
              FocusScope.of(context).requestFocus(FocusNode());
            },
            child: SizedBox(
              width: 40.w,
              height: 40.w,
              child: Stack(
                children: [
                  UtilsLiveImage.getIconByPath(
                    'icon_live_input_message',
                    
                  ),
                  Positioned(
                      right: 0,
                      child: Consumer<ProviderLiveImUnRead>(
                          builder: (_, unreadProvider, __) {
                        return Visibility(
                          child: Container(
                              width: 18.w,
                              height: 18.w,
                              decoration: BoxDecoration(
                                  color: UtilsLiveColor.hexToColor('#F53838'),
                                  borderRadius: BorderRadius.circular(9.w)),
                              child: Center(
                                child: Text(
                                  unreadProvider.unReadNum < 100
                                      ? unreadProvider.unReadNum.toString()
                                      : "99",
                                  style: TextStyle(
                                    color: UtilsLiveColor.hexToColor(
                                      '#FFFFFF',
                                    ),
                                    fontSize: 14,
                                  ),
                                ),
                              )),
                          visible: unreadProvider.unReadNum > 0,
                        );
                      }))
                ],
              ),
            ),
          ),
  // _getTextFieldView(),
          Container(
            width: 235.w,
            constraints:const BoxConstraints(
              maxHeight: 80,
              minHeight: 40,
            ),
            decoration: BoxDecoration(
                color: const Color(UtilsLiveColor.color_white).withAlpha(25),
                borderRadius: const BorderRadius.all(Radius.circular(20))),
            // padding: EdgeInsets.only(left: 16, right: 16),
            child: TextField(
              maxLines: null,
              style:
                  TextStyle(color: UtilsLiveColor.hexToColor('#FFFFFF'), fontSize: 14),
              keyboardType: TextInputType.multiline,
              autofocus: false,
              controller: editingController,
              focusNode: editFocusNode,
              textInputAction: TextInputAction.done,
              maxLength: 200,
              onChanged: (text) {
                if (text.isNotEmpty) {
                  if (_isInput == false) {
                    if (mounted) {
                      setState(() {
                        _isInput = true;
                      });
                    }
                  }
                } else {
                  if (_isInput == true) {
                    if (mounted) {
                      setState(() {
                        _isInput = false;
                      });
                    }
                  }
                }
              },
              decoration: InputDecoration(
                contentPadding: const EdgeInsets.only(left: 15, top: 8, bottom: 8, right: 15),
                // contentPadding:
              // EdgeInsets.only(left: 15, top: 8, bottom: 8, right: 15)),
                  hintText:  S.current.Live_SaySomething,
                  border: InputBorder.none,
                  counterText: "",
                  hintStyle: TextStyle(
                      color: UtilsLiveColor.hexToColor('#8D8D8D'), fontSize: 14)),
              onSubmitted: (text) {},
            ),
          ),
          GestureDetector(
            child: SizedBox(
              width: 50.w,
              height: 50.w,
              child: UtilsLiveImage.getIconByPath(
                _isInput
                    ? 'icon_live_input_send'
                    : 'icon_live_input_no_send',
              ),
            ),
            onTap: () {
              if (userProvider.chat == 1) {
                if (_isInput && editingController.text.isNotEmpty) {
                  String message = editingController.text;
                  widget.clickCallBack(
                      ConfigLiveMethon.liveInputSendMessage, message);
                }
              } else {
                CommonUtils.showToast(S.current.Live_youforbade);
                if (mounted) {
                  setState(() {
                    _isInput = false;
                  });
                }
              }
            },
          )
        ],
      ),
    );
  }
  sendMessageSuccess() {
    editingController.text = '';
    FocusScope.of(context).requestFocus(FocusNode());
  }

  openKeyboard() {
    editFocusNode.requestFocus();
  }

  @override
  void initState() {
    if (editingController.text.isNotEmpty) {
      _isInput = true;
    }
    super.initState();
  }

  @override
  void dispose() {
    editingController.dispose();
    editFocusNode.dispose();

    super.dispose();
  }

  @override
  void didUpdateWidget(WidgetLiveInputWhite oldWidget) {
    super.didUpdateWidget(oldWidget);
  }

  @override
  void didChangeDependencies() {
    super.didChangeDependencies();
  }
}
