import 'package:flutter/material.dart';
import 'package:flutter_screenutil/flutter_screenutil.dart';
import 'package:mmoo_live_room/Config/config_live_methon.dart';
import 'package:mmoo_live_room/Config/config_live_typedef.dart';
import 'package:mmoo_live_room/Config/config_live_app.dart';
import 'package:mmoo_live_room/Provider/provider_live_info_entity.dart';
import 'package:mmoo_live_room/Model/model_live_info_entity.dart';
import 'package:mmoo_live_room/Utils/utils_live_colors.dart';
import 'package:mmoo_live_room/Utils/utils_live_textStyle.dart';
import 'package:mmoo_live_room/Utils/utils_live_image.dart';
import 'package:provider/provider.dart';
///直播间 头部view
class WidgetLiveHeader extends StatefulWidget {
  final double height;

  final ClickCallBack clickCallBack;
  // ignore: use_key_in_widget_constructors
  const WidgetLiveHeader(
      {this.height = 40,
      required this.clickCallBack});
  @override
  WidgetLiveHeaderState createState() => WidgetLiveHeaderState();
}

class WidgetLiveHeaderState extends State<WidgetLiveHeader> {

  @override
  Widget build(BuildContext context) {
    return Consumer<ProviderLiveInfoEntity>(
        builder: (context, infoEntityProvider, child) {
      return buildView(infoEntityProvider.infoEntity);
    });
  }

  Widget buildView(ModelLiveInfoEntity infoEntity) {
    return Container(
      decoration: ShapeDecoration(
        shape:const StadiumBorder(),
          color: const Color(UtilsLiveColor.color_back).withOpacity(0.2),
          ),
      height: widget.height,
      padding: const EdgeInsets.symmetric(horizontal: 2),
      child: Row(
        children: [
          GestureDetector(
            child:  ClipRRect(
                borderRadius: BorderRadius.circular(18),
                child: SizedBox(
                  width: 36,
                  height: 36,
                  // color: const Color(0xff000000),
                  child: UtilsLiveImage.getLoadWidget(infoEntity.cover ?? '',
                      urlWidth: ConfigLiveApp.PIC_WIDTH_HEAD),
                ),
              
            ),
            onTap: () {
              widget.clickCallBack(
                  ConfigLiveMethon.liveRoomInformation, null);
            },
          ),
          Container(
            margin: EdgeInsets.symmetric(horizontal: 6.w),
                  constraints: BoxConstraints(maxWidth: 140.w),
                  child: Text(
                    infoEntity.title ?? '',
                    overflow: TextOverflow.ellipsis,
                    style: UtilsLiveTextStyle.pt16WhiteSemiBold,
                  ),
                ),
          GestureDetector(
            child: SizedBox(
                width: 40.w,
                height: 40.w,
                child: UtilsLiveImage.getIconByPath(
                  infoEntity.follow == 0
                      ? 'icon_live_follow_room'
                      : 'icon_live_unfollow_room',
                )),
            onTap: () {
              widget.clickCallBack(ConfigLiveMethon.liveHeaderFollow,
                  infoEntity.follow == 0 ? true : false);
            },
          )
        ],
      ),
    );
  }

  @override
  void initState() {

    super.initState();
  }

  @override
  void dispose() {

    super.dispose();
  }

  @override
  void didUpdateWidget(WidgetLiveHeader oldWidget) {

    super.didUpdateWidget(oldWidget);
  }

  @override
  void didChangeDependencies() {
    super.didChangeDependencies();
  }
}
