import 'package:flutter/material.dart';
import 'package:flutter_screenutil/flutter_screenutil.dart';
import 'package:mmoo_base/dao/dao_result.dart';
import 'package:mmoo_base/dao/main_dao.dart';
import 'package:mmoo_base/utils/common_utils.dart';
import 'package:mmoo_country_pickers/mmoo_country_pickers.dart';
import 'package:mmoo_live_room/Config/config_live_methon.dart';
import 'package:mmoo_live_room/Config/config_live_typedef.dart';
import 'package:mmoo_live_room/Model/model_live_user_info_entity.dart';
import 'package:mmoo_live_room/Provider/provider_live_info_entity.dart';
import 'package:mmoo_live_room/Utils/utils_live.dart';
import 'package:mmoo_live_room/Utils/utils_live_alert.dart';
import 'package:mmoo_live_room/Utils/utils_live_colors.dart';
import 'package:mmoo_live_room/Widget/widget_action_btns.dart';
import 'package:mmoo_live_room/Widget/widget_live_invite_placelist.dart';
import 'package:mmoo_live_room/generated/l10n.dart';
import 'package:mmoo_live_room/Model/model_live_info_entity.dart';
import 'package:mmoo_live_room/Utils/utils_live_textStyle.dart';
import 'package:mmoo_live_room/Utils/utils_live_image.dart';

///直播间  用户详情页面
class WidgetLiveUserInfo {
  static showUserInfoView(BuildContext context,
      {required ClickCallBack clickCallBack,
      required int userId,
      required ModelLiveInfoEntity infoEntity}) async {
    await showModalBottomSheet(
        context: context,
        isScrollControlled: true,
        backgroundColor: Colors.transparent,
        barrierColor: Colors.transparent,
        builder: (context) {
          return WidgetLiveUserInfoView(
              clickCallBack: clickCallBack,
              infoEntity: infoEntity,
              userId: userId);
        }).then((value) => {});
  }
}

class WidgetLiveUserInfoView extends StatefulWidget {
  final ClickCallBack clickCallBack;
  final ModelLiveInfoEntity infoEntity;
  final int userId;
  // ignore: use_key_in_widget_constructors
  const WidgetLiveUserInfoView({
    required this.clickCallBack,
    required this.infoEntity,
    required this.userId,
  });
  @override
  WidgetLiveUserInfoViewState createState() => WidgetLiveUserInfoViewState();
}

class WidgetLiveUserInfoViewState extends State<WidgetLiveUserInfoView> {
  ModelLiveUserInfoEntity _userInfoEntity = ModelLiveUserInfoEntity();
  Future? _future;
  // CountryPickerUtils
  Map wraps = {
    "AUT1": {
      "on": "icon_live_user_video_call",
      "off": "icon_live_user_video_call"
    },
    "AUT2": {"on": "icon_live_message", "off": "icon_live_message"},
    "AUT3": {"off": "icon_live_follow", "on": "icon_live_unfollow"},
    "AUT4": {
      "off": "icon_live_user_block",
      "on": "icon_live_user_block_remove"
    },
    "AUT5": {"off": "icon_live_seat_invite", "on": "icon_live_seat_leave"},
    "AUT6": {"off": "icon_live_message_allow", "on": "icon_live_message_ban"},
    "AUT7": {"off": "icon_live_mic_allow", "on": "icon_live_mic_ban_user"},
  };
  @override
  Widget build(BuildContext context) {
    return FutureBuilder(
        future: _future,
        builder: (BuildContext context, AsyncSnapshot snapshot) {
          if (snapshot.connectionState == ConnectionState.done) {
            if (snapshot.hasError) {
              return Container(
                height: 200.w,
                margin: EdgeInsets.only(top: 30.w),
                decoration: const BoxDecoration(
                    borderRadius: BorderRadius.only(
                        topLeft: Radius.circular(30),
                        topRight: Radius.circular(30)),
                    color: Color(0xff2B1248)),
              );
            } else {
              return Column(
                children: [
                  Expanded(
                    child: GestureDetector(
                      onTap: () {
                        if (!mounted) {
                          return;
                        }
                        Navigator.pop(context);
                      },
                      child: Container(
                        color: Colors.transparent,
                      ),
                    ),
                  ),
                  Stack(
                    children: [
                      buildUserInfoView(),
                      Positioned(
                          left: 0,
                          right: 0,
                          top: 0,
                          child: Row(
                            mainAxisAlignment: MainAxisAlignment.center,
                            children: [
                              GestureDetector(
                                  child: Container(
                                    decoration: BoxDecoration(
                                      border: Border.all(
                                          color: Colors.white, width: 2.w),
                                      borderRadius: BorderRadius.circular(40.w),
                                    ),
                                    child: ClipRRect(
                                        borderRadius:
                                            BorderRadius.circular(40.w),
                                        child: UtilsLiveImage.getLoadWidget(
                                            _userInfoEntity.headImage,
                                            width: 76.w,
                                            height: 76.w)
                                        // width: 70.w, height: 80.w),
                                        ),
                                  ),
                                  behavior: HitTestBehavior.opaque,
                                  onTap: () {
                                    //                               if (!mounted) {
                                    //   return;
                                    // }
                                    //                               Navigator.push(context,
                                    //                                   MaterialPageRoute(builder: (context) {
                                    //                                 return PagePhotoViewGallery(
                                    //                                     index: 0,
                                    //                                     images: [_userInfoEntity.headImage],
                                    //                                     heroTag:
                                    //                                         _userInfoEntity.headImage ?? '');
                                    //                               }));
                                  })
                            ],
                          ))
                    ],
                  )
                  //  buildUserInfoView()
                ],
              );
            }
          } else {
            return Container(
              decoration: const BoxDecoration(
                  borderRadius: BorderRadius.only(
                      topLeft: Radius.circular(10),
                      topRight: Radius.circular(10)),
                  color: Color(0xff2B1248)),
              padding: EdgeInsets.symmetric(horizontal: 15.w, vertical: 21.w),
              height: 300.w,
              // child: WidgetSpinkit.showSpinkit(),Container(
            );
          }
        });
  }

  Widget buildUserInfoView() {
    return Container(
      margin: EdgeInsets.only(top: 30.w),
      decoration: const BoxDecoration(
          borderRadius: BorderRadius.only(
              topLeft: Radius.circular(30), topRight: Radius.circular(30)),
          color: Color(0xff2B1248)),
      padding: EdgeInsets.symmetric(horizontal: 15.w, vertical: 21.w),
      child: Column(
        children: [
          Row(
            mainAxisAlignment: MainAxisAlignment.spaceBetween,
            children: [
              Visibility(
                visible: false,
                child: GestureDetector(
                  behavior: HitTestBehavior.opaque,
                  child: const SizedBox(
                    width: 40,
                    height: 40,
                  ),
                ),
              ),
              GestureDetector(
                behavior: HitTestBehavior.opaque,
                child: SizedBox(
                  width: 40,
                  height: 40,
                  child: UtilsLiveImage.getIconByPath(
                    'icon_live_report',
                  ),
                ),
                onTap: () {
                  if (!mounted) {
                    return;
                  }
                  widget.clickCallBack(
                      ConfigLiveMethon.liveReport, widget.userId.toString());

                  Navigator.pop(context);
                },
              )
            ],
          ),
          Container(
              margin: EdgeInsets.only(top: 10.w, bottom: 5.w),
              child: Row(
                mainAxisAlignment: MainAxisAlignment.center,
                children: [
                  Container(
                    constraints: BoxConstraints(maxWidth: 150.w),
                    child: Text(_userInfoEntity.nickname ?? '',
                        style: TextStyle(
                            fontSize: 24,
                            color: UtilsLiveColor.hexToColor("#FFFFFF"),
                            fontWeight: FontWeight.bold,
                            decoration: TextDecoration.none)),
                  ),
                  const SizedBox(
                    width: 5,
                  ),
                  UtilsLiveImage.getIconByPath(
                    AssetImage(CountryPickerUtils.getFlagImageAssetPath(
                            CountryPickerUtils.getCountryByPhoneCode(
                                    _userInfoEntity.country ?? '1')
                                ?.isoCode))
                        .assetName,
                    fit: BoxFit.cover,
                    height: 10,
                    package: "mmoo_country_pickers",
                  ),
                ],
              )),
          Row(
            mainAxisAlignment: MainAxisAlignment.center,
            children: [
              Text(
                S.current.Live_ID(_userInfoEntity.userId ?? 0),
                style: TextStyle(
                    fontSize: 18,
                    color:
                        UtilsLiveColor.hexToColor("#FFFFFF").withOpacity(0.6),
                    // fontWeight: FontWeight.n,
                    decoration: TextDecoration.none),
              ),
              Container(
                margin: EdgeInsets.only(left: 5.w),
                height: 20.w,
                decoration: BoxDecoration(
                  borderRadius: BorderRadius.circular(10.w),
                  color: UtilsLiveColor.hexToColor(
                      _userInfoEntity.gender == 0 ? "#25ABE6" : "#FF5C8E"),
                ),
                alignment: Alignment.center,
                padding: const EdgeInsets.only(left: 8, right: 8),
                child: Row(
                  children: [
                    UtilsLiveImage.getIconByPath(_userInfoEntity.gender == 0
                        ? 'app_mine_boys'
                        : 'app_mine_girls'),
                    Text(
                      UtilsLive.getAge(_userInfoEntity.birthday ?? ''),
                      style: UtilsLiveTextStyle.pt14WhiteSemiBold,
                    )
                  ],
                ),
              ),
            ],
          ),
          Container(
            margin: EdgeInsets.only(top: 7.w, bottom: 11.w),
            child: Text(
              _userInfoEntity.signature ?? '',
              style: TextStyle(
                  fontSize: 14,
                  color: UtilsLiveColor.hexToColor("#999999"),
                  // fontWeight: FontWeight.w600,
                  decoration: TextDecoration.none),
              maxLines: null,
            ),
          ),
          Container(
            margin: EdgeInsets.only(bottom: 10.w),
            child: Wrap(
              crossAxisAlignment: WrapCrossAlignment.start,
              runAlignment: WrapAlignment.start,
              alignment: WrapAlignment.spaceBetween,
              // textDirection: TextDirection.rtl,
              runSpacing: 20.w,
              spacing: 25.w,
              children: (_userInfoEntity.btn ?? []).map((e) {
                return GestureDetector(
                  child: e.codeName == 'AUT1'
                      ? SizedBox(
                          width: 185.w,
                          height: 50.w,
                          // color: Colors.red,
                          child: ClipRRect(
                            borderRadius: BorderRadius.circular(25.w),
                            child: UtilsLiveImage.getIconByPath(
                              (e.codeType == 1
                                  ? wraps[e.codeName]['on']
                                  : wraps[e.codeName]['off']),
                            ),
                          ))
                      : SizedBox(
                          height: 50.w,
                          width: 50.w,
                          // color: Colors.red,
                          child: UtilsLiveImage.getIconByPath((e.codeType == 1
                              ? wraps[e.codeName]['on']
                              : wraps[e.codeName]['off'])),
                        ),
                  onTap: () {
                    clickBottomBtns(e);
                  },
                );
              }).toList(),
            ),
          ),
        ],
      ),
    );
  }

  clickBottomBtns(ModelLiveUserInfoBtn infoBtn) async {
    if (!mounted) {
      return;
    }
    if (infoBtn.codeName == 'AUT1') {
      //一对一视频
      widget.clickCallBack(
          ConfigLiveMethon.liveUserCallVideo, widget.userId.toString());
    } else if (infoBtn.codeName == 'AUT2') {
      widget.clickCallBack(
          ConfigLiveMethon.liveUserIMChat, widget.userId.toString());
      //一对一私聊
    } else if (infoBtn.codeName == 'AUT3') {
      //关注
      DataResult dataResult = await MainDao.livePostCareUser(
          careType: infoBtn.codeType == 0 ? 0 : 1,
          userId: _userInfoEntity.userId ?? 0);
      if (dataResult.result) {
        if (mounted) {
          setState(() {
            infoBtn.codeType = infoBtn.codeType == 0 ? 1 : 0;
          });
        }
        CommonUtils.showToast(infoBtn.codeType == 0
            ? S.current.Live_cancelfollow
            : S.current.Live_follow);
      } else {
        UtilsLiveAlert.showDioTips(context, dataResult);
      }
    } else if (infoBtn.codeName == 'AUT4') {
      //拉黑
      if (infoBtn.codeType == 0) {
        UtilsLiveAlert.showCenterGeneral(context,
            isLive: true,
            leftStr: S.current.Live_Cancel,
            rightStr: S.current.Live_Sure, rightVoidCallBack: () async {
          userBlockOperation(infoBtn);
        }, infoStr: S.current.Live_Areyousureset);
      } else {
        userBlockOperation(infoBtn);
      }
      if (mounted) {
        setState(() {
          _userInfoEntity.btn?.forEach((element) {
            if (element.codeName == 'AUT6') {
              element.codeType = infoBtn.codeType == 0 ? 1 : 0;
            } else if (element.codeName == 'AUT7') {
              element.codeType = infoBtn.codeType == 0 ? 1 : 0;
            }
          });
        });
      }
    } else if (infoBtn.codeName == 'AUT5') {
      //邀请 上下麦
      if (infoBtn.codeType == 1) {
        //下麦
        // Navigator.pop(context);
        UtilsLiveAlert.showCenterGeneral(context,
            isLive: true,
            leftStr: S.current.Live_Cancel,
            rightStr: S.current.Live_Yes, rightVoidCallBack: () async {
          // apiLiveMasterDownSeat
          DataResult dataResult = await MainDao.liveMasterDownSeat(
              userId: _userInfoEntity.userId ?? 0,
              roomId: widget.infoEntity.roomId ?? 0,
              roomPlaceId: _userInfoEntity.roomPlaceId ?? 0);
          if (dataResult.result) {
            CommonUtils.showToast(S.current.Live_Operationsucceeded);
            if (mounted) {
              setState(() {
                infoBtn.codeType = infoBtn.codeType == 0 ? 1 : 0;
              });
            }
            Navigator.pop(context);
          } else {
            UtilsLiveAlert.showDioTips(context, dataResult);
          }
        }, infoStr: S.current.Live_kickitofftheseat);
      } else {
        //邀请上麦
        if ((ProviderLiveInfoEntity().infoEntity.videoPlaceList?.length ?? 0) >
                1 &&
            (ProviderLiveInfoEntity().infoEntity.voicePlaceList?.length ?? 0) >
                1) {
          WidgetActionBtns.bottomSheet(context, WidgetLiveInvitePlaceList(
            clickCallBack: (das, data) async {
              bool isSuccess = await inviteUserIntoStearmer(infoBtn, data);
              if (isSuccess) {
                Future.delayed(const Duration(milliseconds: 300), () {
                  Navigator.pop(context);
                });
              }
            },
          )).then((value) {});
        } else {
          //  Navigator.pop(context);
          inviteUserIntoStearmer(
              infoBtn,
              (ProviderLiveInfoEntity().infoEntity.voicePlaceList?.length ??
                          0) >
                      1
                  ? 0
                  : 1);
        }
      }
    } else if (infoBtn.codeName == 'AUT6') {
      //禁群聊
      if (infoBtn.codeType == 0) {
        UtilsLiveAlert.showCenterGeneral(context,
            isLive: true, leftStr: S.current.Live_Sure,
            // rightStr: S.current.Live_Sure,
            leftVoidCallBack: () {
          isCloseGroupChat(infoBtn, true);
        },
            rightVoidCallBack: () async {},
            infoStr: S.current.Live_sendlivemessage);
      } else {
        isCloseGroupChat(infoBtn, false);
      }
    } else if (infoBtn.codeName == 'AUT7') {
      //禁麦
      if (infoBtn.codeType == 0) {
        UtilsLiveAlert.showCenterGeneral(
          context,
          isLive: true,
          infoStr: S.current.Live_usemicrophon,
          leftStr: S.current.Live_Sure,
          leftVoidCallBack: () {
            isCloseMicrophone(infoBtn, true);
          },
        );
      } else {
        isCloseMicrophone(infoBtn, false);
      }
    }
    // Navigator.pop(context);
  }

  isCloseGroupChat(ModelLiveUserInfoBtn infoBtn, bool isClose) async {
    DataResult dataResult = await MainDao.livePostMuteUser(
        isMute: isClose,
        userId: widget.userId,
        roomId: widget.infoEntity.roomId ?? 0);
    if (dataResult.result) {
      CommonUtils.showToast(S.current.Live_Operationsucceeded);
      if (mounted) {
        setState(() {
          infoBtn.codeType = infoBtn.codeType == 0 ? 1 : 0;
        });
      }
    } else {
      UtilsLiveAlert.showDioTips(context, dataResult);
    }
  }

  isCloseMicrophone(ModelLiveUserInfoBtn infoBtn, bool isClose) async {
    DataResult dataResult = await MainDao.livePostMuteVoiceUser(
        isMute: isClose,
        userId: widget.userId,
        roomId: widget.infoEntity.roomId ?? 0);
    if (dataResult.result) {
      CommonUtils.showToast(S.current.Live_Operationsucceeded);
      if (mounted) {
        setState(() {
          infoBtn.codeType = infoBtn.codeType == 0 ? 1 : 0;
        });
      }
    } else {
      UtilsLiveAlert.showDioTips(context, dataResult);
    }
  }

  Future<bool> inviteUserIntoStearmer(
      ModelLiveUserInfoBtn infoBtn, int type) async {
    DataResult dataResult = await MainDao.livePostMasterInvite(
        userId: widget.userId,
        roomId: widget.infoEntity.roomId ?? 0,
        type: type);
    if (dataResult.result) {
      CommonUtils.showToast(S.current.Live_invitationsentout);
      if (mounted) {
        setState(() {
          infoBtn.codeType = infoBtn.codeType == 0 ? 1 : 0;
        });
      }

      // Navigator.pop(context);
      return true;
    } else {
      UtilsLiveAlert.showDioTips(context, dataResult);
      return false;
    }
  }

  userBlockOperation(ModelLiveUserInfoBtn infoBtn) async {
    DataResult dataResult = await MainDao.livePostBlockUser(
        roomId: ProviderLiveInfoEntity().infoEntity.roomId ?? 0,
        userId: _userInfoEntity.userId ?? 0,
        isCancelBlock: infoBtn.codeType == 1 ? true : false);
    if (dataResult.result) {
      CommonUtils.showToast(S.current.Live_Operationsucceeded);
      if (mounted) {
        setState(() {
          infoBtn.codeType = infoBtn.codeType == 0 ? 1 : 0;
        });
      }
    } else {
      if (!mounted) {
        return;
      }
      UtilsLiveAlert.showDioTips(context, dataResult);
    }
  }

  Future initDataSource() async {
    CommonUtils.showLoading();

    // FlutterImclient
    DataResult dataResult = await MainDao.liveGetUserInfo(
        roomId: widget.infoEntity.roomId ?? 0, userId: widget.userId);
    CommonUtils.dismiss();
    if (dataResult.result && dataResult.data != null) {
      _userInfoEntity = ModelLiveUserInfoEntity().fromJson(dataResult.data);
      List<ModelLiveUserInfoBtn> list = [];
      _userInfoEntity.btn?.forEach((element) {
        if (wraps.containsKey(element.codeName)) {
          // list.add(element);
          // element.codeType = 0;
          list.insert(0, element);
        }
      });
      _userInfoEntity.btn = list;
      // List<ModelLiveUserInfoBtn> vsdv = list.reversed as List<ModelLiveUserInfoBtn>;;
      // list.reversed;
      // _userInfoEntity.btn = list.reversed as List<ModelLiveUserInfoBtn>;
      return;
    } else {
      if (!mounted) {
        return;
      }
      UtilsLiveAlert.showDioTips(context, dataResult);

      return Future.error('');
    }
  }

  @override
  void initState() {
    _future = initDataSource();
    super.initState();
  }

  @override
  void dispose() {
    super.dispose();
  }

  @override
  void didUpdateWidget(WidgetLiveUserInfoView oldWidget) {
    super.didUpdateWidget(oldWidget);
  }

  @override
  void didChangeDependencies() {
    super.didChangeDependencies();
  }
}
