import 'package:flutter/material.dart';
import 'package:flutter_screenutil/flutter_screenutil.dart';
import 'package:mmoo_base/dao/dao_result.dart';
import 'package:mmoo_base/dao/main_dao.dart';
import 'package:mmoo_live_room/Config/config_live_globalkey.dart';
import 'package:mmoo_live_room/Config/config_live_methon.dart';
import 'package:mmoo_live_room/Config/config_live_typedef.dart';
import 'package:mmoo_live_room/Provider/provider_live_online.dart';
import 'package:mmoo_live_room/Provider/provider_live_user.dart';
import 'package:mmoo_live_room/Utils/utils_live_alert.dart';
import 'package:mmoo_live_room/Utils/utils_live_colors.dart';
import 'package:mmoo_live_room/Utils/utils_live_image.dart';
import 'package:mmoo_live_room/Widget/widget_live_user_info.dart';
import 'package:mmoo_live_room/generated/l10n.dart';
import 'package:mmoo_live_room/Model/model_live_info_entity.dart';
import 'package:mmoo_live_room/Model/model_live_apply_list_entity.dart';
import 'package:provider/provider.dart';
import 'package:pull_to_refresh/pull_to_refresh.dart';
///直播间  申请类型页面  同时会展示申请对象列表
///
class WidgetLiveUserWaitList extends StatefulWidget {
  final ClickCallBack clickCallBack;
  final ModelLiveInfoEntity infoEntity;
  WidgetLiveUserWaitList(
      {required this.infoEntity, required this.clickCallBack})
      : super(key: ConfigLiveGlobalkey.applyViewKey);
  @override
  WidgetLiveUserWaitListState createState() => WidgetLiveUserWaitListState();
}

class WidgetLiveUserWaitListState extends State<WidgetLiveUserWaitList> {
  RefreshController refreshController = RefreshController(initialRefresh: true);

  ModelLiveApplyListEntity _applyListEntity = ModelLiveApplyListEntity();
  @override
  Widget build(BuildContext context) {
    // widget.infoEntity.type = 1;
    return Container(
        height: 400.w + ScreenUtil().bottomBarHeight,
        padding: EdgeInsets.symmetric(horizontal: 15.w),
        decoration: const BoxDecoration(
            color: Color(0xff2B1248),
            borderRadius: BorderRadius.only(
                topLeft: Radius.circular(30), topRight: Radius.circular(30))),
        child: Column(children: [
          SizedBox(
            height: 60,
            child: Row(
              mainAxisAlignment: MainAxisAlignment.spaceBetween,
              children: [
                const SizedBox(
                  width: 40,
                  height: 40,
                ),
                Text(
                  S.current.Live_WaitingList,
                  style: const TextStyle(
                      color: Colors.white,
                      fontSize: 20,
                      fontWeight: FontWeight.bold),
                ),
                GestureDetector(
                  child: SizedBox(
                    width: 40,
                    height: 40,
                    child: UtilsLiveImage.getIconByPath(
                      'live_open_close',
                    ),
                  ),
                  onTap: () {
                    Navigator.pop(context);
                  },
                )
              ],
            ),
          ),
          Expanded(
              child: SmartRefresher(
                  controller: refreshController,
                  enablePullDown: true,
                  enablePullUp: true,
                  onRefresh: _onRefresh,
                  onLoading: _onLoading,
                  child: ListView.builder(
                    itemCount: _applyListEntity.userList?.length,
                    itemExtent: 70,
                    itemBuilder: (BuildContext context, int index) {
                      return GestureDetector(
                        behavior: HitTestBehavior.opaque,
                        child: buildApplyListView(
                            _applyListEntity.userList![index]),
                        onTap: () {
                           widget.clickCallBack(ConfigLiveMethon.liveClickUserInfo,_applyListEntity.userList![index].userId ??
                                      0);

                        },
                      );
                    },
                  ))),
          Visibility(
              visible: !((widget.infoEntity.videoPlaceList ?? []).isEmpty &&
                  (widget.infoEntity.voicePlaceList ?? []).isEmpty),
              child: Container(
                  margin: EdgeInsets.only(
                      bottom: ScreenUtil().bottomBarHeight + 10.w, top: 10.w),
                  child: ((widget.infoEntity.videoPlaceList ?? []).isNotEmpty &&
                              (widget.infoEntity.voicePlaceList ?? [])
                                  .isNotEmpty) &&
                          ProviderLiveUser().isApplyForMike == false
                      ? buildVideoVoiceBtn()
                      : buildOnlyBtn()))
        ]));
  }

  Widget buildOnlyBtn() {
    return GestureDetector(
        behavior: HitTestBehavior.opaque,
        onTap: () {
          if (ProviderLiveUser().isApplyForMike) {
            Navigator.pop(context);
            widget.clickCallBack(ConfigLiveMethon.liveBottomCancel, null);
          } else {
            applyJoinSeat(widget.infoEntity.type ?? 0);
          }
        },
        child: Container(
          height: 50.w,
          alignment: Alignment.center,
          width: 305.w,
          decoration: ShapeDecoration(
              shape: const StadiumBorder(),
              gradient: LinearGradient(
                  colors: ProviderLiveUser().isApplyForMike
                      ? [
                          Colors.white.withOpacity(0.1),
                          Colors.white.withOpacity(0.1)
                        ]
                      : widget.infoEntity.type == 0
                          ? [const Color(0xff3F9EFD), const Color(0xff33DBAE)]
                          : [
                              const Color(0xffFB5C9A),
                              const Color(0xffF775F2)
                            ])),
          child: Row(
            mainAxisAlignment: MainAxisAlignment.center,
            children: [
              Visibility(
                  visible: ProviderLiveUser().isApplyForMike == false,
                  child: UtilsLiveImage.getIconByPath(
                    widget.infoEntity.type == 0
                        ? 'icon_live_join_voice'
                        : 'icon_live_join_Video',
                  )),
              SizedBox(
                width: 5.w,
              ),
              Text(
                ProviderLiveUser().isApplyForMike
                    ? S.current.Live_Quit
                    : widget.infoEntity.type == 0
                        ? S.current.Live_VoiceJoin
                        : S.current.Live_VideoJoin,
                style: const TextStyle(
                    color: Colors.white,
                    fontSize: 18,
                    fontWeight: FontWeight.bold),
              )
            ],
          ),
        ));
  }

  Widget buildVideoVoiceBtn() {
    return Row(
      mainAxisAlignment: MainAxisAlignment.spaceBetween,
      children: [
        GestureDetector(
            behavior: HitTestBehavior.opaque,
            onTap: () {
              applyJoinSeat(0);
            },
            child: Container(
              height: 50.w,
              alignment: Alignment.center,
              width: 165.w,
              decoration: BoxDecoration(
                  borderRadius: BorderRadius.circular(25.w),
                  gradient: const LinearGradient(
                      colors: [Color(0xff3F9EFD), Color(0xff33DBAE)])),
              child: Row(
                mainAxisAlignment: MainAxisAlignment.center,
                children: [
                  UtilsLiveImage.getIconByPath(
                    'icon_live_join_voice',
                  ),
                  SizedBox(
                    width: 5.w,
                  ),
                  Text(
                    S.current.Live_VoiceJoin,
                    style: const TextStyle(
                        color: Colors.white,
                        fontSize: 18,
                        fontWeight: FontWeight.bold),
                  )
                ],
              ),
            )),
        GestureDetector(
            behavior: HitTestBehavior.opaque,
            onTap: () {
              applyJoinSeat(1);
            },
            child: Container(
              height: 50.w,
              alignment: Alignment.center,
              width: 165.w,
              decoration: BoxDecoration(
                  borderRadius: BorderRadius.circular(25.w),
                  gradient: const LinearGradient(
                      colors: [Color(0xffFB5C9A), Color(0xffF775F2)])),
              child: Row(
                mainAxisAlignment: MainAxisAlignment.center,
                children: [
                  UtilsLiveImage.getIconByPath(
                    'icon_live_join_Video',
                  ),
                  SizedBox(
                    width: 5.w,
                  ),
                  Text(
                    S.current.Live_VideoJoin,
                    style: const TextStyle(
                        color: Colors.white,
                        fontSize: 18,
                        fontWeight: FontWeight.bold),
                  )
                ],
              ),
            ))
      ],
    );
  }

  Widget buildApplyListView(ModelLiveApplyListRows model) {
    return Row(
      mainAxisAlignment: MainAxisAlignment.spaceBetween,
      children: [
        Row(
          children: [
            SizedBox(
              width: 50,
              height: 50,
              child: Stack(
                children: [
                  SizedBox(
                    width: 50,
                    height: 50,
                    child: ClipRRect(
                      borderRadius: BorderRadius.circular(25),
                      child: UtilsLiveImage.getLoadWidget(model.headImage),
                      //  child: ,
                    ),
                  ),
                ],
              ),
            ),
            Column(
              mainAxisAlignment: MainAxisAlignment.center,
              crossAxisAlignment: CrossAxisAlignment.start,
              children: [
                Row(
                  children: [
                    Container(
                      padding: const EdgeInsets.symmetric(horizontal: 10),
                      constraints: BoxConstraints(maxWidth: 200.w),
                      child: Text(
                        model.nickname ?? '',
                        style: TextStyle(
                            fontSize: 18,
                            color: UtilsLiveColor.hexToColor("#FFFFFF"),
                            fontWeight: FontWeight.bold,
                            decoration: TextDecoration.none),
                      ),
                    ),
                    // UtilsLiveImage.getIconByPath(
                    //   model.gender == 0
                    //       ? 'heimingdan_icon_nanren'
                    //       : 'heimingdan_icon_nvren',
                    //
                    // )
                  ],
                ),
                const SizedBox(
                  height: 3,
                ),
                Container(
                  height: 20,
                  margin: const EdgeInsets.only(left: 10),
                  padding: const EdgeInsets.symmetric(horizontal: 7),
                  decoration: BoxDecoration(
                      borderRadius: BorderRadius.circular(10),
                      color: model.isAnchor == 1
                          ? UtilsLiveColor.hexToColor('#EB6B00')
                          : UtilsLiveColor.hexToColor("#FFFFFF")
                              .withOpacity(0.1)),
                  child: Row(
                    children: [
                      Text(
                        model.isAnchor == 1 ? S.current.Live_Anchor : S.current.Live_GuestInfo,
                        style: const TextStyle(
                            color: Colors.white,
                            fontSize: 12,
                            fontWeight: FontWeight.normal,
                            decoration: TextDecoration.none),
                      )
                    ],
                  ),
                )
              ],
            ),
          ],
        ),
        SizedBox(
          child: UtilsLiveImage.getIconByPath(
            'live_open_arrow',
          ),
        )
      ],
    );
  }

  applyJoinSeat(int type) {
    if (type == 1 && (widget.infoEntity.videoPrice ?? 0) > 0 && ProviderLiveUser().userInfo.isHost != '1') {
      UtilsLiveAlert.showCenterGeneral(context,
          isLive: true,
          leftStr: S.current.Live_Cancel,
          rightStr: S.current.Live_Yes, rightVoidCallBack: () async {
        widget.clickCallBack(ConfigLiveMethon.liveBottomPayJoinStream, type);
        Navigator.pop(context);
      },
          infoStr: S.current
              .Live_coinstoapplyforvideo(widget.infoEntity.videoPrice ?? ''));
    } else if (type == 0 && (widget.infoEntity.voicePrice ?? 0) > 0 && ProviderLiveUser().userInfo.isHost != '1') {
      UtilsLiveAlert.showCenterGeneral(context,
          isLive: true,
          leftStr: S.current.Live_Cancel,
          rightStr: S.current.Live_Yes, rightVoidCallBack: () async {
        widget.clickCallBack(ConfigLiveMethon.liveBottomPayJoinStream, type);
        Navigator.pop(context);
      },
          infoStr: S.current
              .Live_coinstoapplyforvoice(widget.infoEntity.voicePrice ?? ''));
    } else {
      widget.clickCallBack(ConfigLiveMethon.liveBottomPayJoinStream, type);
      Navigator.pop(context);
    }
  }

  _onRefresh() {
    _applyListEntity.num = 1;

    _refreshDataSource();
  }

  _onLoading() {
    _applyListEntity.num = (_applyListEntity.num ?? 1) + 1;
    _refreshDataSource();
  }

  _refreshDataSource() async {
    DataResult dataResult = await MainDao.livePostApplyList(
        roomId: widget.infoEntity.roomId ?? 0, num: 1, size: 20);
    refreshController.refreshCompleted();
    if (dataResult.result && dataResult.data != null) {
      ModelLiveApplyListEntity listEntity =
          ModelLiveApplyListEntity().fromJson(dataResult.data);
      if ((listEntity.userList?.length ?? 0) < 20) {
        refreshController.loadNoData();
      } else {
        refreshController.loadComplete();
      }
      if (listEntity.num == 1) {
        _applyListEntity = ModelLiveApplyListEntity().fromJson(dataResult.data);
        if (ProviderLiveOnline().onLineNum != _applyListEntity.onlineNum) {
          ProviderLiveOnline onlineProvider =
              Provider.of<ProviderLiveOnline>(context, listen: false);
          onlineProvider.onLineNum = _applyListEntity.onlineNum ?? 0;
        }
      } else {
        _applyListEntity.userList?.addAll(listEntity.userList ?? []);
      }
      if (mounted) {
        setState(() {});
      }
    } else {
          UtilsLiveAlert.showDioTips(context, dataResult);
        
      refreshController.loadFailed();
    }
  }

  @override
  void initState() {
    _applyListEntity.userList = [];
    // TODO: implement initState
    super.initState();
  }

  @override
  void dispose() {
    // TODO: implement dispose
    super.dispose();
  }

  @override
  void didUpdateWidget(WidgetLiveUserWaitList oldWidget) {
    // TODO: implement didUpdateWidget
    super.didUpdateWidget(oldWidget);
  }

  @override
  void didChangeDependencies() {
    // TODO: implement didChangeDependencies
    super.didChangeDependencies();
  }
}
