// ignore_for_file: use_key_in_widget_constructors

import 'package:flutter/material.dart';
import 'package:flutter_screenutil/flutter_screenutil.dart';
import 'package:mmoo_base/entity/language_entity.dart';
import 'package:mmoo_live_room/Config/config_live_app.dart';
import 'package:mmoo_live_room/Model/model_lastLive_entity.dart';
import 'package:mmoo_live_room/Model/model_live_user_info.dart';
import 'package:mmoo_live_room/Provider/provider_live_user.dart';
import 'package:mmoo_live_room/Config/config_live_typedef.dart';
import 'package:mmoo_live_room/Utils/utils_live_alert.dart';
import 'package:mmoo_live_room/Utils/utils_live_colors.dart';
import 'package:mmoo_live_room/Utils/utils_live_image.dart';
import 'package:mmoo_live_room/Utils/utils_live_repeat_click.dart';
import 'package:mmoo_live_room/Widget/widget_live_more_choose.dart';
import 'package:mmoo_live_room/Utils/utils_live_dlog.dart';
import 'package:mmoo_live_room/Utils/utils_live_textStyle.dart';
import 'package:mmoo_live_room/generated/l10n.dart';

///开播页面 头部view
class WidgetOpenHeader extends StatefulWidget {
  final ClickCallBack? clickCallBack;
  final ModelLastLiveEntity? lastLiveEntity;
  final bool isVideo;
  const WidgetOpenHeader(
      {this.clickCallBack, this.lastLiveEntity, this.isVideo = false});
  @override
  WidgetOpenHeaderState createState() => WidgetOpenHeaderState();
}

class WidgetOpenHeaderState extends State<WidgetOpenHeader> {
  final TextEditingController _editingNameController = TextEditingController();
  final FocusNode _editNameFocusNode = FocusNode();
  @override
  Widget build(BuildContext context) {
    // DLog(widget.lastLiveEntity);
    _editingNameController.text = widget.lastLiveEntity?.title ?? '';
    List rows = [S.current.Live_Begin_Language];

    if (int.parse(widget.lastLiveEntity?.micSeat ?? '0') > 0) {
      rows.add(S.current.Live_Begin_MicSeatPrice);
    }
    if (widget.isVideo) {
      rows.add(S.current.Live_Begin_VideoSeatPrice);
    }
    return SingleChildScrollView(
      child: Column(
        children: [
          Container(
            padding: EdgeInsets.all(10.w),
            height: 100.w,
            decoration: BoxDecoration(
                color: Colors.black.withOpacity(0.2),
                borderRadius: BorderRadius.circular(20)),
            child: Row(
              children: [
                ClipRRect(
                    borderRadius: BorderRadius.circular(10),
                    child: GestureDetector(
                      child: SizedBox(
                        width: 80,
                        height: 80,
                        child: Stack(
                          children: [
                            Positioned.fill(
                              child: Container(
                                // color: Colors.red,
                                // width: 80,
                                child: widget.lastLiveEntity?.cover == null
                                    ? UtilsLiveImage.getIconByPath(
                                        'live_open_cover',
                                        fit: BoxFit.cover,
                                      )
                                    : UtilsLiveImage.getLoadWidget(
                                        widget.lastLiveEntity?.cover ?? '',
                                        fit: BoxFit.cover,
                                        urlWidth: ConfigLiveApp.PIC_WIDTH_HEAD),
                              ),
                            ),
                            Positioned(
                                left: 0,
                                right: 0,
                                bottom: 0,
                                child: Container(
                                  height: 24,
                                  decoration: BoxDecoration(
                                      color: Colors.black.withOpacity(0.4)),
                                  alignment: Alignment.center,
                                  child: Text(
                                    S.current.Live_Begin_Edit,
                                    style: UtilsLiveTextStyle.pt12WhiteSemiBold,
                                  ),
                                ))
                          ],
                        ),
                      ),
                      onTap: () {
                        if (widget.clickCallBack != null) {
                          widget.clickCallBack!('openPhotos', null);
                        }
                      },
                    )),
                Expanded(
                    child: Container(
                  margin: EdgeInsets.only(left: 15.w),
                  child: Column(
                    children: [
                      TextField(
                        textAlign: TextAlign.start,
                        maxLines: 1,
                        textAlignVertical: TextAlignVertical.center,
                        keyboardType: TextInputType.multiline,
                        autofocus: false,
                        onChanged: (text) {
                          DLog(text);
                          widget.lastLiveEntity?.title = text;
                        },
                        controller: _editingNameController,
                        focusNode: _editNameFocusNode,
                        maxLength: 20,
                        textInputAction: TextInputAction.done,
                        decoration: InputDecoration(
                            border: InputBorder.none,
                            counterText: "",
                            hintText: S.current.Live_Begin_hintName,
                            hintStyle: TextStyle(
                                color: UtilsLiveColor.hexToColor("#FFFFFF"))),
                        style: TextStyle(
                            color: UtilsLiveColor.hexToColor("#FFFFFF"),
                            fontSize: 18,
                            fontWeight: FontWeight.bold),
                        onSubmitted: (text) {
                          DLog(text);
                        },
                      ),
                      Row(
                        children: [
                          GestureDetector(
                            onTap: () {
                              if (widget.clickCallBack != null) {
                                widget.clickCallBack!('Set up', '');
                              }
                            },
                            child: Container(
                              height: 30.w,
                              padding:
                                  const EdgeInsets.symmetric(horizontal: 10),
                              decoration: BoxDecoration(
                                  border:
                                      Border.all(width: 1, color: Colors.white),
                                  borderRadius: BorderRadius.circular(10)),
                              child: Row(
                                children: [
                                  Text(
                                    rows.isNotEmpty
                                        ? S.current.Live_Roomsettings
                                        : S.current.Live_Modifysettings,
                                    style: UtilsLiveTextStyle.pt14WhiteSemiBold,
                                  ),
                                  const SizedBox(
                                    width: 4,
                                  ),
                                  UtilsLiveImage.getIconByPath(
                                    'live_open_setting',
                                  )
                                ],
                              ),
                            ),
                          )
                        ],
                      )
                    ],
                  ),
                ))
              ],
            ),
          ),
          Container(
              // constraints: BoxConstraints(maxHeight: 120.w),
              margin: EdgeInsets.only(top: 20.w),
              height: rows.length * 60.w,
              child: ListView.separated(
                itemCount: rows.length,
                physics: const NeverScrollableScrollPhysics(),
                padding: EdgeInsets.only(bottom: ScreenUtil().bottomBarHeight),
                itemBuilder: (BuildContext context, int index) {
                  return GestureDetector(
                    onTap: UtilsLiveRepeatClick.debounce(() {
                      if (rows[index] == S.current.Live_Begin_Language) {
                        UtilsLiveAlert.showBottomSheet(
                            context,
                            WidgetLiveMoreChoose(
                              titStr: S.current.Live_Choosealanguage,
                              rows: (ProviderLiveUser().userInfo.language ?? [])
                                      .isNotEmpty
                                  ? (ProviderLiveUser()
                                          .userInfo
                                          .language
                                          ?.map((e) {
                                        return e.value as String;
                                      }).toList() ??
                                      [])
                                  : (ConfigLiveApp.langList.map((e) {
                                      return e.value as String;
                                    }).toList()),
                              chooseCallback: (index) {
                                if (mounted) {
                                  setState(() {
                                    widget.lastLiveEntity?.language =
                                        ProviderLiveUser()
                                            .userInfo
                                            .language?[index]
                                            .code;
                                  });
                                }
                              },
                            ));
                      } else if (rows[index] ==
                          S.current.Live_Begin_MicSeatPrice) {
                        UtilsLiveAlert.showBottomSheet(
                            context,
                            WidgetLiveMoreChoose(
                              titStr: S.current.Live_Begin_MicSeatPrice,
                              rows: (widget.lastLiveEntity?.voicePrice ?? [])
                                      .isEmpty
                                  ? ConfigLiveApp.LiveVoicePrices.map((e) {
                                      return (e.toString() == '0')
                                          ? S.current.Live_Begin_Free
                                          : S.current.Live_Begin_Coins(e);
                                    }).toList()
                                  : widget.lastLiveEntity?.voicePrice?.map((e) {
                                        return (e.toString() == '0')
                                            ? S.current.Live_Begin_Free
                                            : S.current.Live_Begin_Coins(e);
                                      }).toList() ??
                                      [],
                              chooseCallback: (index) {
                                if (mounted) {
                                  setState(() {
                                    widget.lastLiveEntity?.chooseVoicePrice =
                                        (widget.lastLiveEntity?.voicePrice ??
                                                    [])
                                                .isEmpty
                                            ? (widget.lastLiveEntity
                                                        ?.voicePrice ??
                                                    ConfigLiveApp
                                                        .LiveVoicePrices)[index]
                                                .toString()
                                            : (ConfigLiveApp
                                                    .LiveVoicePrices[index])
                                                .toString();
                                  });
                                }
                              },
                            ));
                      } else if (rows[index] ==
                          S.current.Live_Begin_VideoSeatPrice) {
                        UtilsLiveAlert.showBottomSheet(
                            context,
                            WidgetLiveMoreChoose(
                              titStr: S.current.Live_Begin_VideoSeatPrice,
                              rows: (widget.lastLiveEntity?.videoPrice ?? [])
                                      .isEmpty
                                  ? ConfigLiveApp.LiveVideoPrices.map((e) {
                                      return (e.toString() == '0')
                                          ? S.current.Live_Begin_Free
                                          : S.current.Live_Begin_Coins(e);
                                    }).toList()
                                  : widget.lastLiveEntity?.videoPrice?.map((e) {
                                        return (e.toString() == '0')
                                            ? S.current.Live_Begin_Free
                                            : S.current.Live_Begin_Coins(e);
                                      }).toList() ??
                                      [],
                              chooseCallback: (index) {
                                if (mounted) {
                                  setState(() {
                                    widget.lastLiveEntity?.chooseVideoPrice =
                                        (widget.lastLiveEntity?.videoPrice ??
                                                    [])
                                                .isEmpty
                                            ? (widget.lastLiveEntity
                                                        ?.videoPrice ??
                                                    ConfigLiveApp
                                                        .LiveVideoPrices)[index]
                                                .toString()
                                            : (ConfigLiveApp
                                                    .LiveVideoPrices[index])
                                                .toString();
                                  });
                                }
                              },
                            ));
                      }
                    }),
                    child: Container(
                        padding: EdgeInsets.symmetric(horizontal: 15.w),
                        decoration: BoxDecoration(
                            borderRadius: BorderRadius.circular(15),
                            color: Colors.black.withOpacity(0.2)),
                        height: 50.w,
                        child: GestureDetector(
                          child: buildCell(rows[index], backInfo(rows[index])),
                          behavior: HitTestBehavior.opaque,
                        )),
                  );
                },
                separatorBuilder: (BuildContext context, int index) {
                  return Container(
                    margin: const EdgeInsets.only(top: 15),
                  );
                },
              ))
        ],
      ),
    );
  }

  String backInfo(String tit) {
    if (tit == S.current.Live_Begin_Language) {
      LanguageLists language = LanguageLists();
      language.value = "English";
      language.code = '01';
      ProviderLiveUser().userInfo.language?.forEach((element) {
        if (element.code == widget.lastLiveEntity?.language) {
          language = element;
        }
      });
      return language.value ?? '';
    } else if (tit == S.current.Live_Begin_MicSeatPrice) {
      return ((widget.lastLiveEntity?.chooseVoicePrice).toString() == '0')
          ? S.current.Live_Begin_Free
          : S.current
              .Live_Begin_Coins(widget.lastLiveEntity?.chooseVoicePrice ?? '');
    } else if (tit == S.current.Live_Begin_VideoSeatPrice) {
      return ((widget.lastLiveEntity?.chooseVideoPrice).toString() == '0')
          ? S.current.Live_Begin_Free
          : S.current
              .Live_Begin_Coins(widget.lastLiveEntity?.chooseVideoPrice ?? '');
    } else {
      return '';
    }
  }

  Widget buildCell(String title, String infoStr) {
    return Container(
      height: 50.w,
      color: Colors.transparent,
      child: Column(
        children: [
          Expanded(
              child: Row(
            mainAxisAlignment: MainAxisAlignment.spaceBetween,
            children: [
              Text(
                title,
                style: UtilsLiveTextStyle.pt18WhiteNormal,
              ),
              Row(
                children: [
                  Text(
                    infoStr,
                    style: TextStyle(
                        fontSize: 18,
                        color: UtilsLiveColor.hexToColor("#FFFFFF")
                            .withOpacity(0.8),
                        fontWeight: FontWeight.normal,
                        decoration: TextDecoration.none),
                  ),
                  Container(
                    padding: const EdgeInsets.only(left: 10),
                    child: UtilsLiveImage.getIconByPath(
                      'live_open_arrow',
                    ),
                  )
                ],
              )
            ],
          )),
        ],
      ),
    );
  }

  @override
  void initState() {
    super.initState();
  }

  @override
  void dispose() {
    _editingNameController.dispose();
    _editNameFocusNode.dispose();

    super.dispose();
  }

  @override
  void didUpdateWidget(WidgetOpenHeader oldWidget) {
    super.didUpdateWidget(oldWidget);
  }

  @override
  void didChangeDependencies() {
    super.didChangeDependencies();
  }
}
