// ignore_for_file: camel_case_types, use_key_in_widget_constructors

import 'dart:async';
import 'package:flutter/material.dart';
import 'package:flutter_screenutil/flutter_screenutil.dart';
import 'package:mmoo_base/dao/dao_result.dart';
import 'package:mmoo_base/dao/main_dao.dart';
import 'package:mmoo_base/utils/common_utils.dart';
import 'package:mmoo_live_room/Config/config_live_methon.dart';
import 'package:mmoo_live_room/Config/config_live_typedef.dart';
import 'package:mmoo_live_room/Model/model_live_info_entity.dart';
import 'package:mmoo_live_room/Model/model_live_show_list_entity.dart';
import 'package:mmoo_live_room/Provider/provider_live_info_entity.dart';
import 'package:mmoo_live_room/Provider/provider_live_user.dart';
import 'package:mmoo_live_room/Utils/utils_live_alert.dart';
import 'package:mmoo_live_room/Utils/utils_live_colors.dart';
import 'package:mmoo_live_room/Utils/utils_live_dlog.dart';
import 'package:mmoo_live_room/Utils/utils_live_image.dart';
import 'package:mmoo_live_room/generated/l10n.dart';
import 'package:mmoo_live_room/Model/model_live_apply_list_entity.dart';
import 'package:mmoo_live_room/Model/model_live_user_list_entity.dart';
import 'package:pull_to_refresh/pull_to_refresh.dart';

typedef voidUserNumCallBack = Function(int onlineNum, int applyNum);

///直播间  房子对用户的操作view
class WidgetOwnerManager extends StatefulWidget {
  final ClickCallBack clickCallBack;
  final ModelLiveInfoEntity infoEntity;
  const WidgetOwnerManager(
      {required this.infoEntity, required this.clickCallBack});
  @override
  WidgetOwnerManagerState createState() => WidgetOwnerManagerState();
}

class WidgetOwnerManagerState extends State<WidgetOwnerManager>
    with SingleTickerProviderStateMixin {
  TabController? _tabController;
  int _onlineNum = 0;
  int _applyNum = 0;
  bool isShowShare = false;
  @override
  Widget build(BuildContext context) {
    // widget.infoEntity
    return Container(
        height: 400.w + ScreenUtil().bottomBarHeight,
        padding: EdgeInsets.symmetric(horizontal: 15.w),
        decoration: const BoxDecoration(
            color: Color(0xff2B1248),
            borderRadius: BorderRadius.only(
                topLeft: Radius.circular(30), topRight: Radius.circular(30))),
        child: Column(children: [
          SizedBox(
            height: 60,
            child: Row(
              mainAxisAlignment: MainAxisAlignment.spaceBetween,
              children: [
                SizedBox(
                  height: 38,
                  width: 300.w,
                  // color: Colors.orange,
                  child: TabBar(
                    tabs: [
                      S.current.Live_WaitingNum(_applyNum),
                      S.current.Live_Guest(_onlineNum),
                      if (isShowShare) S.current.Live_Share
                    ].map((e) {
                      return Tab(
                        text: e,
                      );
                    }).toList(),
                    controller: _tabController,
                    labelPadding: const EdgeInsets.symmetric(horizontal: 8),
                    // padding: const EdgeInsets.symmetric(horizontal: 0),
                    unselectedLabelStyle: TextStyle(
                        fontSize: 16,
                        color: UtilsLiveColor.hexToColor("#FFFFFF")
                            .withOpacity(0.6),
                        fontWeight: FontWeight.bold,
                        decoration: TextDecoration.none),
                    // indicatorWeight: 0,

                    labelStyle: TextStyle(
                        fontSize: 20,
                        color: UtilsLiveColor.hexToColor("#FFFFFF"),
                        fontWeight: FontWeight.bold,
                        decoration: TextDecoration.none),
                    isScrollable: true,
                    labelColor: UtilsLiveColor.hexToColor("#FFFFFF"),
                    unselectedLabelColor:
                        UtilsLiveColor.hexToColor("#FFFFFF").withOpacity(0.6),
                    indicator: const BoxDecoration(),
                    onTap: (index) {
                      DLog(index);
                      // _tabsInt = index;
                    },
                  ),
                ),
                GestureDetector(
                  child: SizedBox(
                    width: 40,
                    height: 40,
                    child: UtilsLiveImage.getIconByPath(
                      'live_open_close',
                    ),
                  ),
                  onTap: () {
                    Navigator.pop(context);
                  },
                )
              ],
            ),
          ),
          Expanded(
              child: TabBarView(controller: _tabController, children: [
            WidgetOwnerWait(
              clickCallBack: widget.clickCallBack,
              infoEntity: widget.infoEntity,
              userNumCallBack: (int onlineNum, int applyNum) {
                widget.clickCallBack(
                    ConfigLiveMethon.liveupdataOnlineNum, onlineNum);
                widget.clickCallBack(ConfigLiveMethon.liveupdatWait, applyNum);
                if (mounted) {
                  setState(() {
                    _onlineNum = onlineNum;
                    _applyNum = applyNum;
                  });
                }
              },
            ),
            WidgetOwnerGuest(
              clickCallBack: widget.clickCallBack,
              infoEntity: widget.infoEntity,
              userNumCallBack: (int onlineNum, int applyNum) {
                widget.clickCallBack(
                    ConfigLiveMethon.liveupdataOnlineNum, onlineNum);
                widget.clickCallBack(ConfigLiveMethon.liveupdatWait, applyNum);
                if (mounted) {
                  setState(() {
                    _onlineNum = onlineNum;
                    _applyNum = applyNum;
                  });
                }
              },
            ),
            if (isShowShare)
              WidgetOwnerShare(
                clickCallBack: widget.clickCallBack,
                infoEntity: widget.infoEntity,
                userNumCallBack: (int onlineNum, int applyNum) {
                  // widget.clickCallBack(
                  //     ConfigLiveMethon.liveupdataOnlineNum, onlineNum);
                  // widget.clickCallBack(ConfigLiveMethon.liveupdatWait, applyNum);
                  // if (mounted) {
                  //   setState(() {
                  //     _onlineNum = onlineNum;
                  //     _applyNum = applyNum;
                  //   });
                  // }
                },
              )
          ]))
        ]));
  }

  @override
  void initState() {
    if (widget.infoEntity.type == 0 ||
        (widget.infoEntity.videoPlaceList ?? []).isNotEmpty) {
      isShowShare = true;
    }

    _tabController = TabController(vsync: this, length: isShowShare ? 3 : 2);

    super.initState();
  }

  @override
  void dispose() {
    super.dispose();
    _tabController?.dispose();
  }

  @override
  void didUpdateWidget(WidgetOwnerManager oldWidget) {
    super.didUpdateWidget(oldWidget);
  }

  @override
  void didChangeDependencies() {
    super.didChangeDependencies();
  }
}

class WidgetOwnerWait extends StatefulWidget {
  final ClickCallBack clickCallBack;
  final ModelLiveInfoEntity infoEntity;
  final voidUserNumCallBack userNumCallBack;
  const WidgetOwnerWait(
      {required this.infoEntity,
      required this.clickCallBack,
      required this.userNumCallBack});
  @override
  WidgetOwnerWaitState createState() => WidgetOwnerWaitState();
}

class WidgetOwnerWaitState extends State<WidgetOwnerWait> {
  RefreshController refreshController = RefreshController(initialRefresh: true);
  ModelLiveApplyListEntity _applyListEntity = ModelLiveApplyListEntity();
  @override
  Widget build(BuildContext context) {
    return SmartRefresher(
        controller: refreshController,
        enablePullDown: true,
        enablePullUp: true,
        onRefresh: _onRefresh,
        onLoading: _onLoading,
        child: ListView.separated(
          itemCount: _applyListEntity.userList?.length ?? 0,
          separatorBuilder: (BuildContext context, int index) {
            return Container(
              color: Colors.white.withOpacity(0.1),
              height: 1,
            );
          },
          itemBuilder: (BuildContext context, int index) {
            return buildApplyListView(_applyListEntity.userList![index]);
          },
        ));
  }

  Widget buildApplyListView(ModelLiveApplyListRows listRows) {
    return SizedBox(
      height: 70,
      // padding: EdgeInsets.symmetric(horizontal: 15.w),
      child: Row(
        mainAxisAlignment: MainAxisAlignment.spaceBetween,
        children: [
          Row(
            children: [
              Container(
                margin: EdgeInsets.only(right: 10.w),
                child: UtilsLiveImage.getIconByPath(
                  listRows.type == 0
                      ? 'icon_live_apply_voice_Application'
                      : 'icon_live_video_Application',
                ),
              ),
              SizedBox(
                width: 50.w,
                height: 50.w,
                child: ClipRRect(
                  borderRadius: BorderRadius.circular(25.w),
                  child: UtilsLiveImage.getLoadWidget(listRows.headImage),
                ),
              ),
              Column(
                mainAxisAlignment: MainAxisAlignment.center,
                crossAxisAlignment: CrossAxisAlignment.start,
                children: [
                  Row(
                    children: [
                      Container(
                        padding: const EdgeInsets.symmetric(horizontal: 10),
                        constraints: BoxConstraints(maxWidth: 140.w),
                        child: Text(
                          listRows.nickname ?? '',
                          maxLines: 1,
                          overflow: TextOverflow.ellipsis,
                          style: TextStyle(
                              fontSize: 18,
                              color: UtilsLiveColor.hexToColor("#FFFFFF"),
                              fontWeight: FontWeight.bold,
                              wordSpacing: -1,
                              decoration: TextDecoration.none),
                        ),
                      ),
                    ],
                  ),
                  const SizedBox(
                    height: 3,
                  ),
                  Container(
                    height: 20,
                    margin: const EdgeInsets.only(left: 10),
                    padding: const EdgeInsets.symmetric(horizontal: 7),
                    decoration: BoxDecoration(
                        borderRadius: BorderRadius.circular(10),
                        color: listRows.isAnchor == 1
                            ? UtilsLiveColor.hexToColor('#EB6B00')
                            : UtilsLiveColor.hexToColor("#FFFFFF")
                                .withOpacity(0.1)),
                    child: Row(
                      children: [
                        Text(
                          listRows.isAnchor == 1 ? 'Anchor' : 'Guest',
                          style: const TextStyle(
                              color: Colors.white,
                              fontSize: 12,
                              fontWeight: FontWeight.normal,
                              decoration: TextDecoration.none),
                        )
                      ],
                    ),
                  )
                ],
              ),
            ],
          ),
          Row(
            children: [
              GestureDetector(
                  behavior: HitTestBehavior.opaque,
                  child: UtilsLiveImage.getIconByPath(
                    'icon_live_apply_Delete',
                  ),
                  onTap: () {
                    // WidgetGeneralalert
                    // WidgetGeneralAlert(infoStr: infoStr)
                    clickApplyOrRefuse(listRows, false);
                  }),
              const SizedBox(
                width: 10,
              ),
              GestureDetector(
                behavior: HitTestBehavior.opaque,
                child: Container(
                    width: 80,
                    height: 30,
                    alignment: Alignment.center,
                    decoration: const ShapeDecoration(
                        shape: StadiumBorder(),
                        gradient:
                            LinearGradient(colors: UtilsLiveColor.startColors)),
                    child: Text(
                      S.current.Live_Accept,
                      style: const TextStyle(
                          color: Colors.white,
                          fontWeight: FontWeight.bold,
                          fontSize: 16),
                    )),
                onTap: () {
                  UtilsLiveAlert.showCenterGeneral(
                    context,
                    infoStr: listRows.type == 0
                        ? S.current.Live_AgreeAudioChat
                        : S.current.Live_AgreeVideoChat,
                    isLive: true,
                    leftStr: S.current.Live_Cancel,
                    rightStr: S.current.Live_Yes,
                    rightVoidCallBack: () {
                      clickApplyOrRefuse(listRows, true);
                    },
                  );
                },
              ),
            ],
          ),
        ],
      ),
    );
  }

  clickApplyOrRefuse(ModelLiveApplyListRows listRows, bool isApply) async {
    DataResult dataResult = await MainDao.livePostAgreeForMike(
        roomId: widget.infoEntity.roomId ?? 0,
        type: isApply ? 1 : 0,
        userId: listRows.userId ?? 0);

    if (dataResult.result && dataResult.data != null) {
      if ((_applyListEntity.applyNum ?? 0) > 0) {
        _applyListEntity.applyNum = (_applyListEntity.applyNum ?? 0) - 1;
      }
      widget.userNumCallBack(
          _applyListEntity.onlineNum ?? 0, _applyListEntity.applyNum ?? 0);
      if (mounted) {
        setState(() {
          _applyListEntity.userList!.remove(listRows);
        });
      }
    } else {
      refreshController.requestRefresh();
      UtilsLiveAlert.showDioTips(context, dataResult);
    }
  }

  _onRefresh() async {
    _applyListEntity.num = 1;

    _refreshDataSource();
  }

  _refreshDataSource() async {
    DataResult dataResult = await MainDao.livePostApplyList(
        roomId: widget.infoEntity.roomId ?? 0, num: 1, size: 20);
    refreshController.refreshCompleted();
    if (dataResult.result && dataResult.data != null) {
      ModelLiveApplyListEntity listEntity =
          ModelLiveApplyListEntity().fromJson(dataResult.data);
      widget.userNumCallBack(
          listEntity.onlineNum ?? 0, listEntity.applyNum ?? 0);

      if ((listEntity.userList?.length ?? 0) < 20) {
        refreshController.loadNoData();
      } else {
        refreshController.loadComplete();
      }
      if (listEntity.num == 1) {
        _applyListEntity = ModelLiveApplyListEntity().fromJson(dataResult.data);
        // widget.userNumCallBack(
        //   _applyListEntity.onlineNum ?? 0, _applyListEntity.applyNum ?? 0);
        // if (ProviderLiveJoinPlace().joinNum != _applyListEntity.applyNum) {
        //   ProviderLiveJoinPlace joinPlace =
        //       Provider.of<ProviderLiveJoinPlace>(context, listen: false);
        //   joinPlace.joinNum = listEntity.applyNum ?? 0;

        // }
        // if (ProviderLiveOnline().onLineNum != _applyListEntity.onlineNum) {

        //   ProviderLiveOnline onlineProvider =
        //       Provider.of<ProviderLiveOnline>(context, listen: false);
        //   onlineProvider.onLineNum = _applyListEntity.onlineNum ?? 0;
        // }
      } else {
        _applyListEntity.userList?.addAll(listEntity.userList ?? []);
      }
      if (mounted) {
        setState(() {});
      }
    } else {
      refreshController.loadFailed();
    }
  }

  _onLoading() async {
    _applyListEntity.num = (_applyListEntity.num ?? 1) + 1;
    _refreshDataSource();
  }

  @override
  void initState() {
    _applyListEntity.userList = [];

    super.initState();
  }

  @override
  void dispose() {
    super.dispose();
  }

  @override
  void didUpdateWidget(WidgetOwnerWait oldWidget) {
    super.didUpdateWidget(oldWidget);
  }

  @override
  void didChangeDependencies() {
    super.didChangeDependencies();
  }
}

class WidgetOwnerGuest extends StatefulWidget {
  final ClickCallBack clickCallBack;
  final ModelLiveInfoEntity infoEntity;
  final voidUserNumCallBack userNumCallBack;
  const WidgetOwnerGuest(
      {required this.infoEntity,
      required this.clickCallBack,
      required this.userNumCallBack});
  @override
  WidgetOwnerGuestState createState() => WidgetOwnerGuestState();
}

class WidgetOwnerGuestState extends State<WidgetOwnerGuest> {
  final RefreshController _refreshController =
      RefreshController(initialRefresh: true);

  ModelLiveUserListEntity _userlistEntity = ModelLiveUserListEntity();
  Timer? _timerUtil;
  @override
  Widget build(BuildContext context) {
    return SmartRefresher(
      enablePullDown: true,
      enablePullUp: true,
      controller: _refreshController,
      onRefresh: _onRefresh,
      onLoading: _onLoading,
      child: ListView.separated(
        itemCount: _userlistEntity.users?.length ?? 0,
        separatorBuilder: (BuildContext context, int index) {
          return Container(
            color: Colors.white.withOpacity(0.1),
            height: 1,
          );
        },
        itemBuilder: (c, i) => buildMemberList(_userlistEntity.users![i]),
      ),
    );
  }

  Widget buildMemberList(ModelLiveUserListUsers listModel) {
    return SizedBox(
      height: 70,
      // margin: EdgeInsets.symmetric(horizontal: 15.w, vertical: 13.w),
      child: Row(
        mainAxisAlignment: MainAxisAlignment.spaceBetween,
        children: [
          Row(
            children: [
              GestureDetector(
                child: ClipRRect(
                  borderRadius: BorderRadius.circular(25.w),
                  child: SizedBox(
                    width: 50.w,
                    height: 50.w,
                    child: UtilsLiveImage.getLoadWidget(listModel.headImage),
                  ),
                ),
                onTap: () {
                  widget.clickCallBack(
                      ConfigLiveMethon.liveClickUserInfo, listModel.userId);
                  Navigator.pop(context);
                },
              ),
              Column(
                mainAxisAlignment: MainAxisAlignment.center,
                crossAxisAlignment: CrossAxisAlignment.start,
                children: [
                  Row(
                    children: [
                      Container(
                        padding: const EdgeInsets.symmetric(horizontal: 10),
                        constraints: BoxConstraints(maxWidth: 180.w),
                        child: Text(
                          listModel.nickname ?? '',
                          maxLines: 1,
                          overflow: TextOverflow.ellipsis,
                          style: TextStyle(
                              fontSize: 18,
                              color: UtilsLiveColor.hexToColor("#FFFFFF"),
                              fontWeight: FontWeight.bold,
                              wordSpacing: -1,
                              decoration: TextDecoration.none),
                        ),
                      ),
                    ],
                  ),

                  const SizedBox(
                    height: 3,
                  ),

                  //   Container(
                  //   height: 20,
                  //   margin: const EdgeInsets.only(left: 10),
                  //   padding: const EdgeInsets.symmetric(horizontal: 7),
                  //   decoration: BoxDecoration(
                  //       borderRadius: BorderRadius.circular(10),
                  //       color: listModel.isHost == 0
                  //           ? UtilsLiveColor.hexToColor("#FFFFFF")
                  //               .withOpacity(0.1)
                  //           : listModel.userId ==
                  //                   ProviderLiveInfoEntity().infoEntity.userId
                  //               ? const Color(0xffFB5C9A)
                  //               : UtilsLiveColor.hexToColor('#EB6B00')),
                  //   // Color(0xffFB5C9A)
                  //   child: Row(
                  //     children: [
                  //       Text(
                  //         listModel.isHost == 0
                  //             ? 'Guest'
                  //             : listModel.userId ==
                  //                     ProviderLiveInfoEntity().infoEntity.userId
                  //                 ? 'Owners'
                  //                 : 'Anchor',
                  //         style: const TextStyle(
                  //             color: Colors.white,
                  //             fontSize: 12,
                  //             fontWeight: FontWeight.normal,
                  //             decoration: TextDecoration.none),
                  //       )
                  //     ],
                  //   ),
                  // )
                  Container(
                    height: 20,
                    margin: const EdgeInsets.only(left: 10),
                    padding: const EdgeInsets.symmetric(horizontal: 7),
                    decoration: BoxDecoration(
                        borderRadius: BorderRadius.circular(10),
                        color: listModel.isHost == 0
                            ? UtilsLiveColor.hexToColor("#FFFFFF")
                                .withOpacity(0.1)
                            : listModel.userId ==
                                    ProviderLiveInfoEntity().infoEntity.userId
                                ? const Color(0xffFB5C9A)
                                : UtilsLiveColor.hexToColor('#EB6B00')),
                    child: Row(
                      children: [
                        Text(
                          listModel.isHost == 0
                              ? 'Guest'
                              : listModel.userId ==
                                      ProviderLiveInfoEntity().infoEntity.userId
                                  ? 'Owners'
                                  : 'Anchor',
                          style: const TextStyle(
                              color: Colors.white,
                              fontSize: 12,
                              fontWeight: FontWeight.normal,
                              decoration: TextDecoration.none),
                        )
                      ],
                    ),
                  )
                ],
              ),
            ],
          ),
          Visibility(
              visible: ProviderLiveUser().userInfo.uid != listModel.userId,
              child: listModel.invitedCOunt == 0
                  ? Row(
                      children: [
                        Visibility(
                            visible: (widget.infoEntity.videoPlaceList ?? [])
                                    .isNotEmpty &&
                                (widget.infoEntity.voicePlaceList ?? [])
                                    .isNotEmpty &&
                                (listModel.roomPlaceId ?? 0) == 0,
                            child: buildVoiceBtn(listModel)),
                        SizedBox(
                          width: 10.w,
                        ),
                        (listModel.roomPlaceId ?? 0) > 0
                            ? buildRoomPlaceBtn(listModel)
                            : ((widget.infoEntity.videoPlaceList ?? [])
                                    .isNotEmpty
                                ? buildVideoBtn(listModel)
                                : buildVoiceBtn(listModel))
                      ],
                    )
                  : Container(
                      width: 90,
                      height: 30,
                      decoration: ShapeDecoration(
                          shape: const StadiumBorder(),
                          gradient: LinearGradient(colors: [
                            const Color(0xffFB5C9A).withOpacity(0.4),
                            const Color(0xffF775F2).withOpacity(0.4)
                          ])),
                      alignment: Alignment.center,
                      child: Text(
                        S.current.Live_Invited(listModel.invitedCOunt),
                        style: TextStyle(
                            fontSize: 16,
                            wordSpacing: -1,
                            color: UtilsLiveColor.hexToColor("#FFFFFF")
                                .withOpacity(0.6),
                            fontWeight: FontWeight.bold,
                            decoration: TextDecoration.none),
                      ),
                    ))
        ],
      ),
    );
  }

  Widget buildRoomPlaceBtn(ModelLiveUserListUsers listModel) {
    return GestureDetector(
      behavior: HitTestBehavior.opaque,
      onTap: () {
        // listModel.invitedCOunt = 5;
      },
      child: UtilsLiveImage.getIconByPath(
        listModel.type == 0
            ? 'icon_live_guest_in_voice'
            : 'icon_live_guest_in_video',
      ),
    );
  }

  Widget buildVideoBtn(ModelLiveUserListUsers listModel) {
    return GestureDetector(
      behavior: HitTestBehavior.opaque,
      onTap: () async {
        CommonUtils.showLoading();
        DataResult dataResult = await MainDao.livePostMasterInvite(
            userId: listModel.userId ?? 0,
            roomId: widget.infoEntity.roomId ?? 0,
            type: 1);
        CommonUtils.dismiss();
        if (dataResult.result) {
          CommonUtils.showToast(S.current.Live_invitationsentout);
          if (mounted) {
            listModel.invitedCOunt = 5;
            if (mounted) {
              setState(() {});
            }
          }
        } else {
          UtilsLiveAlert.showDioTips(context, dataResult);
        }
      },
      child: UtilsLiveImage.getIconByPath(
        'icon_live_guest_invite_video',
      ),
    );
  }

  Widget buildVoiceBtn(ModelLiveUserListUsers listModel) {
    return GestureDetector(
      behavior: HitTestBehavior.opaque,
      onTap: () async {
        CommonUtils.showLoading();
        DataResult dataResult = await MainDao.livePostMasterInvite(
            userId: listModel.userId ?? 0,
            roomId: widget.infoEntity.roomId ?? 0,
            type: 0);
        CommonUtils.dismiss();
        if (dataResult.result) {
          CommonUtils.showToast(S.current.Live_invitationsentout);
          if (mounted) {
            listModel.invitedCOunt = 5;
            if (mounted) {
              setState(() {});
            }
          }
        } else {
          UtilsLiveAlert.showDioTips(context, dataResult);
        }
      },
      child: UtilsLiveImage.getIconByPath(
        'icon_live_guest_invite_voice',
      ),
    );
  }

  void _onRefresh() async {
    _userlistEntity.num = 1;
    refreshDataSource();
  }

  void refreshDataSource() async {
    final res = await MainDao.livePostRoomUserList(
        roomId: widget.infoEntity.roomId ?? 0, num: _userlistEntity.num ?? 1);
    _refreshController.refreshCompleted();
    if (res.result && res.data != null) {
      ModelLiveUserListEntity entity =
          ModelLiveUserListEntity().fromJson(res.data);
      widget.userNumCallBack(entity.onlineNum ?? 0, entity.applyNum ?? 0);
      if ((entity.users?.length ?? 0) < 20) {
        _refreshController.loadNoData();
      } else {
        _refreshController.loadComplete();
      }
      if (entity.num == 1) {
        _userlistEntity = ModelLiveUserListEntity().fromJson(res.data);
      } else {
        _userlistEntity.users?.addAll(entity.users ?? []);
      }
      if (mounted) {
        setState(() {});
      }
    } else {
      _refreshController.refreshFailed();
      _refreshController.loadFailed();
    }
  }

  void _onLoading() async {
    // monitor network fetch
    _userlistEntity.num = (_userlistEntity.num ?? 1) + 1;
    refreshDataSource();
  }

  startCount() {
    // void startTimer() {
    if (_timerUtil?.isActive == true) {
      _timerUtil?.cancel();
    }
    bool isInvited = false;
    _timerUtil = Timer.periodic(const Duration(seconds: 1), (timer) {
      isInvited = false;
      _userlistEntity.users?.forEach((element) {
        if (element.invitedCOunt > 0) {
          element.invitedCOunt = (element.invitedCOunt - 1);
          isInvited = true;
        }
        if (isInvited && mounted) {
          setState(() {});
        }
      });
    });
    // }
  }

  @override
  void initState() {
    startCount();

    _userlistEntity.num = 1;
    _userlistEntity.users = [];

    super.initState();
  }

  @override
  void dispose() {
    _timerUtil?.cancel();

    super.dispose();
  }

  @override
  void didUpdateWidget(WidgetOwnerGuest oldWidget) {
    super.didUpdateWidget(oldWidget);
  }

  @override
  void didChangeDependencies() {
    super.didChangeDependencies();
  }
}

class WidgetOwnerShare extends StatefulWidget {
  final ClickCallBack clickCallBack;
  final ModelLiveInfoEntity infoEntity;
  final voidUserNumCallBack userNumCallBack;
  const WidgetOwnerShare(
      {required this.infoEntity,
      required this.clickCallBack,
      required this.userNumCallBack});
  @override
  WidgetOwnerShareState createState() => WidgetOwnerShareState();
}

class WidgetOwnerShareState extends State<WidgetOwnerShare> {
  final RefreshController _refreshController =
      RefreshController(initialRefresh: true);

  ModelLiveShowListEntity _sharelistEntity = ModelLiveShowListEntity();
  Timer? _timerUtil;
  @override
  Widget build(BuildContext context) {
    return SmartRefresher(
      enablePullDown: true,
      enablePullUp: true,
      controller: _refreshController,
      onRefresh: _onRefresh,
      onLoading: _onLoading,
      child: ListView.separated(
        itemCount: _sharelistEntity.rows?.length ?? 0,
        separatorBuilder: (BuildContext context, int index) {
          return Container(
            color: Colors.white.withOpacity(0.1),
            height: 1,
          );
        },
        itemBuilder: (c, i) => buildMemberList(_sharelistEntity.rows![i]),
      ),
    );
  }

  Widget buildMemberList(ModelLiveShowListRows listModel) {
    return SizedBox(
      height: 70,
      // margin: EdgeInsets.symmetric(horizontal: 15.w, vertical: 13.w),
      child: Row(
        mainAxisAlignment: MainAxisAlignment.spaceBetween,
        children: [
          Row(
            children: [
              GestureDetector(
                child: ClipRRect(
                  borderRadius: BorderRadius.circular(25.w),
                  child: SizedBox(
                    width: 50.w,
                    height: 50.w,
                    child: UtilsLiveImage.getLoadWidget(listModel.headImage),
                  ),
                ),
                onTap: () {
                  widget.clickCallBack(
                      ConfigLiveMethon.liveClickUserInfo, listModel.userId);
                  Navigator.pop(context);
                },
              ),
              Column(
                mainAxisAlignment: MainAxisAlignment.center,
                crossAxisAlignment: CrossAxisAlignment.start,
                children: [
                  Row(
                    children: [
                      Container(
                        padding: const EdgeInsets.symmetric(horizontal: 10),
                        constraints: BoxConstraints(maxWidth: 180.w),
                        child: Text(
                          listModel.nickname ?? '',
                          maxLines: 1,
                          overflow: TextOverflow.ellipsis,
                          style: TextStyle(
                              fontSize: 18,
                              color: UtilsLiveColor.hexToColor("#FFFFFF"),
                              fontWeight: FontWeight.bold,
                              wordSpacing: -1,
                              decoration: TextDecoration.none),
                        ),
                      ),
                    ],
                  ),
                  const SizedBox(
                    height: 3,
                  ),
                  Container(
                    height: 20,
                    margin: const EdgeInsets.only(left: 10),
                    padding: const EdgeInsets.symmetric(horizontal: 7),
                    decoration: BoxDecoration(
                        borderRadius: BorderRadius.circular(10),
                        color: listModel.isAnchor == 0
                            ? UtilsLiveColor.hexToColor("#FFFFFF")
                                .withOpacity(0.1)
                            : listModel.userId ==
                                    ProviderLiveInfoEntity().infoEntity.userId
                                ? const Color(0xffFB5C9A)
                                : UtilsLiveColor.hexToColor('#EB6B00')),
                    child: Row(
                      children: [
                        Text(
                          listModel.isAnchor == 0
                              ? 'Guest'
                              : listModel.userId ==
                                      ProviderLiveInfoEntity().infoEntity.userId
                                  ? 'Owners'
                                  : 'Anchor',
                          style: const TextStyle(
                              color: Colors.white,
                              fontSize: 12,
                              fontWeight: FontWeight.normal,
                              decoration: TextDecoration.none),
                        )
                      ],
                    ),
                  )
                ],
              ),
            ],
          ),
          Visibility(
              visible: ProviderLiveUser().userInfo.uid != listModel.userId,
              child: listModel.invitedCount == 0
                  ? GestureDetector(
                      behavior: HitTestBehavior.opaque,
                      child: Container(
                          width: 90,
                          height: 30,
                          alignment: Alignment.center,
                          decoration: const ShapeDecoration(
                              shape: StadiumBorder(),
                              gradient: LinearGradient(
                                  colors: UtilsLiveColor.startColors)),
                          child: Text(
                            S.current.Live_Invitation,
                            style: const TextStyle(
                                color: Colors.white,
                                fontWeight: FontWeight.bold,
                                fontSize: 16),
                          )),
                      onTap: () {
                        _invitationAnchorJoinLive(listModel);
                      },
                    )
                  : Container(
                      width: 90,
                      height: 30,
                      decoration: ShapeDecoration(
                          shape: const StadiumBorder(),
                          gradient: LinearGradient(colors: [
                            const Color(0xffFB5C9A).withOpacity(0.4),
                            const Color(0xffF775F2).withOpacity(0.4)
                          ])),
                      alignment: Alignment.center,
                      child: Text(
                        S.current.Live_Invited(listModel.invitedCount),
                        style: TextStyle(
                            fontSize: 16,
                            wordSpacing: -1,
                            color: UtilsLiveColor.hexToColor("#FFFFFF")
                                .withOpacity(0.6),
                            fontWeight: FontWeight.bold,
                            decoration: TextDecoration.none),
                      ),
                    ))
        ],
      ),
    );
  }

  void _onRefresh() async {
    _sharelistEntity.num = 1;
    refreshDataSource();
  }

  void refreshDataSource() async {
    final res = await MainDao.postAnchorInviteList(
        num: 1, roomId: widget.infoEntity.roomId ?? 0);
    _refreshController.refreshCompleted();
    if (res.result && res.data != null) {
      ModelLiveShowListEntity entity =
          ModelLiveShowListEntity().fromJson(res.data);
      // widget.userNumCallBack(entity.onlineNum ?? 0, entity.applyNum ?? 0);
      if ((entity.rows?.length ?? 0) < 20) {
        _refreshController.loadNoData();
      } else {
        _refreshController.loadComplete();
      }
      if (entity.num == 1) {
        _sharelistEntity = ModelLiveShowListEntity().fromJson(res.data);
      } else {
        _sharelistEntity.rows?.addAll(entity.rows ?? []);
      }
      if (mounted) {
        setState(() {});
      }
    } else {
      _refreshController.refreshFailed();
      _refreshController.loadFailed();
    }
  }

  void _onLoading() async {
    // monitor network fetch
    _sharelistEntity.num = (_sharelistEntity.num ?? 1) + 1;
    refreshDataSource();
  }

  startCount() {
    // void startTimer() {
    if (_timerUtil?.isActive == true) {
      _timerUtil?.cancel();
    }
    bool isInvited = false;
    _timerUtil = Timer.periodic(const Duration(seconds: 1), (timer) {
      isInvited = false;
      _sharelistEntity.rows?.forEach((element) {
        if (element.invitedCount > 0) {
          element.invitedCount = (element.invitedCount - 1);
          isInvited = true;
        }
        if (isInvited && mounted) {
          setState(() {});
        }
      });
    });
    // }
  }

  _invitationAnchorJoinLive(ModelLiveShowListRows rows) async {
    CommonUtils.showLoading();
    final res = await MainDao.postAnchorInviteOther(
        ids: [rows.userId],
        roomId: widget.infoEntity.roomId ?? 0,
        liveId: widget.infoEntity.liveId ?? 0);
    CommonUtils.dismiss();
    if (res.result && res.data != null) {
      CommonUtils.showToast(S.current.Live_invitationsentout);
      if (mounted) {
        rows.invitedCount = 5;
        if (mounted) {
          setState(() {});
        }
      }
    } else {
      UtilsLiveAlert.showDioTips(context, res);
    }
  }

  @override
  void initState() {
    startCount();

    _sharelistEntity.num = 1;
    _sharelistEntity.rows = [];

    super.initState();
  }

  @override
  void dispose() {
    _timerUtil?.cancel();

    super.dispose();
  }

  @override
  void didUpdateWidget(WidgetOwnerShare oldWidget) {
    super.didUpdateWidget(oldWidget);
  }

  @override
  void didChangeDependencies() {
    super.didChangeDependencies();
  }
}
