import 'package:flutter/material.dart';
import 'package:flutter_screenutil/flutter_screenutil.dart';
import 'package:mmoo_live_room/Config/config_live_methon.dart';
import 'package:mmoo_live_room/Config/config_live_typedef.dart';
import 'package:mmoo_live_room/Model/model_live_info_entity.dart';
import 'package:mmoo_live_room/Provider/provider_live_im_unread.dart';
import 'package:mmoo_live_room/Provider/provider_live_join_place.dart';
import 'package:mmoo_live_room/Provider/provider_live_user.dart';
import 'package:mmoo_live_room/Utils/utils_live_colors.dart';
import 'package:mmoo_live_room/Utils/utils_live_image.dart';
import 'package:mmoo_live_room/generated/l10n.dart';
import 'package:provider/provider.dart';
///直播间  底部按钮view
class WidghtLiveBottomBtn extends StatefulWidget {
  final double height;
  final ClickCallBack clickCallBack;
  final ModelLiveInfoEntity infoEntity;
  WidghtLiveBottomBtn(this.height,
      {required this.infoEntity, required this.clickCallBack});
  @override
  WidghtLiveBottomBtnState createState() => WidghtLiveBottomBtnState();
}

class WidghtLiveBottomBtnState extends State<WidghtLiveBottomBtn> {
  @override
  Widget build(BuildContext context) {
    return Consumer<ProviderLiveUser>(
        builder: (context, bottomStateProvider, child) {
      return Container(
        height: widget.height,
        margin: EdgeInsets.only(right: 10.w),
        // color: Colors.black45,
        child: Row(
          mainAxisAlignment: MainAxisAlignment.spaceBetween,
          crossAxisAlignment: CrossAxisAlignment.center,
          children: [
            Row(
              mainAxisAlignment: MainAxisAlignment.end,
              children: buildBottomBtn(bottomStateProvider),
            ),
            GestureDetector(
                onTap: () {
                  widget.clickCallBack(ConfigLiveMethon.liveBottomJoin, null);
                },
                child:
                    widget.infoEntity.userId == ProviderLiveUser().userInfo.uid
                        ? buildManagerBtn()
                        : buildJoinBtn(bottomStateProvider)),
          ],
        ),
      );
    });
  }

  Widget buildJoinBtn(ProviderLiveUser bottomStateProvider) {
    if (bottomStateProvider.isLiving) {
      return UtilsLiveImage.getIconByPath(
        'icon_live_hangup',
      );
    } else {
      return Container(
        height: 40,
        decoration: BoxDecoration(
            borderRadius: BorderRadius.circular(25.w),
            gradient: LinearGradient(
                colors: bottomStateProvider.isApplyForMike
                    ? [
                       const Color(0xff0FEBB9).withOpacity(0.4),
                       const Color(0xff00C9D9).withOpacity(0.4)
                      ]
                    : [const Color(0xff0FEBB9),const Color(0xff00C9D9)])),
        padding: EdgeInsets.symmetric(horizontal: 17.w),
        child: Row(
          children: [
            UtilsLiveImage.getIconByPath(
              bottomStateProvider.isApplyForMike
                  ? 'icon_live_join_waiting'
                  : 'icon_live_join',
            ),
            SizedBox(
              width: 5.w,
            ),
            Text(bottomStateProvider.isApplyForMike ? S.current.Live_Waiting : S.current.Live_Join,
                style: TextStyle(
                    fontSize: 16,
                    color: bottomStateProvider.isApplyForMike
                        ? Colors.white.withOpacity(0.6)
                        : Colors.white,
                    fontWeight: FontWeight.bold,
                    decoration: TextDecoration.none))
          ],
        ),
      );
    }
  }

  Widget buildManagerBtn() {
    // ProviderLiveJoinPlace().applyNum = 2;
    return Consumer<ProviderLiveJoinPlace>(
        builder: (context, joinProvider, child) {
      return Container(
        height: 40,
        decoration: BoxDecoration(
            borderRadius: BorderRadius.circular(25.w),
            gradient: LinearGradient(
                colors: joinProvider.applyNum == 0
                    ? [
                        Colors.white.withOpacity(0.2),
                        Colors.white.withOpacity(0.2)
                      ]
                    : UtilsLiveColor.startColors)),
        padding: EdgeInsets.symmetric(horizontal: 17.w),
        child: Row(
          children: [
            UtilsLiveImage.getIconByPath(
              'icon_live_join',
              
            ),
            SizedBox(
              width: 5.w,
            ),
            Text(
                joinProvider.applyNum == 0
                    ? 'Manage'
                    : joinProvider.applyNum.toString(),
                style: TextStyle(
                    fontSize: joinProvider.applyNum == 0 ? 16 : 20,
                    color: Colors.white,
                    fontWeight: FontWeight.bold,
                    decoration: TextDecoration.none))
          ],
        ),
      );
    });
  }

  List<Widget> buildBottomBtn(ProviderLiveUser bottomStateProvider) {
    List roleViews = [
      {"tit": ConfigLiveMethon.liveBottomGroupChat, "im": "icon_live_message_room"},
    ];
    if (widget.infoEntity.type == 0) {
      if (bottomStateProvider.isLiving) {
        roleViews.add(
          bottomStateProvider.voice == 0
              ? {
                  "tit": ConfigLiveMethon.liveBottomMic,
                  "im": "icon_live_bottom_mic_ban"
                }
              : bottomStateProvider.voice == 1
                  ? {
                      "tit": ConfigLiveMethon.liveBottomMic,
                      "im": "icon_live_bottom_mic_open"
                    }
                  : {
                      "tit": ConfigLiveMethon.liveBottomMic,
                      "im": "icon_live_bottom_mic_close"
                    },
        );
      }
      roleViews.add(
        bottomStateProvider.isSpeaker
            ? {
                "tit": ConfigLiveMethon.liveBottomlLoudSpeaker,
                "im": "icon_live_bottom_sound_open"
              }
            : {
                "tit": ConfigLiveMethon.liveBottomlLoudSpeaker,
                "im": "icon_live_bottom_sound_close"
              },
      );
    } else {
      roleViews.add(
        {"tit": ConfigLiveMethon.liveBottomMore, "im": "icon_live_more"},
      );
    }
    roleViews.add(
      {"tit": ConfigLiveMethon.liveBottomGift, "im": "icon_live_send_gift"},
    );
    return roleViews.map((e) {
      return GestureDetector(
        child: Container(
          width: 40,
          height: 40,
          margin: EdgeInsets.only(left: 10.w),
          child: e['tit'] == ConfigLiveMethon.liveBottomGroupChat
              ? Stack(
                  children: [
                    Positioned.fill(
                      child: UtilsLiveImage.getIconByPath(
                        e['im'] ,
                      ),
                    ),
                    Positioned(
                        right: 0,
                        child: Consumer<ProviderLiveImUnRead>(
                            builder: (_, unreadProvider, __) {
                          return Visibility(
                            child: Container(
                                width: 18.w,
                                height: 18.w,
                                decoration: BoxDecoration(
                                    color: UtilsLiveColor.hexToColor('#F53838'),
                                    borderRadius: BorderRadius.circular(9.w)),
                                child: Center(
                                  child: Text(
                                    unreadProvider.unReadNum < 100
                                        ? unreadProvider.unReadNum.toString()
                                        : "99",
                                    style: TextStyle(
                                      color: UtilsLiveColor.hexToColor(
                                        '#FFFFFF',
                                      ),
                                      fontSize: 14,
                                    ),
                                  ),
                                )),
                            visible: unreadProvider.unReadNum > 0,
                          );
                        }))
                  ],
                )
              : UtilsLiveImage.getIconByPath(
                   e['im'] ,
                  
                ),
        ),
        onTap: () {
          widget.clickCallBack(e['tit'], null);
        },
      );
    }).toList();
  }

  @override
  void initState() {
    super.initState();
  }

  @override
  void dispose() {
    super.dispose();
  }

  @override
  void didUpdateWidget(WidghtLiveBottomBtn oldWidget) {
    super.didUpdateWidget(oldWidget);
  }

  @override
  void didChangeDependencies() {
    super.didChangeDependencies();
  }
}
